@@ -1,5 +1,5 @@
 <?php
-/* $Id: croatian-utf-8.inc.php 10758 2007-10-10 21:15:26Z lem9 $ */
+/* $Id: croatian-utf-8.inc.php 11651 2008-10-14 16:54:11Z lem9 $ */
 
 /**
  *   Croatian language file by
@@ -21,12 +21,12 @@ $month = array('Sij', 'Velj', 'Ožu', 'Tra', 'Svi', 'Lip', 'Srp', 'Kol', 'Ruj',
 $datefmt = '%B %d, %Y u %I:%M %p';
 $timespanfmt = '%s dana, %s sati, %s minuta i %s sekunda';
 
-
 $strAbortedClients = 'Prekinuto';
 $strAccessDeniedCreateConfig = 'Vjerojatan razlog je nepostojeća konfiguracijska datoteka. Za izradu možete upotrijebiti naredbu %1$ssetup script%2$s';
 $strAccessDeniedExplanation = 'phpMyAdmin pokušao je uspostaviti vezu s MySQL poslužiteljem, ali je poslužitelj odbio povezivanje. U datoteci config.inc.php provjerite naziv računala, korisničko ime i lozinku, te provjerite da se odgovaraju podacima koje vam je dao administrator MySQL poslužitelja.';
 $strAccessDenied = 'Pristup odbijen';
 $strAction = 'Aktivnost';
+$strActions = 'Aktivnosti';
 $strAddAutoIncrement = 'Dodaj vrijednost AUTO_INCREMENT';
 $strAddClause = 'Dodaj %s';
 $strAddConstraints = 'Dodaj prisile';
@@ -43,7 +43,6 @@ $strAddToIndex = 'Dodaj u indeks &nbsp;%s&nbsp;stupci';
 $strAddUser = 'Dodaj novog korisnika';
 $strAddUserMessage = 'Dodali ste novog korisnika.';
 $strAdministration = 'Administracija';
-$strAffectedRows = 'Zahvaćeni redovi:';
 $strAfterInsertBack = 'Kreni nazad na prethodnu stranicu';
 $strAfterInsertNewInsert = 'Umetni dodatni novi redak';
 $strAfterInsertNext = 'Uredi sljedeći redak';
@@ -53,6 +52,7 @@ $strAllowInterrupt = 'Dopusti prekid uvoza u slučaju da skripta otkrije blizinu
 $strAll = 'Sve';
 $strAllTableSameWidth = 'Prikazati sve tablice uz istu širinu?';
 $strAlterOrderBy = 'Izmijeni rasporede tablice po';
+$strAnalyze = 'Analiziraj';
 $strAnalyzeTable = 'Analiziraj tablicu';
 $strAnd = 'I';
 $strAndThen = 'i potom';
@@ -66,6 +66,7 @@ $strAPrimaryKey = 'Primarni ključ je dodan na %s';
 $strArabic = 'Arapski';
 $strArmenian = 'Armenski';
 $strAscending = 'Uzlazno';
+$strAsDefined = 'Kako je definirano:';
 $strAtBeginningOfTable = 'Pri početku tablice';
 $strAtEndOfTable = 'Pri završetku tablice';
 $strAttr = 'Atributi';
@@ -104,7 +105,6 @@ $strBufferWriteWaitsInPercent = 'Zapisivanje čeka pri %';
 $strBufferWriteWaits = 'Zapisivanje čeka';
 $strBulgarian = 'Bugarski';
 $strBusyPages = 'Zaposlene stranice';
-$strBzError = 'phpMyAdmin nije bio u mogućnosti komprimirati izbacivanje zbog prekinutog Bz2 proširenja u ovoj verziji PHP-a. Snažno se preporučuje da postavite <code>$cfg[\'BZipDump\']</code> direktivu u vašoj phpMyAdmin konfiguracijskoj datoteci na <code>FALSE</code>Ako želite upotrebljavati kompresijsku osobinu Bz2, bit će potrebna nadogradnja na noviju verziju PHP-a. Detalje pregledajte u izvještaju PHP nedostataka: %s.';
 $strBzip = '"bzipano"';
 
 $strCalendar = 'Kalendar';
@@ -137,6 +137,7 @@ $strCheckAll = 'Označi sve';
 $strCheckOverhead = 'Provjeri za prepunjene tablice';
 $strCheckPrivsLong = 'Provjeri privilegije za bazu podataka "%s".';
 $strCheckPrivs = 'Provjeri privilegije';
+$strCheck = 'Provjeri';
 $strCheckTable = 'Provjeri tablicu';
 $strChoosePage = 'Odaberite tablicu za uređivanje';
 $strColComFeat = 'Prikazivanje stupca komentara';
@@ -144,7 +145,7 @@ $strCollation = 'Uspoređivanje';
 $strColumnNames = 'Nazivi stupaca';
 $strColumnPrivileges = 'Privilegije specifične za stupac';
 $strCommand = 'Naredba';
-$strCommentsForTable = 'COMMENTS FOR TABLE';
+$strComment = 'Komentar';
 $strComments = 'Komentari';
 $strCompatibleHashing = 'MySQL&nbsp;4.0 kompatibilno';
 $strCompleteInserts = 'Dovrši umetanja';
@@ -173,7 +174,7 @@ $strCreateNewDatabase = 'Izradi novu bazu podataka';
 $strCreateNewTable = 'Izradi novu tablicu u bazi podataka %s';
 $strCreatePage = 'Izradi novu stranicu';
 $strCreatePdfFeat = 'Izrada PDF datoteka';
-$strCreateRelation = 'Izradi povezanost';
+$strCreateRelation = 'Izradi relaciju';
 $strCreateTable  = 'Izradi tablicu';
 $strCreateUserDatabase = 'Baza podataka za korisnika';
 $strCreateUserDatabaseName = 'Izradi bazu podataka istog naziva i podari sve privilegije';
@@ -183,6 +184,7 @@ $strCreationDates = 'Izrada/Ažuriranje/Provjera datuma';
 $strCriteria = 'Kriterij';
 $strCroatian = 'Hrvatski';
 $strCSV = 'CSV';
+$strCustomColor = 'Prilagođena boja';
 $strCyrillic = 'Ćirilica';
 $strCzech = 'Češki';
 $strCzechSlovak = 'Češki ili Slovački';
@@ -191,6 +193,7 @@ $strDanish = 'Danski';
 $strDatabase = 'Baza podataka';
 $strDatabaseEmpty = 'Naziv baze podataka je prazan!';
 $strDatabaseExportOptions = 'Opcije izvoza baze podataka';
+$strDatabaseHasBeenCreated = 'Baza podataka %1$s uspješno je izrađena.';
 $strDatabaseHasBeenDropped = 'Baza podataka %s je odbačena.';
 $strDatabases = 'Baze podataka';
 $strDatabasesDropped = 'Baza podataka %s uspješno je odbačena.';
@@ -216,17 +219,17 @@ $strDelayedInserts = 'Upotrijebi odgođena umetanja';
 $strDeleteAndFlushDescr = 'Ovo je najčišći način, ali ponovno učitavanje privilegija može potrajati.';
 $strDeleteAndFlush = 'Izbriši korisnike i potom ponovo učitaj privilegije.';
 $strDeleted = 'Redak je izbrisan';
-$strDeletedRows = 'Izbrisani redovi:';
 $strDelete = 'Izbriši';
 $strDeleteNoUsersSelected = 'Nema odabranih korisnika za uklanjanje!';
-$strDeleteRelation = 'Izbriši povezanost';
+$strDeleteRelation = 'Izbriši relaciju';
 $strDeleting = 'Brisanje %s';
 $strDelimiter = 'Razgraničavanje';
 $strDelOld = 'Trenutna stranica sadrži reference prema tablicama koje više ne postoje. Želite li izbrisati te reference?';
 $strDescending = 'Silazno';
 $strDescription = 'Opis';
-$strDesignerHelpDisplayField = 'Polje pregledavanja prikazano je u rozoj boji. Kako biste za polje odabrali ili uklonili opciju polja za prikazivanje kliknite ikonu "Odaberite polje za prikazivanje", a zatim kliknite odgovarajući naziv polja.';
+$strDesignerHelpDisplayField = 'Polje pregledavanja prikazano je u rozoj boji. Kako biste za polje odabrali ili uklonili opciju polja za prikazivanje pritisnite ikonu "Odaberite polje za prikazivanje", a zatim pritisnite odgovarajući naziv polja.';
 $strDesigner = 'Kreator';
+$strDetails = 'Detalji...';
 $strDictionary = 'rječnik';
 $strDirectLinks = 'Izravne veze';
 $strDirtyPages = 'Prljave stranice';
@@ -266,14 +269,15 @@ $strEnglish = 'Engleski';
 $strEnglishPrivileges = ' Napomena: Nazivi MySQL privilegija navedeni su na engleskom jeziku ';
 $strErrorInZipFile = 'Pogreška u ZIP arhivi:';
 $strError = 'Pogreška';
-$strErrorRelationAdded = 'Pogreška: Povezanost nije dodana.';
-$strErrorRelationExists = 'Pogreška: Povezanost već postoji.';
+$strErrorRelationAdded = 'Pogreška: Relacija nije dodana.';
+$strErrorRelationExists = 'Pogreška: Relacija već postoji.';
 $strErrorRenamingTable = 'Pogreška tijekom preimenovanja tablice %1$s u %2$s';
 $strErrorSaveTable = 'Pogreška tijekom spremanja koordinata za Kreatora.';
-$strEscapeWildcards = 'Da bi mogli biti upotrebljavani u doslovnom smislu, džokerima \_ i \% mora prethoditi znak \\';
+$strEscapeWildcards = 'Kako bi se mogli upotrebljavati u doslovnom smislu, džokerima \_ i \% mora prethoditi znak \\';
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estonski';
 $strEvent = 'Događaj';
+$strEvents = 'Događaji';
 $strExcelEdition = 'Excel izdanje';
 $strExecuteBookmarked = 'Izvrši favorizirani upit';
 $strExplain = 'Objasni SQL';
@@ -307,7 +311,8 @@ $strFlushQueryCache = 'Isprazni pohranu upita';
 $strFlushTable = 'Isprazni tablicu ("FLUSH")';
 $strFlushTables = 'Isprazni (zatvori) sve tablice';
 $strFontSize = 'Veličina fonta';
-$strForeignKeyError = 'Pogreška tijekom izrade stranog ključa (provjerite vrste podataka)';
+$strForeignKeyError = 'Pogreška tijekom izrade stranog ključa na %1$s (provjerite vrste podataka)';
+$strForeignKeyRelationAdded = 'Dodana je relacija FOREIGN KEY';
 $strFormat = 'Oblikovanje';
 $strFormEmpty = 'U obrascu nedostaje vrijednost!';
 $strFreePages = 'Slobodne stranice';
@@ -332,14 +337,13 @@ $strGzip = '"gzipano"';
 
 $strHandler = 'Hvatišta';
 $strHasBeenAltered = 'izmijenjeno je.';
-$strHasBeenCreated = 'izrađeno je.';
 $strHaveToShow = 'Morate odabrati najmanje jedan stupac za prikazivanje';
 $strHebrew = 'Hebrejski';
 $strHelp = 'Pomoć';
 $strHexForBLOB = 'Za BLOB upotrijebi heksadecimalno';
 $strHide         = 'Sakrij';
 $strHideShowAll = 'Prikaži / Sakrij sve';
-$strHideShowNoRelation = 'Prikaži / Sakrij tablice bez povezanosti';
+$strHideShowNoRelation = 'Prikaži / Sakrij tablice bez relacija';
 $strHomepageOfficial = 'Službena stranica programa phpMyAdmin';
 $strHome = 'Početna stranica';
 $strHostEmpty = 'Naziv računala je prazan!';
@@ -361,7 +365,7 @@ $strImportFormat = 'Oblikovanje uvezene datoteke';
 $strImportSuccessfullyFinished = 'Uvoz je uspješno dovršen. Izvršeno upita: %d .';
 $strImport = 'Uvoz';
 $strIndexes = 'Indeksi';
-$strIndexesSeemEqual = 'Sljedeći indeksi izgledaju jednakim i jednog je potrebno ukloniti:';
+$strIndexesSeemEqual = 'Indeksi %1$s i %2$s izgledaju jednakim i jednog od njih moguće je ukloniti.';
 $strIndexHasBeenDropped = 'Index %s je odbačen';
 $strIndex = 'Indeks';
 $strIndexName = 'Naziv indeksa:';
@@ -375,15 +379,14 @@ $strInnoDBDataFilePath = 'Podatkovne datoteke';
 $strInnoDBDataHomeDirDesc = 'Uobičajeni dio putanje mapa za sve InnoDB podatkovne datoteke.';
 $strInnoDBDataHomeDir = 'Osnovna mapa podataka';
 $strInnoDBPages = 'stranice';
-$strInnoDBRelationAdded = 'Dodana InnoDB povezanosti';
 $strInnodbStat = 'InnoDB stanje';
 $strInsecureMySQL = 'Vaša konfiguracijska datoteka sadrži postavke (root korisnik bez lozinke) koja odgovara zadanom privilegiranom nalogu MySQL-a. Vaš MySQL poslužitelj pokrenut je sa zadanim postavkama i kao takav otvoren je upadima. Potrebno je ispraviti ovaj sigurnosni nedostatak.';
 $strInsertAsNewRow = 'Umetni kao novi redak';
-$strInsertedRowId = 'ID umetnutog retka:';
-$strInsertedRows = 'Umetnuti redovi:';
+$strInsertedRowId = 'Umetnut ID retka: %1$d';
 $strInsert = 'Umetni';
-$strInternalNotNecessary = '* Interna relacija nije potrebna ako također postoji unutar InnoDB.';
-$strInternalRelationAdded = 'Dodane interne povezanosti';
+$strInterface = 'Sučelje';
+$strInternalAndForeign = 'Interna relacija nije potrebna ako postoji odgovarajuća relacija FOREIGN KEY.';
+$strInternalRelationAdded = 'Dodane interne relacije';
 $strInternalRelations = 'Interne relacije';
 $strInUse = 'u upotrebi';
 $strInvalidAuthMethod = 'Neispravan komplet načina provjere vjerodostojnosti u konfiguraciji:';
@@ -455,7 +458,7 @@ $strMIME_available_transform = 'Raspoloživa preoblikovanja';
 $strMIME_description = 'Opis';
 $strMIME_MIMEtype = 'MIME vrsta';
 $strMIME_nodescription = 'Za ovo preoblikovanje ne postoji raspoloživ opis.<br />Molimo da od autora zatražite objašnjenje rada %s .';
-$strMIME_transformation_note = 'Za popis raspoloživih opcija preoblikovanja i njihovih MIME vrsta oblikovanja, kliknite %sopcije preoblikovanja%s';
+$strMIME_transformation_note = 'Za popis raspoloživih opcija preoblikovanja i njihovih MIME vrsta oblikovanja, pritisnite %sopcije preoblikovanja%s';
 $strMIME_transformation_options_note = 'Unesite vrijednosti za opcije preoblikovanja upotrebom ovog oblika: \'a\', 100, b,\'c\'...<br />Ako je potrebno unijeti lijevu kosu crtu ("\") ili jednostruki navodnik ("\'") unutar ovih vrijednosti, ispred znaka stavite lijevu kosu crtu (na primjer: \'\\\\xyz\' ili \'a\\\'B\').';
 $strMIME_transformation_options = 'Opcije preoblikovanja';
 $strMIME_transformation = 'Pretvaranje preglednika';
@@ -487,8 +490,6 @@ $strMySQLConnectionCollation = 'MySQL uspoređivanje veza';
 $strMysqlLibDiffersServerVersion = 'Verzija %s vaše PHP MySQL biblioteke razlikuje se oda vaše verzije %s MySQL poslužitelja. Ovo bi moglo prouzrokovati nepredviđeno ponašanje.';
 $strMySQLSaid = 'MySQL je poručio:  ';
 $strMySQLShowProcess = 'Prikaži procese';
-$strMySQLShowStatus = 'Prikaži podatke MySQL pokretanja';
-$strMySQLShowVars = 'Prikaži MySQL sistemske varijable';
 
 $strName = 'Naziv';
 $strNext = 'Sljedeće';
@@ -535,22 +536,52 @@ $strOpenDocumentText = 'Otvori tekst dokumenta';
 $strOpenNewWindow = 'Otvori novi phpMyAdmin prozor';
 $strOperations = 'Operacije';
 $strOperator = 'Operator';
+$strOptimize = 'Optimiziraj';
 $strOptimizeTable = 'Optimiziraj tablicu';
 $strOptions = 'Opcije';
 $strOr = 'Ili';
 $strOverhead = 'Prepunjenje';
 $strOverwriteExisting = 'Prepiši postojeće datoteke';
 
+$strPacked = 'Pakirano';
 $strPageNumber = 'Broj stranice:';
 $strPagesToBeFlushed = 'Stranice za pražnjenje';
 $strPaperSize = 'Veličina papira';
 $strPartialImport = 'Djelomičan uvoz';
 $strPartialText = 'Djelomični tekstovi';
+$strPartitionDefinition = 'Definicija PARTICIJE';
+$strPartitioned = 'particionirano';
+$strPartitionMaintenance = 'Održavanje particije';
+$strPartition = 'Particija %s';
 $strPasswordChanged = 'Lozinka za %s uspješno je promijenjena.';
 $strPasswordEmpty = 'Lozinka je prazna!';
 $strPasswordHashing = 'Izrada presjeka lozinke';
 $strPassword = 'Lozinka';
 $strPasswordNotSame = 'Lozinke se ne podudaraju!';
+$strPBXTCheckpointFrequencyDesc = 'Količina podataka zapisana u zapisnik transakcija prije izvođenja točke provjere. Zadana vrijednost je 24 MB.';
+$strPBXTCheckpointFrequency = 'Učestalost točke provjere';
+$strPBXTDataFileGrowSizeDesc = 'Veličina porasta rukovanim datotekama podataka (.xtr).';
+$strPBXTDataFileGrowSize = 'Veličina porasta datoteke podataka';
+$strPBXTDataLogThresholdDesc = 'Najveća dopuštena veličina datoteke zapisnika podataka. Zadana vrijednost je 64 MB. PBXT može izraditi najviše 32.000 zapisnika koje koriste sve tablice. Vrijednost ove varijable može se povećati kako bi se povećao ukupan broj podataka koji se mogu pohraniti u bazu podataka.';
+$strPBXTDataLogThreshold = 'Najveća veličina zapisnika podataka';
+$strPBXTGarbageThresholdDesc = 'Postotak otpada u datoteci zapisnika podataka prije sređivanja. Vrijednost može biti od 1 do 99. Zadana vrijednost je 50.';
+$strPBXTGarbageThreshold = 'Najveća veličina otpada';
+$strPBXTIndexCacheSizeDesc = 'Količina memorije dodijeljena međuspremniku indeksa. Zadana vrijednost je 32 MB. Ovdje dodijeljena memorija koristi se samo za međupohranjivanje stranica indeksa.';
+$strPBXTIndexCacheSize = 'Veličina pohrane indeksa';
+$strPBXTLogBufferSizeDesc = 'Veličina međuspremnika tijekom zapisivanja podataka zapisnika. Zadana vrijednost je 256 MB. Pogon dodjeljuje jedan međuspremnik po grani, ali samo ako je grana potrebna za zapisivanje zapisnika podataka.';
+$strPBXTLogBufferSize = 'Veličina međuspremnika zapisnika';
+$strPBXTLogCacheSizeDesc = 'Količina memorije dodijeljena međuspremniku zapisnika transakcija. Zadana vrijednost je 16 MB.';
+$strPBXTLogCacheSize = 'Veličina pohrane zapisnika';
+$strPBXTLogFileCountDesc = 'Broj datoteka zapisnika transakcija (pbxt/system/xlog*.xt) koje će sustav održavati. Ako broj zapisnika premašuje ovu vrijednost, stari zapisnici bit će izbrisani. U protivnom se preimenuju i daje im se sljedeći veći redni broj.';
+$strPBXTLogFileCount = 'Najveći broj datoteka zapisnika';
+$strPBXTLogFileThresholdDesc = 'Veličina zapisnika transakcija prije povrata i izrade novog zapisnika. Zadana vrijednost je 16 MB.';
+$strPBXTLogFileThreshold = 'Najveća veličina datoteke zapisnika';
+$strPBXTRecordCacheSizeDesc = 'Količina memorije dodijeljena međuspremniku zapisnika koja se koristi za međuspremanje podataka tablice. Zadana vrijednost je 32 MB. Ova se memorija upotrebljava za međuspremanje izmjena u datotekama rukovanim podacima (.xtd) pokazivača retka (.xtr).';
+$strPBXTRecordCacheSize = 'Veličina pohrane zapisa';
+$strPBXTRowFileGrowSizeDesc = 'Veličina porasta datoteka pokazivača retka (.xtr).';
+$strPBXTRowFileGrowSize = 'Veličina porasta datoteke redaka';
+$strPBXTTransactionBufferSizeDesc = 'Veličina globalnog međuspremnika zapisnika transakcija (pogon dodjeljuje 2 međuspremnika ove veličine). Zadana vrijednost je 1 MB.';
+$strPBXTTransactionBufferSize = 'Veličina međuspremnika transakcije';
 $strPdfDbSchema = 'Shema "%s" baza podataka - stranica %s';
 $strPdfInvalidTblName = 'Tablica "%s" ne postoji!';
 $strPdfNoTables = 'Nema tablica';
@@ -562,13 +593,12 @@ $strPerMinute = 'po minuti';
 $strPerSecond = 'po sekundi';
 $strPersian = 'Perzijski';
 $strPhoneBook = 'telefonski imenik';
-$strPHP40203 = 'Upotrebljavate PHP 4.2.3 koji ima ozbiljne poteškoće s nizovima od višestrukih bajtova (mbstring). Pogledajte PHP izvještaj o nedostatku 19404. Ne preporučuje se upotreba ove verzije PHP-a uz program phpMyAdmin.';
+$strPHPExtension = 'PHP ekstenzija';
 $strPhp = 'Izradi PHP kod';
 $strPHPVersion = 'PHP verzija';
 $strPleaseSelectPrimaryOrUniqueKey = 'Odaberite primarni ključ ili jedinstveni ključ';
 $strPmaDocumentation = 'phpMyAdmin dokumentacija';
 $strPmaUriError = 'Direktiva <tt>$cfg[\'PmaAbsoluteUri\']</tt> MORA BITI postavljena u vašoj konfiguracijskoj datoteci!';
-$strPmaWiki = 'phpMyAdmin wiki';
 $strPolish = 'Poljski';
 $strPortrait = 'Portret';
 $strPos1 = 'Na vrh stranice';
@@ -592,6 +622,7 @@ $strPrivDescCreateView = 'Dopušta izradu novih prikaza.';
 $strPrivDescDelete = 'Dopušta brisanje podataka.';
 $strPrivDescDropDb = 'Dopušta odbacivanje baza podataka i tablica.';
 $strPrivDescDropTbl = 'Dopušta odbacivanje tablica.';
+$strPrivDescEvent = 'Omogućuje postavljanje događaja za planer';
 $strPrivDescExecute5 = 'Dopušta pokretanje pohranjenih rutina.';
 $strPrivDescExecute = 'Dopušta izvršavanje pohranjenih postupaka. Nema učinka u ovoj verziji MySQL-a.';
 $strPrivDescFile = 'Dopušta uvoz i izvoz podataka iz datoteka.';
@@ -603,8 +634,7 @@ $strPrivDescMaxConnections = 'Ograničava broj novih povezivanja koje korisnik m
 $strPrivDescMaxQuestions = 'Ograničava broj upita koje korisnik može poslati poslužitelju, po satu.';
 $strPrivDescMaxUpdates = 'Ograničava broj naredbi koje korisnik može pokrenuti, a čija je namjena mijenjanje bilo koje tablice ili baze podataka, po satu.';
 $strPrivDescMaxUserConnections = 'Ograničava broj istovremenih povezivanja koje korisnik može imati.';
-$strPrivDescProcess3 = 'Dopušta eliminiranje postupaka drugih korisnika.';
-$strPrivDescProcess4 = 'Dopušta pregledavanje cjelokupnih upita u popisu postupaka.';
+$strPrivDescProcess = 'Omogućuje pregledavanje procesa za sve korisnike';
 $strPrivDescReferences = 'Nema učinka u ovoj verziji MySQL-a.';
 $strPrivDescReload = 'Dopušta ponovno učitavanje postavki poslužitelja i pražnjenje privremene pohrane poslužitelja.';
 $strPrivDescReplClient = 'Dopušta korisnik postavljanje upita o lokaciji potčinjenih i gospodara.';
@@ -614,6 +644,7 @@ $strPrivDescShowDb = 'Daje pristup cjelokupnom popisu baza podataka.';
 $strPrivDescShowView = 'Dopušta izvođenje upita SHOW CREATE VIEW.';
 $strPrivDescShutdown = 'Dopušta gašenje poslužitelja.';
 $strPrivDescSuper = 'Dopušta povezivanje čak i kad je dostignut najveći broj veza. Potrebno za većinu administrativnih operacija poput postavljanja općih varijabli ili eliminiranje grana drugih korisnika.';
+$strPrivDescTrigger = 'Omogućuje izradu i uklanjanje okidača';
 $strPrivDescUpdate = 'Dopušta mijenjanje podataka.';
 $strPrivDescUsage = 'Bez privilegija.';
 $strPrivileges = 'Privilegije';
@@ -639,24 +670,29 @@ $strQueryType = 'Vrsta upita';
 $strQueryWindowLock = 'Ne prepisuj ovaj upit iz vanjskog prozora';
 
 $strReadRequests = 'Pročitaj zahtjeve';
+$strRebuild = 'Ponovno izgradi';
 $strReceived = 'Primljeno';
 $strRecommended = 'preporučeno';
 $strRecords = 'Zapisi';
 $strReferentialIntegrity = 'Provjeri referencijalan integritet:';
 $strRefresh = 'Osvježi';
+$strRelationalDisplayField = 'Polje za prikaz relacija';
+$strRelationalKey = 'Relacijski ključ';
 $strRelationalSchema = 'Shema relacija';
-$strRelationDeleted = 'Povezanost je izbrisana';
-$strRelationNotWorking = 'Dodatne osobine za rad s povezanim tablicama su isključene. Da biste saznali zašto kliknite %sovdje%s.';
+$strRelationDeleted = 'Relacija je izbrisana';
+$strRelationNotWorking = 'Dodatne osobine za rad s relacijski tablicama su isključene. Kako biste saznali razloge, pritisnite %sovdje%s.';
 $strRelationsForTable = 'RELACIJE TABLICE';
 $strRelations = 'Relacije';
 $strRelationView = 'Prikaz relacija';
 $strReloadingThePrivileges = 'Ponovno učitavanje privilegija';
 $strReload = 'Osvježi';
 $strReloadPrivileges = 'Ponovno učitaj privilegije';
+$strRemovePartitioning = 'Ukloni particioniranje';
 $strRemoveSelectedUsers = 'Ukloni odabrane korisnike';
 $strRenameDatabaseOK = 'Baza podataka %s preimenovana je u %s';
 $strRenameTableOK = 'Tablica %s preimenovana je u %s';
 $strRenameTable = 'Preimenuj tablicu u';
+$strRepair = 'Popravi';
 $strRepairTable = 'Popravi tablicu';
 $strReplaceNULLBy = 'NULL zamijeni s';
 $strReplaceTable = 'Podatke tablice zamijeni datotekom';
@@ -673,7 +709,10 @@ $strRomanian = 'Rumunjski';
 $strRoutineReturnType = 'Vrsta povratka';
 $strRoutines = 'Rutine';
 $strRowLength = 'Duljina retka';
+$strRowsAffected = 'Zahvaćeno redaka: %1$d.';
+$strRowsDeleted = 'Izbrisano redaka: %1$d.';
 $strRowsFrom = 'redovi koji započinju zapisom #';
+$strRowsInserted = 'Umetnuto redaka: %1$d.';
 $strRowSize = ' Veličina retka ';
 $strRowsModeFlippedHorizontal = 'vodoravno (okrenuta zaglavlja)';
 $strRowsModeHorizontal = 'vodoravno';
@@ -690,8 +729,9 @@ $strRussian = 'Ruski';
 $strSaveOnServer = 'Spremi na poslužitelju u mapi %s';
 $strSavePosition = 'Spremi položaj';
 $strSave = 'Spremi';
-$strScaleFactorSmall = 'Vrijednost omjera suviše je malen da bi shema stala na jednu stranicu';
+$strScaleFactorSmall = 'Vrijednost omjera suviše je malen kako bi shema stala na jednu stranicu';
 $strSearchFormTitle = 'Traži u bazi podataka';
+$strSearchInField = 'Unutar polja:';
 $strSearchInTables = 'Unutar tablica:';
 $strSearchNeedle = 'Riječi ili vrijednost za pretraživanje (džoker: "%"):';
 $strSearchOption1 = 'najmanje jedna riječ';
@@ -743,7 +783,7 @@ $strShowSlaveHosts = 'Prikaži potčinjena računala';
 $strShowSlaveStatus = 'Prikaži stanje potčinjenog';
 $strShowStatusBinlog_cache_disk_useDescr = 'Broj transakcija koje su upotrebljavale privremeni binarni zapisnik pohrane, ali su nadmašile vrijednost binlog_cache_size i upotrijebile privremenu datoteku za pohranjivanje izjava transakcija.';
 $strShowStatusBinlog_cache_useDescr = 'Broj transakcija koje su upotrebljavale privremeni binarni zapisnik pohrane.';
-$strShowStatusCreated_tmp_disk_tablesDescr = 'Broj privremenih tablica koje poslužitelj automatski izrađuje na disku tijekom izvršavanja izjava. Ako je stavka Created_tmp_disk_tables velika, moglo bi biti potrebno da povećate vrijednost tmp_table_size, da biste privremene tablice smjestili u radnu memoriju, a ne na tvrdi disk.';
+$strShowStatusCreated_tmp_disk_tablesDescr = 'Broj privremenih tablica koje poslužitelj automatski izrađuje na disku tijekom izvršavanja izjava. Ako je stavka Created_tmp_disk_tables velika, moglo bi biti potrebno da povećate vrijednost tmp_table_size, kako biste privremene tablice smjestili u radnu memoriju, a ne na tvrdi disk.';
 $strShowStatusCreated_tmp_filesDescr = 'Koliko je privremenih tablica izradio mysqld.';
 $strShowStatusCreated_tmp_tablesDescr = 'Broj privremenih tablica u memoriji koje je poslužitelj automatski izradio tijekom izvršavanja izjava.';
 $strShowStatusDelayed_errorsDescr = 'Broj redaka upisanih pomoću naredbe INSERT DELAYED, a kod kojih je došlo do neke vrste pogreške (vjerojatan razlog je udvojen ključ).';
@@ -895,14 +935,17 @@ $strStructureForView = 'Struktura za pregledavanje';
 $strStructure = 'Strukturu';
 $strSubmit = 'Podnesi';
 $strSuccess = 'Vaš SQL upit uspješno je izvršen';
+$strSuhosin = 'Poslužitelj pokrenut sa Suhosin. Proučite %sdokumentaciju%s radi mogućih problema.';
 $strSum = 'Zbroj';
 $strSwedish = 'Švedski';
 $strSwitchToDatabase = 'Prebaci se na kopiranu bazu podataka';
 $strSwitchToTable = 'Prebaci se na kopiranu tablicu';
 
 $strTableAlreadyExists = 'Tablica %s već postoji!';
+$strTableAlteredSuccessfully = 'Tablica %1$s uspješno je izmijenjena.';
 $strTableComments = 'Komentari tablice';
 $strTableEmpty = 'Naziv tablice je prazan!';
+$strTableHasBeenCreated = 'Tablica %1$s je izrađena.';
 $strTableHasBeenDropped = 'Tablica %s je odbačen';
 $strTableHasBeenEmptied = 'Tablica %s je očišćena';
 $strTableHasBeenFlushed = 'Tablica %s je ispražnjena';
@@ -918,6 +961,7 @@ $strTakeIt = 'Dodijeli';
 $strTblPrivileges = 'Privilegije specifične za tablicu';
 $strTempData = 'Privremeni podaci';
 $strTextAreaLength = ' Zbog svoje duljine,<br /> uređivanje ovog polja možda neće biti moguće ';
+$strTexyText = 'Texy! tekst';
 $strThai = 'Thai';
 $strThemeDefaultNotFound = 'Zadana tema %s nije pronađena!';
 $strThemeNoPreviewAvailable = 'Nema raspoloživog pregleda.';
@@ -935,16 +979,16 @@ $strTime = 'Vrijeme';
 $strToFromPage = 'stranica od / prema';
 $strToggleScratchboard = 'Uključi bilješke';
 $strToggleSmallBig = 'Malo / Veliko';
-$strToSelectRelation = 'Za odabir povezanosti kliknite:';
+$strToSelectRelation = 'Za odabir relacije pritisnite:';
 $strTotalUC = 'Ukupno';
 $strTotal = 'ukupno';
 $strTraditionalChinese = 'Kineski, tradicionalan';
 $strTraditionalSpanish = 'Španjolski, tradicionalan';
 $strTraffic = 'Promet';
 $strTransactionCoordinator = 'Koordinator transakcije';
-$strTransformation_application_octetstream__download = 'Prikazuje vezu prema preuzimanju binarnih podataka polja. Možete upotrijebiti prvu opciju da biste sami odredili naziv datoteke ili drugu opciju da biste upotrijebili naziv polja koje sadrži naziv datoteke. Ako upotrijebite drugu opciju, u prvu opciju morate unijeti prazan niz.';
+$strTransformation_application_octetstream__download = 'Prikazuje vezu prema preuzimanju binarnih podataka polja. Možete upotrijebiti prvu opciju kako biste sami odredili naziv datoteke ili drugu opciju kako biste upotrijebili naziv polja koje sadrži naziv datoteke. Ako upotrijebite drugu opciju, u prvu opciju morate unijeti prazan niz.';
 $strTransformation_application_octetstream__hex = 'Prikazuje podatke u heksadecimalnom obliku. Opcionalan prvi parametar određuje koliko često će prazna mjesta biti dodavana (zadana vrijednost je 2).';
-$strTransformation_image_jpeg__inline = 'Prikazuje sličicu s mogućnošću klikanja. Opcije su najveća širina i visina u pikselima. Izvorne proporcije su očuvane.';
+$strTransformation_image_jpeg__inline = 'Prikazuje sličicu s mogućnošću pritiskanja. Opcije su najveća širina i visina u pikselima. Izvorne proporcije su očuvane.';
 $strTransformation_image_jpeg__link = 'Prikazuje vezu za preuzimanje ove slike.';
 $strTransformation_image_png__inline = 'Pogledajte slika/jpeg: inline';
 $strTransformation_text_plain__dateformat = 'Polja TIME (vrijeme), TIMESTAMP (vremenska oznaka), DATETIME (datum i vrijeme) ili brojčanu uniksoidnu oznaku vremena prikazuje kao oblikovani datum. Prva opcija je odmak (u satima) koji će biti pridodan vremenskoj oznaci (zadano: 0). Druga opcije određuje drukčiji oblik izražavanja datuma i vremena. Treća opcija određuje želite li prikazati lokalni datum ili u skladu s UTC (upotrijebite izraz "local" ili "utc"). Sukladno tome, oblik datuma ima različite vrijednosti - za opciju "local" pogledajte dokumentaciju o upotrebi PHP funkcije strftime(), a za "utc" pogledajte dokumentaciju o upotrebi funkcije gmdate().';
@@ -982,7 +1026,6 @@ $strUploadLimit = 'Vjerojatno ste pokušali s učitavanjem prevelike datoteke. P
 $strUploadsNotAllowed = 'Učitavanje datoteka nije dopušteno na ovom poslužitelju.';
 $strUsage = 'Upotreba';
 $strUseBackquotes = 'Unesi nazive tablica i polja sa stražnjim navodnicima';
-$strUsedPhpExtensions = 'Upotrijebljena PHP proširenja';
 $strUseHostTable = 'Upotrijebi tablicu poslužitelja';
 $strUserAlreadyExists = 'Korisnik %s već postoji!';
 $strUserEmpty = 'Korisničko ime je prazno!';
@@ -1005,15 +1048,17 @@ $strVersionInformation = 'Podaci o verziji';
 $strViewDumpDatabases = 'Prikaži ispis (shemu) baza podataka';
 $strViewDumpDB = 'Prikaži ispis (shemu) baze podataka';
 $strViewDump = 'Prikaži ispis (shemu) tablice';
+$strViewHasAtLeast = 'Ovaj prikaz sadrži najmanje ovoliko redaka. Proučite %sdokumentaciju%s.';
 $strViewHasBeenDropped = 'Index %s je ispušten';
-$strViewMaxExactCount = 'Ovaj prikaz sadrži više od %s redaka. Pogledajte %sdokumentaciju%s.';
 $strViewName = 'Naziv prikaza';
 $strView = 'Prikaz';
 
 $strWebServerUploadDirectoryError = 'Mapu koju ste odabrali za potrebe učitavanja nije moguće dohvatiti';
 $strWebServerUploadDirectory = 'mapa učitavanja web poslužitelja';
+$strWebServer = 'Web poslužitelj';
 $strWelcome = 'Dobro došli u %s';
 $strWestEuropean = 'Zapadno europski';
+$strWiki = 'Wiki';
 $strWildcard = 'džoker';
 $strWindowNotFound = 'Ciljani prozor preglednika nije bilo moguće osvježiti. Možda ste zatvorili nadređeni prozor ili su postavke sigurnosti vašeg preglednika konfigurirane za blokiranje ažuriranja preko više prozora.';
 $strWithChecked = 'S odabirom:';
