@@ -1,5 +1,5 @@
 <?php
-/* $Id: french-utf-8.inc.php 10490 2007-07-16 13:08:28Z lem9 $ */
+/* $Id: french-utf-8.inc.php 11652 2008-10-18 14:54:47Z lem9 $ */
 
 $charset = 'utf-8';
 $allow_recoding = TRUE;
@@ -24,6 +24,7 @@ $strAccessDenied = 'Accès refusé';
 $strAccessDeniedCreateConfig = 'La raison probable est que vous n\'avez pas créé de fichier de configuration. Vous pouvez utiliser le %1$sscript de configuration%2$s dans ce but.';
 $strAccessDeniedExplanation = 'phpMyAdmin a tenté de se connecter au serveur MySQL, et le serveur a rejeté la connexion. Veuillez vérifier les valeurs de "host", "username" et "password" dans votre configuration et vous assurer qu\'elles correspondent aux informations fournies par l\'administrateur du serveur MySQL.';
 $strAction = 'Action';
+$strActions = 'Actions';
 $strAddAutoIncrement = 'Inclure la valeur courante de l\'AUTO_INCREMENT';
 $strAddClause = 'Ajouter %s';
 $strAddConstraints = 'Inclure les contraintes de clés étrangères';
@@ -36,11 +37,10 @@ $strAddNewField = 'Ajouter un champ';
 $strAddPrivilegesOnDb = 'Ajouter des privilèges sur cette base de données';
 $strAddPrivilegesOnTbl = 'Ajouter des privilèges sur cette table';
 $strAddSearchConditions = 'Critères de recherche (pour l\'énoncé "where"):';
-$strAddToIndex = 'Ajouter à la clef&nbsp;%s&nbsp;colonne(s)';
+$strAddToIndex = 'Ajouter à l\'index&nbsp;%s&nbsp;colonne(s)';
 $strAddUser = 'Ajouter un utilisateur';
 $strAddUserMessage = 'Vous avez ajouté un utilisateur';
 $strAdministration = 'Administration';
-$strAffectedRows = 'Nombre d\'enregistrements affectés :';
 $strAfter = 'Après %s';
 $strAfterInsertBack = 'Retourner à la page précédente';
 $strAfterInsertNewInsert = 'Insérer un nouvel enregistrement';
@@ -50,6 +50,7 @@ $strAllowInterrupt = 'Permettre l\'interruption de l\'importation si la limite d
 $strAllTableSameWidth = 'Afficher toutes les tables avec une largeur identique';
 $strAll = 'Tout';
 $strAlterOrderBy = '<b>Ordonner</b> la table par';
+$strAnalyze = 'Analyser';
 $strAnalyzeTable = 'Analyser la table';
 $strAnd = 'et';
 $strAndThen = 'et ensuite';
@@ -63,6 +64,7 @@ $strAPrimaryKey = 'Une clé primaire a été ajoutée sur %s';
 $strArabic = 'arabe';
 $strArmenian = 'arménien';
 $strAscending = 'Croissant';
+$strAsDefined = 'Tel que défini :';
 $strAtBeginningOfTable = 'En début de table';
 $strAtEndOfTable = 'En fin de table';
 $strAttr = 'Attributs';
@@ -101,7 +103,6 @@ $strBufferWriteWaitsInPercent = 'Nombre d\'attentes d\'écriture en %';
 $strBufferWriteWaits = 'Nombre d\'attentes d\'écriture';
 $strBulgarian = 'bulgare';
 $strBusyPages = 'Pages occupées';
-$strBzError = 'phpMyAdmin n\'a pu compresser le fichier exporté en raison d\'une composante Bz2 défaillante dans cette version de PHP. Il est recommandé de donner à <code>$cfg[\'BZipDump\']</code> dans votre fichier de configuration phpMyAdmin la valeur <code>FALSE</code>. Si vous voulez utiliser la compression en mode Bz2, veuillez mettre à niveau votre version de PHP. Ce rapport d\'anomalies PHP donne les détails: %s.';
 $strBzip = '"bzippé"';
 
 $strCalendar = 'Calendrier';
@@ -111,7 +112,7 @@ $strCanNotLoadImportPlugins = 'Chargement impossible des greffons d\'importation
 $strCannotLogin = 'Connexion au serveur MySQL non permise';
 $strCantLoad = 'PHP ne peut charger l\'extension %s, [br]veuillez vérifier votre configuration de PHP';
 $strCantLoadRecodeIconv = 'Erreur lors du chargement de l\'extension iconv ou recode, utilisée pour convertir le jeu de caractères; veuillez activer l\'une de ces extensions dans PHP, ou désactiver la conversion des jeux de caractères dans phpMyAdmin';
-$strCantRenameIdxToPrimary = 'La clef ne peut être renommée PRIMARY&nbsp;!';
+$strCantRenameIdxToPrimary = 'La clé ne peut être renommée PRIMARY!';
 $strCantUseRecodeIconv = 'Erreur lors de l\'utilisation de iconv, libiconv et recode_string, alors que ces extensions semblent chargées. Veuillez vérifier votre configuration de PHP.';
 $strCardinality = 'Cardinalité';
 $strCaseInsensitive = 'insensible à la casse';
@@ -123,7 +124,7 @@ $strChangeCopyModeDeleteAndReload = ' ... supprimer l\'ancien utilisateur, puis
 $strChangeCopyModeJustDelete = ' ... supprimer l\'ancien utilisateur.';
 $strChangeCopyModeRevoke = ' ... effacer tous les privilèges de l\'ancien utilisateur, puis l\'effacer.';
 $strChangeCopyUser = 'Changement des informations de connexion / Copie d\'utilisateur';
-$strChangeDisplay = 'Champ à afficher';
+$strChangeDisplay = 'Champ descriptif';
 $strChange = 'Modifier';
 $strChangePassword = 'Modifier le mot de passe';
 $strCharset = 'Jeu de caractères';
@@ -135,14 +136,15 @@ $strCheckOverhead = 'Cocher tables avec pertes';
 $strCheckPrivsLong = 'Vérifier les privilèges pour la base de données &quot;%s&quot;.';
 $strCheckPrivs = 'Vérifier les privilèges';
 $strCheckTable = 'Vérifier la table';
+$strCheck = 'Vérifier';
 $strChoosePage = 'Page à éditer';
 $strColComFeat = 'Commentaires de colonnes';
 $strCollation = 'Interclassement';
 $strColumnNames = 'Nom des colonnes';
 $strColumnPrivileges = 'Privilèges de colonnes';
 $strCommand = 'Commande';
+$strComment = 'Commentaire';
 $strComments = 'Commentaires';
-$strCommentsForTable = 'COMMENTAIRES POUR LA TABLE';
 $strCompatibleHashing = 'compatible MySQL&nbsp;4.0';
 $strCompleteInserts = 'Insertions complètes';
 $strCompression = 'Compression';
@@ -164,8 +166,8 @@ $strCopyTableSameNames = 'On ne peut copier la table sur elle-même!';
 $strCouldNotKill = 'phpMyAdmin n\'a pu éliminer le processus %s. Il était probablement déjà fermé.';
 $strCreate = 'Créer';
 $strCreateDatabaseBeforeCopying = 'Faire CREATE DATABASE avant la copie';
-$strCreateIndex = 'Créer une clef sur&nbsp;%s&nbsp;colonne(s)';
-$strCreateIndexTopic = 'Créer un nouvelle clef';
+$strCreateIndex = 'Créer un index sur&nbsp;%s&nbsp;colonne(s)';
+$strCreateIndexTopic = 'Créer un nouvel index';
 $strCreateNewDatabase = 'Créer une base de données';
 $strCreateNewTable = '<b>Créer une nouvelle table</b> sur la base %s';
 $strCreatePage = 'Créer une page';
@@ -180,6 +182,7 @@ $strCreationDates = 'Dates de création/modification/vérification';
 $strCriteria = 'Critère';
 $strCroatian = 'croate';
 $strCSV = 'CSV';
+$strCustomColor = 'Couleur au choix';
 $strCyrillic = 'cyrillique';
 $strCzechSlovak = 'tchèque-slovaque';
 $strCzech = 'tchèque';
@@ -188,6 +191,7 @@ $strDanish = 'danois';
 $strDatabase = 'Base de données';
 $strDatabaseEmpty = 'Le nom de la base de données est vide!';
 $strDatabaseExportOptions = 'Options d\'exportation';
+$strDatabaseHasBeenCreated = 'La base de données %1$s a été créée.';
 $strDatabaseHasBeenDropped = 'La base de données %s a été effacée.';
 $strDatabases = 'Bases de données';
 $strDatabasesDropped = '%s bases de données ont été supprimées.';
@@ -199,7 +203,7 @@ $strDataDict = 'Dictionnaire de données';
 $strData = 'Données';
 $strDataOnly = 'Données seulement';
 $strDataPages = 'Pages contenant des données';
-$strDBComment = '<b>Commentaire</b> sur la base de données: ';
+$strDBComment = 'Commentaire sur la base de données: ';
 $strDBCopy = 'Copier la base de données vers';
 $strDbIsEmpty = 'La base de données semble vide!';
 $strDbPrivileges = 'Privilèges spécifiques à une base de données';
@@ -213,7 +217,6 @@ $strDelayedInserts = 'Insertions avec délais (DELAYED)';
 $strDeleteAndFlushDescr = 'Ceci est la méthode la plus directe, mais le fait de recharger les privilèges pourrait prendre du temps.';
 $strDeleteAndFlush = 'Effacer les utilisateurs, puis recharger les privilèges.';
 $strDeleted = 'L\'enregistrement a été effacé';
-$strDeletedRows = 'Nombre d\'enregistrements effacés :';
 $strDelete = 'Effacer';
 $strDeleteNoUsersSelected = 'Aucun utilisateur n\'a été choisi en vue de le détruire!';
 $strDeleteRelation = 'Effacer la relation';
@@ -224,6 +227,7 @@ $strDescending = 'Décroissant';
 $strDescription = 'Description';
 $strDesigner = 'Concepteur';
 $strDesignerHelpDisplayField = 'Le champ à afficher est montré en rose. Pour indiquer qu\'un champ est ou n\'est plus le champ à afficher, cliquer l\'icône "Champ à afficher", puis cliquer sur le nom de champ approprié.';
+$strDetails = 'Détails...';
 $strDictionary = 'dictionnaire';
 $strDirectLinks = 'Liens directs';
 $strDirtyPages = 'Pages modifiées';
@@ -271,6 +275,7 @@ $strEscapeWildcards = 'Préfixer avec \ les passepartouts _ et % pour un usage l
 $strEsperanto = 'Espéranto';
 $strEstonian = 'estonien';
 $strEvent = 'Événement';
+$strEvents = 'Événements';
 $strExcelEdition = 'Excel en version';
 $strExecuteBookmarked = 'Exécuter la requête en signets';
 $strExplain = 'Expliquer SQL';
@@ -304,7 +309,8 @@ $strFlushQueryCache = 'Vider la cache des requêtes';
 $strFlushTable = 'Recharger la table ("FLUSH")';
 $strFlushTables = 'Fermer toutes les tables';
 $strFontSize = 'Taille du texte';
-$strForeignKeyError = 'Erreur lors de la création de la clé étrangère (vérifiez les types de données';
+$strForeignKeyError = 'Erreur lors de la création de la clé étrangère sur %1$s (vérifiez le type des colonnes)';
+$strForeignKeyRelationAdded = 'Relation de type FOREIGN KEY ajoutée';
 $strFormat = 'format';
 $strFormEmpty = 'Formulaire incomplet !';
 $strFreePages = 'Pages libres';
@@ -329,7 +335,6 @@ $strGzip = '"gzippé"';
 
 $strHandler = 'Gestionnaire';
 $strHasBeenAltered = 'a été modifié(e).';
-$strHasBeenCreated = 'a été créé(e).';
 $strHaveToShow = 'Vous devez choisir au moins une colonne à afficher';
 $strHebrew = 'hébreu';
 $strHelp = 'Aide';
@@ -338,7 +343,7 @@ $strHide         = 'Cacher';
 $strHideShowAll = 'Cacher/montrer tout';
 $strHideShowNoRelation = 'Cacher/montrer les tables sans liens';
 $strHome = 'Accueil';
-$strHomepageOfficial = 'Site officiel de phpMyAdmin';
+$strHomepageOfficial = 'Site officiel';
 $strHostEmpty = 'Le nom de serveur est vide';
 $strHost = 'Serveur';
 $strHTMLExcel = 'Microsoft Excel 2000';
@@ -358,11 +363,11 @@ $strImportFormat = 'Format du fichier d\'importation';
 $strImport = 'Importer';
 $strImportSuccessfullyFinished = 'L\'importation s\'est terminée avec succès, %d requêtes exécutées.';
 $strIndexes = 'Index';
-$strIndexesSeemEqual = 'Les index suivants semblent équivalents, vous devriez en éliminer un.';
+$strIndexesSeemEqual = 'Les index %1$s et %2$s semblent identiques et l\'un d\'eux pourrait être supprimé.'; 
 $strIndexHasBeenDropped = 'L\'index %s a été effacé';
 $strIndex = 'Index';
-$strIndexName = 'Nom de la clef&nbsp;:';
-$strIndexType = 'Type de clef&nbsp;:';
+$strIndexName = 'Nom de l\'index :';
+$strIndexType = 'Type d\'index :';
 $strIndexWarningTable = 'Il y a des problèmes avec les index de la table `%s`';
 $strInnoDBAutoextendIncrement = 'Auto-croissant: Taille de l\'incrément';
 $strInnoDBAutoextendIncrementDesc = 'La valeur de l\'incrément lors de l\'agrandissement du fichier auto-croissant lorsqu\'il devient plein.';
@@ -372,14 +377,13 @@ $strInnoDBDataFilePath = 'Fichiers de données';
 $strInnoDBDataHomeDirDesc = 'Le chemin du répertoire pour tous les fichiers de données InnoDB.';
 $strInnoDBDataHomeDir = 'Répertoire des données';
 $strInnoDBPages = 'pages';
-$strInnoDBRelationAdded = 'Relation InnoDB ajoutée';
 $strInnodbStat = 'État InnoDB';
 $strInsecureMySQL = 'Votre fichier de configuration fait référence à l\'utilisateur root sans mot de passe, ce qui correspond à la valeur par défaut de MySQL.  Votre serveur MySQL est donc ouvert aux intrusions, et vous devriez corriger ce problème de sécurité.';
 $strInsertAsNewRow = 'Sauvegarder un nouvel enregistrement';
-$strInsertedRowId = 'Identifiant de l\'enregistrement inséré:';
-$strInsertedRows = 'Nombre d\'enregistrements insérés :';
+$strInsertedRowId = 'Identifiant de l\'enregistrement inséré : %1$d';
 $strInsert = 'Insérer';
-$strInternalNotNecessary = '* Si une relation existe dans InnoDB, il n\'est pas nécessaire de la définir dans les relations internes.';
+$strInterface = 'Interface';
+$strInternalAndForeign = 'Une relation interne n\'est pas nécessaire lorsqu\'une clé correspondante de type FOREIGN KEY existe';
 $strInternalRelationAdded = 'Relation interne ajoutée';
 $strInternalRelations = 'Relations internes';
 $strInUse = 'utilisé';
@@ -406,7 +410,7 @@ $strJustDelete = 'Seulement effacer les utilisateurs des tables de privilèges.'
 
 $strKeepPass = 'Conserver le mot de passe';
 $strKeyCache = 'Cache des clés';
-$strKeyname = 'Nom de la clé';
+$strKeyname = 'Nom de l\'index';
 $strKill = 'Supprimer';
 $strKnownExternalBug = 'La fonctionnalité %s est affectée par une anomalie connue, voir %s';
 $strKorean = 'coréen';
@@ -439,7 +443,7 @@ $strLoginInformation = 'Information pour la connexion';
 $strLogout = 'Quitter';
 $strLogPassword = 'Mot de passe&nbsp;:';
 $strLogServer = 'Serveur';
-$strLogUsername = 'Nom d\'utilisateur&nbsp;:';
+$strLogUsername = 'Utilisateur&nbsp;:';
 $strLongOperation = 'Cette opération pourrait être longue. Procéder quand même? ';
 
 $strMaxConnects = 'max. de connexions simultanées';
@@ -459,7 +463,7 @@ $strMIME_transformation = 'Transformation';
 $strMIMETypesForTable = 'TYPES MIME POUR LA TABLE';
 $strMIME_without = 'Les types MIME affichées en italiques ne possèdent pas de fonctions de transformation.';
 $strModifications = 'Les modifications ont été sauvegardées.';
-$strModifyIndexTopic = 'Modifier une clef';
+$strModifyIndexTopic = 'Modifier un index';
 $strModify = 'Modifier';
 $strMoveMenu = 'Déplacer le menu';
 $strMoveTable = '<b>Déplacer</b> la table vers (base<b>.</b>table)&nbsp;:';
@@ -484,8 +488,6 @@ $strMySQLConnectionCollation = 'Interclassement pour la connexion MySQL';
 $strMysqlLibDiffersServerVersion = 'La version de votre bibliothèque MySQL (%s) diffère de la version de votre serveur MySQL (%s). Ceci peut occasionner un comportement imprévisible.';
 $strMySQLSaid = 'MySQL a répondu:';
 $strMySQLShowProcess = 'Afficher les processus';
-$strMySQLShowStatus = 'Afficher l\'état du serveur';
-$strMySQLShowVars = 'Afficher les variables du serveur';
 
 $strName = 'Nom';
 $strNext = 'Suivant';
@@ -499,8 +501,8 @@ $strNoDropDatabases = 'La commande "DROP DATABASE" est désactivée.';
 $strNoExplain = 'Ne pas expliquer SQL';
 $strNoFilesFoundInZip = 'Aucun fichier présent dans l\'archive ZIP!';
 $strNoFrames = 'L\'utilisation de phpMyAdmin est plus aisée avec un navigateur <b>supportant les "frames"</b>.';
-$strNoIndex = 'Aucune clef n\'est définie&nbsp;!';
-$strNoIndexPartsDefined = 'Aucune colonne n\'a été définie pour cette clef&nbsp;!';
+$strNoIndex = 'Aucun index n\'est défini!';
+$strNoIndexPartsDefined = 'Aucune colonne n\'a été définie pour cet index!';
 $strNoModification = 'Pas de modifications';
 $strNone = 'aucune';
 $strNo = 'Non';
@@ -532,22 +534,52 @@ $strOpenDocumentText = 'Texte "Open Document"';
 $strOpenNewWindow = 'Ouvrir une nouvelle fenêtre phpMyAdmin';
 $strOperations = 'Opérations';
 $strOperator = 'Opérateur';
+$strOptimize = 'Optimiser';
 $strOptimizeTable = 'Optimiser la table';
 $strOptions = 'Options';
 $strOr = 'Ou';
 $strOverhead = 'Perte';
 $strOverwriteExisting = 'Écraser les fichiers existants';
 
+$strPacked = 'Compressé';
 $strPageNumber = 'Page n°:';
 $strPagesToBeFlushed = 'Pages devant être vidées';
 $strPaperSize = 'Taille du papier';
 $strPartialImport = 'Importation partielle';
 $strPartialText = 'Textes réduits';
+$strPartitionDefinition = 'Définition de PARTITION';
+$strPartitioned = 'partitionné';
+$strPartitionMaintenance = 'Gestion des partitions';
+$strPartition = 'Partition %s';
 $strPasswordChanged = 'Le mot de passe de %s a été changé.';
 $strPasswordEmpty = 'Le mot de passe est vide';
 $strPasswordHashing = 'Hachage du mot de passe';
 $strPassword = 'Mot de passe';
 $strPasswordNotSame = 'Les mots de passe doivent être identiques';
+$strPBXTCheckpointFrequencyDesc = 'La quantité de données écrite au journal de transactions avant un point de contrôle (valeur par défaut de 24 Mio).';
+$strPBXTCheckpointFrequency = 'Fréquence des points de contrôle';
+$strPBXTDataFileGrowSizeDesc = 'La taille de l\'augmentation des fichiers pointeurs d\'enregistrements (.xtd).';
+$strPBXTDataFileGrowSize = 'Taille de l\'augmentation du fichier des données';
+$strPBXTDataLogThresholdDesc = 'La taille maximale d\'un fichier journal de données. Sa valeur par défaut est de 64 Mio. PBXT peut créer un maximum de 32000 journaux de données, utilisés par toutes les tables. Par conséquent cette variable peut être augmentée pour augmenter la quantité totale de données pouvant être stockée dans la base de données.';
+$strPBXTDataLogThreshold = 'Seuil du journal des données';
+$strPBXTGarbageThresholdDesc = 'Le pourcentage d\'information parasites dans un journal de données au-delà duquel il est comprimé. Il s\'agit d\'une valeur entre 1 et 99, par défaut 50.';
+$strPBXTGarbageThreshold = 'Seuil des informations parasites';
+$strPBXTIndexCacheSizeDesc = 'La quantité de mémoire allouée au cache des index (valeur par défaut de 32 Mio).';
+$strPBXTIndexCacheSize = 'Taille du cache d\'index';
+$strPBXTLogBufferSizeDesc = 'La taille du tampon utilisé lors de l\'écriture du journal (par défaut 256 Mio).';
+$strPBXTLogBufferSize = 'Taille du tampon du journal';
+$strPBXTLogCacheSizeDesc = 'La quantité de mémoire allouée au cache du journal des transactions (valeur par défaut de 16 Mio).';
+$strPBXTLogCacheSize = 'Taille du cache du journal';
+$strPBXTLogFileCountDesc = 'Le nombre de journaux de transactions (pbxt/system/xlog*.xt) conservés par le système. Si le nombre de journaux dépasse cette valeur, les journaux les plus anciens sont détruits, sinon ils sont renommés.';
+$strPBXTLogFileCount = 'Nombre de fichiers journal';
+$strPBXTLogFileThresholdDesc = 'La taille d\'un journal de transactions au-delà de laquelle un nouveau journal est créé (valeur par défaut de 16 Mio).';
+$strPBXTLogFileThreshold = 'Seuil du fichier journal';
+$strPBXTRecordCacheSizeDesc = 'La quantité de mémoire allouée au cache des enregistrements (valeur par défaut de 32 Mio). Utilisé pour le cache des changements aux fichiers de données (.xtd) et pointeurs (.xtr).';
+$strPBXTRecordCacheSize = 'Taille du cache des enregistrements';
+$strPBXTRowFileGrowSizeDesc = 'La taille de l\'augmentation des fichiers pointeurs d\'enregistrements (.xtr).';
+$strPBXTRowFileGrowSize = 'Taille d\'augmentation du fichier des enregistrements';
+$strPBXTTransactionBufferSizeDesc = 'La taille du tampon du journal global des transactions (deux tampons sont alloués). La valeur par défaut est de 1 Mio.';
+$strPBXTTransactionBufferSize = 'Taille du tampon des transactions';
 $strPdfDbSchema = 'Schema de la base "%s" - Page %s';
 $strPdfInvalidTblName = 'La table "%s" n\'existe pas !';
 $strPdfNoTables = 'Pas de table !';
@@ -559,20 +591,19 @@ $strPerMinute = 'par minute';
 $strPerSecond = 'par seconde';
 $strPersian = 'perse';
 $strPhoneBook = 'annuaire téléphonique';
-$strPHP40203 = 'Vous utilisez PHP 4.2.3, et cette version a un sérieux problème avec les caractères multi-octets (mbstring), tel que décrit sur le rapport d\'anomalies 19404 chez PHP.  Il n\'est pas recommandé d\'utiliser cette version de PHP avec phpMyAdmin.';
 $strPhp = 'Créer source PHP';
+$strPHPExtension = 'Extension PHP';
 $strPHPVersion = 'Version de PHP';
-$strPleaseSelectPrimaryOrUniqueKey = 'Veuillez choisir la clé primaire ou une clé unique';
+$strPleaseSelectPrimaryOrUniqueKey = 'Veuillez choisir la clé primaire ou un index unique';
 $strPmaDocumentation = 'Documentation de phpMyAdmin';
 $strPmaUriError = 'Le paramètre <tt>$cfg[\'PmaAbsoluteUri\']</tt> DOIT être renseigné dans votre fichier de configuration !';
-$strPmaWiki = 'Wiki phpMyAdmin';
 $strPolish = 'polonais';
 $strPortrait = 'Portrait';
 $strPos1 = 'Début';
 $strPrevious = 'Précédent';
 $strPrimaryKeyHasBeenDropped = 'La clé primaire a été effacée';
-$strPrimaryKeyName = 'Le nom d\'une clef primaire doit être PRIMARY&nbsp;!';
-$strPrimaryKeyWarning = '("PRIMARY" <b>doit et ne peut être</b> que le nom d\'une clef primaire&nbsp;!)';
+$strPrimaryKeyName = 'Le nom d\'une clé primaire doit être PRIMARY!';
+$strPrimaryKeyWarning = '("PRIMARY" <b>doit et ne peut être</b> que le nom d\'une clé primaire&nbsp;!)';
 $strPrimary = 'Primaire';
 $strPrint = 'Imprimer';
 $strPrintViewFull = 'Version imprimable (avec textes complets)';
@@ -589,6 +620,7 @@ $strPrivDescCreateView = 'Permission de créer des vues.';
 $strPrivDescDelete = 'Permission de détruire des données';
 $strPrivDescDropDb = 'Permission d\'effacer des bases de données et des tables.';
 $strPrivDescDropTbl = 'Permission d\'effacer des tables.';
+$strPrivDescEvent = 'Permission de mettre en place des événements pour le programmateur d\'événements';
 $strPrivDescExecute5 = 'Permission d\'exécuter des procédures stockées';
 $strPrivDescExecute = 'Permission d\'exécuter des procédures. Non effectif dans cette version de MySQL.';
 $strPrivDescFile = 'Permission d\'importer et d\'exporter des données à partir de / dans des fichiers.';
@@ -600,8 +632,7 @@ $strPrivDescMaxConnections = 'Limite du nombre de nouvelles connexions qu\'un ut
 $strPrivDescMaxQuestions = 'Limite du nombre de requêtes qu\'un utilisateur peut envoyer au serveur, par heure.';
 $strPrivDescMaxUpdates = 'Limite du nombre de commandes changeant une table ou base de données, qu\'un utilisateur peut exécuter, par heure.';
 $strPrivDescMaxUserConnections = 'Limite le nombre de connexions simultanées autorisées pour un utilisateur.';
-$strPrivDescProcess3 = 'Permission de détruire les processus de d\'autres utilisateurs.';
-$strPrivDescProcess4 = 'Permission de voir le texte complet des requêtes, dans la liste des processus.';
+$strPrivDescProcess = 'Permission de voir les processus de tous les utilisateurs';
 $strPrivDescReferences = 'Non effectif dans cette version de MySQL.';
 $strPrivDescReload = 'Permission de recharger les réglages du serveur, et de vidanger la mémoire cache.';
 $strPrivDescReplClient = 'Permission de demander où sont les maîtres et les esclaves (système de duplication).';
@@ -611,6 +642,7 @@ $strPrivDescShowDb = 'Permission de voir la liste complète des noms de bases de
 $strPrivDescShowView = 'Permission d\'exécuter SHOW CREATE VIEW.';
 $strPrivDescShutdown = 'Permission d\'arrêter le serveur MySQL.';
 $strPrivDescSuper = 'Permission de se connecter, même si le nombre maximal de connexions permises a été atteint; ceci est requis pour la plupart des opérations de type administratif, par exemple les changements de variables globales ou la destruction de processus.';
+$strPrivDescTrigger = 'Permission de créer et de supprimer des déclencheurs';
 $strPrivDescUpdate = 'Permission de changer des données.';
 $strPrivDescUsage = 'Pas de privilèges';
 $strPrivileges = 'Privilèges';
@@ -631,16 +663,19 @@ $strQueryOnDb = 'Requête SQL sur la base <b>%s</b>&nbsp;:';
 $strQueryResultsOperations = 'Opérations sur les résultats de la requête';
 $strQuerySQLHistory = 'Historique SQL';
 $strQueryStatistics = '<b>Statistiques sur les requêtes</b>: Depuis son démarrage, %s requêtes ont été envoyées au serveur.';
-$strQueryTime = 'traitement: %01.4f sec.';
+$strQueryTime = 'Traitement en %01.4f sec.';
 $strQueryType = 'Type de requête';
 $strQueryWindowLock = 'Ne pas écraser cette requête depuis une autre fenêtre';
 
 $strReadRequests = 'Requêtes de lecture';
+$strRebuild = 'Reconstruire';
 $strReceived = 'Reçu';
 $strRecommended = 'recommandé';
 $strRecords = 'Enregistrements';
 $strReferentialIntegrity = 'Vérifier l\'intégrité référentielle';
 $strRefresh = 'Actualiser';
+$strRelationalDisplayField = 'Relations : champs descriptifs';
+$strRelationalKey = 'Relations : clés';
 $strRelationalSchema = 'Schéma relationnel';
 $strRelationDeleted = 'Relation supprimée';
 $strRelationNotWorking = 'Certaines fonctionnalités ayant trait aux tables reliées sont désactivées. Pour une analyse du problème, cliquez %sici%s.';
@@ -650,15 +685,17 @@ $strRelationView = 'Gestion des relations';
 $strReloadingThePrivileges = 'Chargement des privilèges en cours.';
 $strReloadPrivileges = 'Recharger les privilèges';
 $strReload = 'Recharger';
+$strRemovePartitioning = 'Supprimer le partitionnement';
 $strRemoveSelectedUsers = 'Effacer les utilisateurs sélectionnés.';
 $strRenameDatabaseOK = 'La base de données %s a été renommée en %s';
 $strRenameTable = '<b>Changer le nom</b> de la table pour';
 $strRenameTableOK = 'La table %s se nomme maintenant %s';
+$strRepair = 'Réparer';
 $strRepairTable = 'Réparer la table';
 $strReplaceNULLBy = 'Remplacer NULL par';
 $strReplaceTable = 'Remplacer les données de la table avec le fichier';
 $strReplication = 'Réplication';
-$strReset = 'Réinitialiser les valeurs';
+$strReset = 'Réinitialiser';
 $strResourceLimits = 'Limites de ressources.';
 $strRestartInsertion = 'Recommencer l\'insertion avec %s lignes';
 $strReType = 'Entrer à nouveau';
@@ -670,8 +707,11 @@ $strRomanian = 'roumain';
 $strRoutineReturnType = 'Type retourné';
 $strRoutines = 'Procédures stockées';
 $strRowLength = 'Longueur enr.';
+$strRowsAffected = '%1$d enregistrement(s) affecté(s).';
+$strRowsDeleted = '%1$d enregistrement(s) supprimé(s).';
 $strRows = 'Enregistrements';
 $strRowsFrom = 'enregistrement(s) à partir de l\'enregistrement n°';
+$strRowsInserted = '%1$d enregistrement(s) inséré(s).';
 $strRowSize = ' Taille enr. ';
 $strRowsModeFlippedHorizontal = 'horizontal (en-têtes pivotés)';
 $strRowsModeHorizontal = 'horizontal';
@@ -689,6 +729,7 @@ $strSavePosition = 'Sauvegarder la position';
 $strSave = 'Sauvegarder';
 $strScaleFactorSmall = 'Veuillez augmenter l\'échelle car le schéma déborde la page';
 $strSearchFormTitle = 'Effectuer une nouvelle recherche dans la base de données';
+$strSearchInField = 'Dans la colonne:';
 $strSearchInTables = 'Dans la(les) table(s) :';
 $strSearchNeedle = 'Mot(s) ou Valeur à rechercher (passe-partout: "%") :';
 $strSearchOption1 = 'au moins un mot';
@@ -892,14 +933,17 @@ $strStructureForView = 'Structure de la vue';
 $strStructure = 'Structure';
 $strSubmit = 'Exécuter';
 $strSuccess = 'Votre requête SQL a été exécutée avec succès';
+$strSuhosin = 'Ce serveur utilise Suhosin. Veuillez vous référer à la %sdocumentation%s pour en connaître les conséquences possibles.';
 $strSum = 'Somme';
 $strSwedish = 'suédois';
 $strSwitchToDatabase = 'Aller à la base de données copiée';
 $strSwitchToTable = 'Aller à la table copiée';
 
 $strTableAlreadyExists = 'La table %s existe déjà!';
+$strTableAlteredSuccessfully = 'La table %1$s a été modifiée avec succès.';
 $strTableComments = 'Commentaires sur la table';
 $strTableEmpty = 'Le nom de la table est vide';
+$strTableHasBeenCreated = 'La table %1$s a été créée.';
 $strTableHasBeenDropped = 'La table %s a été effacée';
 $strTableHasBeenEmptied = 'La table %s a été vidée';
 $strTableHasBeenFlushed = 'La table %s a été rechargée';
@@ -915,6 +959,7 @@ $strTakeIt = 'utiliser celui-ci';
 $strTblPrivileges = 'Privilèges spécifiques à une table';
 $strTempData = 'Données temporaires';
 $strTextAreaLength = 'Il est possible que ce champ<br />ne soit pas éditable<br />en raison de sa longueur';
+$strTexyText = 'Texte Texy!';
 $strThai = 'thaï';
 $strThemeDefaultNotFound = 'Thème par défaut %s inexistant!';
 $strThemeNoPreviewAvailable = 'Prévisualisation non disponible.';
@@ -979,7 +1024,6 @@ $strUploadLimit = 'Vous avez probablement tenté de télécharger un fichier tro
 $strUploadsNotAllowed = 'Les téléchargements vers ce serveur ne sont pas permis.';
 $strUsage = 'Espace';
 $strUseBackquotes = 'Protéger les noms des tables et des champs par des&nbsp;"`"';
-$strUsedPhpExtensions = 'Extensions PHP utilisées';
 $strUseHostTable = 'Utiliser la table Host';
 $strUserAlreadyExists = 'L\'utilisateur %s existe déjà!';
 $strUserEmpty = 'Le nom d\'utilisateur est vide';
@@ -998,19 +1042,21 @@ $strValidateSQL = 'Valider SQL';
 $strValidatorError = 'Le validateur SQL n\'a pas pu être initialisé. Vérifiez que les extensions PHP nécessaires ont bien été installées (voir la %sdocumentation%s).';
 $strValue = 'Valeur';
 $strVar = 'Variable';
-$strVersionInformation = 'Information de version';
+$strVersionInformation = 'Version';
 $strViewDump = '<b>Afficher le schéma</b> de la table';
 $strViewDumpDatabases = 'Schéma et/ou contenu des bases de données';
 $strViewDumpDB = 'Schéma et données de la base ';
+$strViewHasAtLeast = 'Cette vue contient au moins ce nombre d\'enregistrements. Veuillez référer à %sdocumentation%s.';
 $strViewHasBeenDropped = 'La vue %s a été supprimée';
-$strViewMaxExactCount = 'Cette vue comporte plus de %d enregistrements. Veuillez vous référer à la %sdocumentation%s.';
 $strViewName = 'Nom de la vue';
 $strView = 'Vue';
 
+$strWebServer = 'Serveur web';
 $strWebServerUploadDirectoryError = 'Le répertoire de transfert est inaccessible';
 $strWebServerUploadDirectory = 'répertoire de transfert du serveur Web';
 $strWelcome = 'Bienvenue à %s ';
 $strWestEuropean = 'Europe de l\'ouest';
+$strWiki = 'Wiki';
 $strWildcard = 'passepartout';
 $strWindowNotFound = 'La fenêtre principale n\'a pu être mise à jour. Il est possible que vous l\'ayiez fermée, ou encore que votre navigateur bloque les mises à jour inter-fenêtres pour des raisons de sécurité.';
 $strWithChecked = 'Pour la sélection :';
