@@ -1,5 +1,5 @@
 <?php
-/* $Id: japanese-utf-8.inc.php 11187 2008-04-06 00:00:42Z lem9 $ */
+/* $Id: japanese-utf-8.inc.php 11655 2008-10-18 23:28:08Z lem9 $ */
 
 /**
  * Translated by Yukihiro Kawada <kawada at den.fujifilm.co.jp>
@@ -24,12 +24,13 @@ $datefmt = '%Y 年 %B %d 日 %H:%M';
 $timespanfmt = '%s 日 %s 時間 %s 分 %s 秒';
 
 $strAbortedClients = '中断';
-$strAccessDenied = 'アクセスは拒否されました';
 $strAccessDeniedCreateConfig = '設定ファイルが作成されていないものと思われます。%1$sセットアップスクリプト%2$s を利用して設定ファイルを作成してください';
 $strAccessDeniedExplanation = 'MySQL サーバに接続しようとしましたが拒否されました。config.inc.php のホスト、ユーザ名、パスワードが MySQL サーバの管理者から与えられた情報と一致するか確認してください';
+$strAccessDenied = 'アクセスは拒否されました';
+$strActions = 'アクション';
 $strAction = '操作';
 $strAddAutoIncrement = 'AUTO_INCREMENT 値を追加する';
-$strAddClause = '%sを追加';
+$strAddClause = '%s を追加';
 $strAddConstraints = '制約を追加する';
 $strAddDeleteColumn = 'フィールド列を追加・削除する';
 $strAddDeleteRow = '条件行を追加・削除する';
@@ -41,21 +42,21 @@ $strAddPrivilegesOnDb = 'データベースに特権を追加';
 $strAddPrivilegesOnTbl = 'テーブルに特権を追加';
 $strAddSearchConditions = '検索条件("where"節の内容)を追加してください:';
 $strAddToIndex = 'インデックスに&nbsp;%s&nbsp; の列を追加しました';
-$strAddUser = '新しいユーザを追加する';
 $strAddUserMessage = '新しいユーザを追加しました';
+$strAddUser = '新しいユーザを追加する';
 $strAdministration = '管理';
-$strAffectedRows = '変更された行数:';
-$strAfter = '指定カラムの後に %s';
 $strAfterInsertBack = '前のページに戻る';
 $strAfterInsertNewInsert = '新しいレコードを追加する';
 $strAfterInsertNext = '次の行を編集する';
 $strAfterInsertSame = 'このページに戻る';
-$strAll = '全部';
+$strAfter = '指定カラムの後に %s';
 $strAllowInterrupt = '制限時間が近くなったときにスクリプト側でインポートを中断できるようにします。大きなファイルをインポートする場合には便利ですが、トランザクションが壊れることもあります';
 $strAllTableSameWidth = 'すべてのテーブルを同じ幅で表示しますか?';
+$strAll = '全部';
 $strAlterOrderBy = 'テーブルの並び順';
 $strAnalyzeTable = 'テーブルを分析する';
-$strAnd = 'AND';
+$strAnalyze = '分析';
+$strAnd = 'および';
 $strAndThen = '続いて';
 $strAngularLinks = '角リンク';
 $strAnIndex = '%s にインデックスを追加しました';
@@ -67,6 +68,7 @@ $strAPrimaryKey = '%s に主キーを追加しました';
 $strArabic = 'アラビア語';
 $strArmenian = 'アルメニア語';
 $strAscending = '昇順';
+$strAsDefined = 'ユーザ定義';
 $strAtBeginningOfTable = 'テーブルの先頭';
 $strAtEndOfTable = 'テーブルの末尾';
 $strAttr = '属性';
@@ -92,20 +94,19 @@ $strBookmarkLabel = 'ラベル';
 $strBookmarkQuery = 'ブックマークされている SQL';
 $strBookmarkReplace = '同名のブックマークは差し替える';
 $strBookmarkThis = 'この SQL をブックマークする';
-$strBookmarkView = '表示のみ'; // XXX ビュー専用？
-$strBrowseDistinctValues = '重複している値を表示しない'; // XXX
-$strBrowse = '表示';
+$strBookmarkView = '表示のみ';
+$strBrowseDistinctValues = '重複している値を表示しない';
 $strBrowseForeignValues = '参照されている値を表示する';
+$strBrowse = '表示';
 $strBufferPool = 'バッファプール';
 $strBufferPoolActivity = 'バッファプールの利用状況';
 $strBufferPoolUsage = 'バッファプールの使用量';
-$strBufferReadMisses = '読み込みミス';
 $strBufferReadMissesInPercent = '読み込みミス(％)';
-$strBufferWriteWaits = '書き込み待ち';
+$strBufferReadMisses = '読み込みミス';
 $strBufferWriteWaitsInPercent = '書き込み待ち(％)';
+$strBufferWriteWaits = '書き込み待ち';
 $strBulgarian = 'ブルガリア語';
-$strBusyPages = 'ビジーなページ数'; // XXX
-$strBzError = 'このバージョンの PHP は Bz2 拡張が壊れているのでダンプを圧縮できません。phpMyAdmin の設定ファイルの <code>$cfg[\'BZipDump\']</code> を <code>FALSE</code>に設定することを強く推奨します。Bz2 圧縮機能を使いたい場合は PHP のバージョンを上げて下さい。PHP のバグレポート %s もご覧ください';
+$strBusyPages = 'ビジーなページ数';
 $strBzip = '"bzip 形式"';
 
 $strCalendar = 'カレンダー';
@@ -120,37 +121,38 @@ $strCantUseRecodeIconv = '必要な拡張はロードされているようです
 $strCardinality = '一意な値の数';
 $strCaseInsensitive = '大文字小文字を区別しない';
 $strCaseSensitive = '大文字小文字を区別する';
-$strCentralEuropean = '中央ヨーロッパ語';
-$strChange = '変更';
-$strChangeCopyMode = '同じ特権を持つ新しいユーザを作る';
+$strCentralEuropean = '中央ヨーロッパ諸語';
 $strChangeCopyModeCopy = '元のユーザも残す';
 $strChangeCopyModeDeleteAndReload = 'ユーザテーブルから元のユーザを削除し、特権をリロードする';
 $strChangeCopyModeJustDelete = 'ユーザテーブルから元のユーザを削除する';
 $strChangeCopyModeRevoke = '元のユーザの特権をすべて無効にしてから削除する';
+$strChangeCopyMode = '同じ特権を持つ新しいユーザを作る';
 $strChangeCopyUser = 'ログイン情報の変更 / ユーザの複製';
 $strChangeDisplay = '表示するフィールドを選択してください';
 $strChangePassword = 'パスワードを変更する';
-$strCharset = '文字セット';
+$strChange = '変更';
 $strCharsetOfFile = 'ファイルの文字セット:';
-$strCharsets = '文字セット';
 $strCharsetsAndCollations = '文字セットと照合順序';
+$strCharsets = '文字セット';
+$strCharset = '文字セット';
 $strCheckAll = 'すべてチェックする';
-$strCheckOverhead = 'オーバーヘッドのあるテーブルを確認してください'; // XXX
+$strCheckOverhead = 'オーバーヘッドのあるテーブルを確認してください';
+$strCheckPrivsLong = 'データベース &quot;%s&quot; の特権を確認してください';
 $strCheckPrivs = '特権をチェックする';
-$strCheckPrivsLong = 'データベース &quot;%s&quot; の特権を確認してください'; // XXX
 $strCheckTable = 'テーブルをチェックする';
+$strCheck = '確認';
 $strChoosePage = '編集するページを選択してください';
 $strColComFeat = '列コメント表示機能'; // XXX
 $strCollation = '照合順序';
 $strColumnNames = 'カラム名';
 $strColumnPrivileges = 'このカラムに固有の特権';
 $strCommand = 'コマンド';
+$strComment = 'コメント';
 $strComments = 'コメント';
-$strCommentsForTable = 'COMMENTS FOR TABLE'; // XXX
 $strCompatibleHashing = 'MySQL&nbsp;4.0 互換';
 $strCompleteInserts = '完全な INSERT 文を作成する';
-$strCompression = '圧縮';
 $strCompressionWillBeDetected = 'インポートしたファイルの圧縮方法は次の中から自動検出されます: %s';
+$strCompression = '圧縮';
 $strConfigDefaultFileError = 'デフォルトの設定を読み込めませんでした: "%1$s"';
 $strConfigFileError = 'phpMyAdmin の設定ファイルを読み込めませんでした! <br />文法エラーが発生したか、ファイルが見つかりません。<br />下のリンクから直接設定ファイルを読み込んで PHP のエラーメッセージを確認してください。たいていの場合はどこかに引用符やセミコロンの抜けがあります。<br />空白のページが表示されれば問題なしです';
 $strConfigureTableCoord = 'テーブル %s の座標を設定してください';
@@ -166,7 +168,6 @@ $strCopyTable = 'テーブルを(database<b>.</b>table)にコピーする:';
 $strCopyTableOK = 'テーブル %s を %s にコピーしました';
 $strCopyTableSameNames = '同じテーブルにはコピーできません!';
 $strCouldNotKill = 'スレッド %s の終了に失敗しました。すでに閉じているようです';
-$strCreate = '作成';
 $strCreateDatabaseBeforeCopying = 'コピーの前に CREATE DATABASE する';
 $strCreateIndex = '&nbsp;%s&nbsp; のカラムにインデックスを作成する';
 $strCreateIndexTopic = '新しいインデックスを作成する';
@@ -176,30 +177,33 @@ $strCreatePage = '新しいページを作成する';
 $strCreatePdfFeat = 'PDF の作成';
 $strCreateRelation = 'リレーションを作成';
 $strCreateTable  = 'テーブルを作成';
-$strCreateUserDatabase = 'ユーザ専用データベース';
 $strCreateUserDatabaseName = '同名のデータベースを作成してすべての特権を与える';
 $strCreateUserDatabaseNone = 'なし';
 $strCreateUserDatabaseWildcard = 'ワイルドカード(ユーザ名_%)に該当するデータベースにすべての特権を与える';
+$strCreateUserDatabase = 'ユーザ専用データベース';
+$strCreate = '作成';
 $strCreationDates = '作成/更新/検査日';
 $strCriteria = '条件';
 $strCroatian = 'クロアチア語';
 $strCSV = 'CSV';
-$strCyrillic = 'キリル文字ロシア語';
-$strCzech = 'チェコ語';
+$strCustomColor = 'カスタムカラー';
+$strCyrillic = 'キリル諸語';
 $strCzechSlovak = 'チェコのスロバキア語';
+$strCzech = 'チェコ語';
 
 $strDanish = 'デンマーク語';
 $strData = 'データ';
 $strDatabase = 'データベース';
 $strDatabaseEmpty = 'データベース名が空です!';
 $strDatabaseExportOptions = 'データベースエクスポートオプション';
+$strDatabaseHasBeenCreated = 'データベース %1$s を作成しました。';
 $strDatabaseHasBeenDropped = 'データベース %s を削除しました';
 $strDatabases = 'データベース';
 $strDatabasesDropped = 'データベース %s を正常に削除しました';
-$strDatabasesStats = 'データベースの統計';
 $strDatabasesStatsDisable = '統計を無効にする';
 $strDatabasesStatsEnable = '統計を有効にする';
 $strDatabasesStatsHeavyTraffic = '注意: データベースの統計を有効にするとウェブサーバと MySQL サーバの間の通信量が激増することがあります';
+$strDatabasesStats = 'データベースの統計';
 $strDataDict = 'データ辞書';
 $strDataOnly = 'データのみ';
 $strDataPages = 'データが含まれているページ数';
@@ -209,18 +213,17 @@ $strDbIsEmpty = 'データベースが空のようです!';
 $strDbPrivileges = 'データベースに固有の特権';
 $strDBRename = '新しいデータベース名';
 $strDbSpecific = 'データベース固有';
-$strDefault = 'デフォルト値';
 $strDefaultEngine = '%s はこの MySQL サーバのデフォルトストレージエンジンです';
 $strDefaultValueHelp = 'デフォルト値にはひとつの値のみ入力してください。バックスラッシュによるエスケープや引用符を含めることはできません。例: a';
+$strDefault = 'デフォルト値';
 $strDefragment = 'テーブルのデフラグ';
 $strDelayedInserts = '遅延インサートを使用する';
-$strDelete = '削除';
-$strDeleteAndFlush = 'ユーザを削除して特権をリロードする';
 $strDeleteAndFlushDescr = 'これはもっともクリーンな方法ですが、特権のリロードに時間がかかることがあります';
+$strDeleteAndFlush = 'ユーザを削除して特権をリロードする';
 $strDeleted = '行を削除しました';
-$strDeletedRows = '削除した行数:';
 $strDeleteNoUsersSelected = '削除するユーザが選択されていません!';
 $strDeleteRelation = 'リレーションを削除';
+$strDelete = '削除';
 $strDeleting = '%s を削除中です';
 $strDelimiter = 'デリミタ';
 $strDelOld = 'このページには存在しないテーブルへの参照があります。これらの参照を削除しますか?';
@@ -228,6 +231,7 @@ $strDescending = '降順';
 $strDescription = '説明';
 $strDesigner = 'デザイナ';
 $strDesignerHelpDisplayField = '表示するフィールドはピンク色で表示されます。表示非表示を切り替える場合は「表示するフィールドを選択する」というアイコンをクリックしてから適切なフィールド名をクリックください';
+$strDetails = '詳細...';
 $strDictionary = '辞書';
 $strDirectLinks = '直リンク';
 $strDirtyPages = 'ダーティページ';
@@ -240,32 +244,32 @@ $strDoAQuery = '"query by example"を実行 (ワイルドカード: "%")';
 $strDocSQL = 'DocSQL';
 $strDocu = 'ドキュメント';
 $strDoYouReally = '本当に実行しますか?';
-$strDrop = '削除';
 $strDropDatabaseStrongWarning = 'データベースを完全に削除しようとしています!';
 $strDropUsersDb = 'ユーザと同名のデータベースを削除する';
+$strDrop = '削除';
 $strDumpingData = 'テーブルのデータをダンプしています';
 $strDumpSaved = 'ダンプをファイル %s に保存しました';
 $strDumpXRows = '%s 行をダンプします(開始行: %s)';
 $strDynamic = '動的';
 
-$strEdit = '編集';
 $strEditPDFPages = 'PDF ページを編集する';
 $strEditPrivileges = '特権を編集';
-$strEffective = '実効'; // XXX
-$strEmpty = '空にする';
+$strEdit = '編集';
+$strEffective = '有効';
 $strEmptyResultSet = '返り値が空でした(行数0)';
+$strEmpty = '空にする';
 $strEnabled = '有効';
 $strEncloseInTransaction = 'エクスポートをトランザクションで囲む';
 $strEncto = 'エンコーディングへ変換する'; // encoding convert
-$strEnd = '最後';
 $strEndCut = 'END CUT';
 $strEndRaw = 'END RAW';
+$strEnd = '最後';
 $strEngineAvailable = '%s は有効になっています';
 $strEngineDisabled = '%s は無効になっています';
 $strEngines = 'エンジン';
 $strEngineUnsupported = 'この MySQL サーバは %s ストレージエンジンをサポートしていません';
-$strEnglish = '英語';
 $strEnglishPrivileges = '注意: MySQL の特権名は英語で表示されます';
+$strEnglish = '英語';
 $strError = 'エラー';
 $strErrorInZipFile = 'ZIP アーカイブにエラーがあります:';
 $strErrorRelationAdded = 'エラー: リレーションを追加できませんでした';
@@ -276,6 +280,7 @@ $strEscapeWildcards = '_ や % というワイルドカードを文字として
 $strEsperanto = 'エスペラント語';
 $strEstonian = 'エストニア語';
 $strEvent = 'イベント';
+$strEvents = 'イベント';
 $strExcelEdition = 'Excel のエディション';
 $strExecuteBookmarked = 'ブックマークされたクエリを実行する';
 $strExplain = 'EXPLAIN で確認';
@@ -295,12 +300,12 @@ $strFieldsEscapedBy = 'フィールドのエスケープ記号';
 $strFieldsTerminatedBy = 'フィールド区切り記号';
 $strFileAlreadyExists = 'サーバ上に既存のファイル %s があります。ファイル名を変更するか、上書きオプションを有効にしてください';
 $strFileCouldNotBeRead = 'ファイルを読み込めませんでした';
-$strFileNameTemplate = 'ファイル名のテンプレート';
 $strFileNameTemplateDescription = 'このテンプレートは %1$sstrftime%2$s を使って解釈されます。そのため、時間の書式文字列を利用できます。また、次の変換も行われます。%3$s それ以外のテキストは修正されません';
 $strFileNameTemplateDescriptionDatabase = 'データベース名';
 $strFileNameTemplateDescriptionServer = 'サーバ名';
 $strFileNameTemplateDescriptionTable = 'テーブル名';
 $strFileNameTemplateRemember = 'テンプレートを記憶させる';
+$strFileNameTemplate = 'ファイル名のテンプレート';
 $strFiles = 'ファイル';
 $strFileToImport = 'インポートするファイル';
 $strFixed = '固定';
@@ -309,18 +314,19 @@ $strFlushQueryCache = 'クエリキャッシュをフラッシュする';
 $strFlushTable = 'テーブルをフラッシュする("FLUSH")';
 $strFlushTables = 'すべてのテーブルをフラッシュする(閉じる)';
 $strFontSize = 'フォントサイズ';
-$strForeignKeyError = '外部キーを作成中にエラーが発生しました (データ型を確認してください)';
+$strForeignKeyError = '%1$s に外部キーを作成するときにエラーが発生しました (データ型を確認してください)';
+$strForeignKeyRelationAdded = '外部キーを追加しました';
 $strFormat = 'フォーマット';
 $strFormEmpty = 'フォームに入力されていない値があります!';
 $strFreePages = 'フリーページ数';
 $strFullText = '全文';
-$strFunction = '関数';
 $strFunctions = '関数';
+$strFunction = '関数';
 
 $strGenBy = '生成環境';
 $strGeneralRelationFeat = '一般的なリレーション機能';
-$strGenerate = '生成する';
 $strGeneratePassword = 'パスワードを生成する';
+$strGenerate = '生成する';
 $strGenTime = '生成時間';
 $strGeorgian = 'グルジア語';
 $strGerman = 'ドイツ語';
@@ -334,14 +340,13 @@ $strGzip = '"gzip 形式"';
 
 $strHandler = 'ハンドラ';
 $strHasBeenAltered = 'を変更しました';
-$strHasBeenCreated = 'を作成しました';
 $strHaveToShow = '最低ひとつは表示するカラムを選択してください';
 $strHebrew = 'ヘブライ語';
 $strHelp = 'ヘルプ';
 $strHexForBLOB = 'BLOBに16進数表記を利用する';
-$strHide         = '隠す';
 $strHideShowAll = 'すべて隠す/表示';
 $strHideShowNoRelation = 'リレーションのないテーブルを隠す/表示';
+$strHide = '隠す';
 $strHome = 'メインページへ';
 $strHomepageOfficial = 'phpMyAdmin のオフィシャルサイト';
 $strHost = 'ホスト';
@@ -354,9 +359,9 @@ $strIcelandic = 'アイスランド語';
 $strId = 'ID';
 $strIdxFulltext = '全文';
 $strIEUnsupported = 'Internet Explorer ではこの機能は利用できません';
-$strIgnore = '無視';
 $strIgnoreDuplicates = '重複している行を無視する';
 $strIgnoreInserts = 'INSERT IGNORE を使用する';
+$strIgnore = '無視';
 $strImport = 'インポート';
 $strImportExportCoords = 'PDF スキーマの座標をインポート/エクスポートする';
 $strImportFiles = 'インポートファイル';
@@ -364,33 +369,32 @@ $strImportFormat = 'インポートするファイルの形式';
 $strImportSuccessfullyFinished = 'インポートは正常終了しました。%d 個のクエリを実行しました';
 $strIndex = 'インデックス';
 $strIndexes = 'インデックスサイズ';
-$strIndexesSeemEqual = '以下のインデックスは同じもののように思われます。いずれかを削除してください :';
+$strIndexesSeemEqual = 'インデックス %1$s と %2$s は同一のもののようです。一方は削除してもよいかもしれません。';
 $strIndexHasBeenDropped = 'インデックス %s を削除しました';
 $strIndexName = 'インデックス名:';
 $strIndexType = 'インデックスの種類:';
 $strIndexWarningTable = 'テーブル `%s` のインデックスに問題があります';
-$strInnoDBAutoextendIncrementDesc = 'スペースがいっぱいになったときに自動的にテーブルを拡張する場合に追加されるテーブルサイズ';
-$strInnoDBAutoextendIncrement = '自動拡張時に追加されるテーブルサイズ';
-$strInnoDBBufferPoolSize = 'バッファプールのサイズ';
+$strInnoDBAutoextendIncrementDesc = 'スペースがいっぱいになったときに自動的にテーブルを拡張する場合に追加されるテーブルの大きさ';
+$strInnoDBAutoextendIncrement = '自動拡張時に追加されるテーブルの大きさ';
 $strInnoDBBufferPoolSizeDesc = 'InnoDB がテーブルのデータやインデックスをキャッシュするのに使うメモリバッファ量';
+$strInnoDBBufferPoolSize = 'バッファプールの大きさ';
 $strInnoDBDataFilePath = 'データファイル';
 $strInnoDBDataHomeDir = 'データのホームディレクトリ';
 $strInnoDBDataHomeDirDesc = 'すべての InnoDB データファイルに共通するディレクトリパス';
 $strInnoDBPages = 'ページ';
-$strInnoDBRelationAdded = 'InnoDB リレーションを追加しました';
 $strInnodbStat = 'InnoDB ステータス';
-$strInsecureMySQL = 'お使いの設定ファイルに MySQL のデフォルト特権アカウントに相当する設定 (root ユーザでパスワードなし) が含まれています。お使いの MySQL サーバはこのデフォルト設定で動作しているため不正アクセス可能な状態になっています。このセキュリティーホールはかならず閉ざしてください';
-$strInsert = '挿入';
+$strInsecureMySQL = 'お使いの設定ファイルに MySQL のデフォルト特権アカウントに相当する設定 (root ユーザでパスワードなし) が含まれています。お使いの MySQL サーバはこのデフォルト設定で動作しているため不正アクセス可能な状態になっています。このセキュリティホールはかならず閉ざしてください';
 $strInsertAsNewRow = '新しい行として挿入する';
-$strInsertedRowId = '挿入した行 ID:';
-$strInsertedRows = '挿入した行数:';
-$strInternalNotNecessary = '* InnoDB にも内部リレーションが存在している場合は不要です';
+$strInsertedRowId = 'id %1$d の行を挿入しました';
+$strInsert = '挿入';
+$strInterface = 'インタフェース';
+$strInternalAndForeign = '対応する外部リレーションが存在する場合、内部リレーションは必要ありません。';
 $strInternalRelationAdded = '内部リレーションを追加しました';
 $strInternalRelations = '内部リレーション';
 $strInUse = '使用中';
 $strInvalidAuthMethod = '設定ファイルに無効な認証方法が指定されています:';
-$strInvalidColumn = '不正なカラム(%s)が指定されています!';
 $strInvalidColumnCount = 'カラム数は 0 より大きくなければいけません';
+$strInvalidColumn = '不正なカラム(%s)が指定されています!';
 $strInvalidCSVFieldCount = 'CSV 入力のフィールド数が不正です (行: %d)';
 $strInvalidCSVFormat = 'CSV 入力の書式が不正です (行: %d)';
 $strInvalidCSVParameter = 'CSV インポートのパラメータが不正です: %s';
@@ -406,8 +410,8 @@ $strInvalidTableName = 'テーブル名が不正です';
 $strJapanese = '日本語';
 $strJoins = '結合';
 $strJumpToDB = '&quot;%s&quot; データベースに移動';
-$strJustDelete = '特権テーブルからユーザを削除するだけにする';
 $strJustDeleteDescr = '特権がリロードされるまでは「削除」されたユーザもふつうにサーバにアクセスできます';
+$strJustDelete = '特権テーブルからユーザを削除するだけにする';
 
 $strKanjiEncodConvert = '漢字コード変換'; // kanji code convert
 $strKeepPass = 'パスワードは変更しない';
@@ -418,13 +422,13 @@ $strKnownExternalBug = '%s の機能には既知のバグがあります。%s 
 $strKorean = '韓国語';
 
 $strLandscape = '横向き';
-$strLanguage = '言語';
 $strLanguageUnknown = '言語ファイルが登録されていません: %1$s';
+$strLanguage = '言語';
 $strLatchedPages = 'ラッチされているページ';
 $strLatexCaption = 'テーブルのキャプション';
 $strLatexContent = 'テーブル __TABLE__ の内容';
-$strLatexContinued = '(続き)';
 $strLatexContinuedCaption = 'テーブルのキャプション(続き)';
+$strLatexContinued = '(続き)';
 $strLatexIncludeCaption = 'テーブルのキャプションを含める';
 $strLatexLabel = 'ラベルキー';
 $strLaTeX = 'LaTeX';
@@ -458,47 +462,45 @@ $strMIME_available_transform = '利用できる変換機能';
 $strMIME_description = '説明';
 $strMIME_MIMEtype = 'MIME タイプ';
 $strMIME_nodescription = 'この変換機能には説明がありません。<br />%s の動作については作者にご確認ください';
-$strMIME_transformation = 'ブラウザ変換機能';
 $strMIME_transformation_note = '利用可能な変換オプションや MIME タイプの変換の一覧については %s変換機能の説明%s をご覧ください';
-$strMIME_transformation_options = '変換オプション';
 $strMIME_transformation_options_note = '変換オプションの値の書式: \'a\',\'b\',\'c\'...<br />バックスラッシュ ("\") やシングルクォート ("\'") を値に含める必要がある場合は ( \\\\xyz や a\\\'b のように) バックスラッシュでエスケープしてください';
-$strMIMETypesForTable = 'MIME TYPES FOR TABLE'; // XXX
+$strMIME_transformation_options = '変換オプション';
+$strMIME_transformation = 'ブラウザ変換機能';
+$strMIMETypesForTable = 'MIME TYPES FOR TABLE';
 $strMIME_without = 'イタリック表示されている MIME タイプには個別の変換関数はありません';
 $strModifications = '修正を保存しました';
-$strModify = '修正';
 $strModifyIndexTopic = 'インデックスを修正する';
+$strModify = '修正';
 $strMoveMenu = 'メニューを移動する';
-$strMoveTable = 'テーブルの移動先(database<b>.</b>table):';
 $strMoveTableOK = 'テーブル %s を %s に移動しました';
 $strMoveTableSameNames = '同じテーブルには移動できません!';
-$strMultilingual = '複数言語';
+$strMoveTable = 'テーブルの移動先(database<b>.</b>table):';
+$strMultilingual = '多言語';
 $strMyISAMDataPointerSize = 'データポインタのサイズ';
 $strMyISAMDataPointerSizeDesc = 'MAX_ROWS オプションを指定せずに MyISAM テーブルを作成するときに CREATE TABLE が使用するデフォルトのポインタサイズ (バイト単位)';
-$strMyISAMMaxExtraSortFileSize = 'インデックス作成時に利用する一時ファイルの最大サイズ';
 $strMyISAMMaxExtraSortFileSizeDesc = 'MyISAM のインデックスを高速生成するときに利用される一時ファイルとキーキャッシュの差がここで指定した値以上に大きくなる場合は、キーキャッシュ法が使われます';
-$strMyISAMMaxSortFileSize = 'ソート用の一時ファイルの最大サイズ';
+$strMyISAMMaxExtraSortFileSize = 'インデックス作成時に利用する一時ファイルの最大サイズ';
 $strMyISAMMaxSortFileSizeDesc = 'MyISAM インデックスを再作成するとき (REPAIR TABLE や ALTER TABLE、LOAD DATA INFILE の最中) に利用できる一時ファイルの最大サイズ';
+$strMyISAMMaxSortFileSize = 'ソート用の一時ファイルの最大サイズ';
 $strMyISAMRecoverOptionsDesc = 'クラッシュした MyISAM テーブルを自動修復するときのモード (サーバ起動オプション --myisam-recover で設定されるもの)';
 $strMyISAMRecoverOptions = '自動修復モード';
-$strMyISAMRepairThreads = 'スレッドの修復';
 $strMyISAMRepairThreadsDesc = 'この値が 1 より大きい場合は MyISAM テーブルのインデックスも修復中にソートプロセスによって (スレッドごとに) 同時作成されます';
+$strMyISAMRepairThreads = 'スレッドの修復';
 $strMyISAMSortBufferSize = 'ソートバッファのサイズ';
 $strMyISAMSortBufferSizeDesc = 'REPAIR TABLE の最中に MyISAM のインデックスをソートするとき、あるいは CREATE INDEX や ALTER TABLE でインデックスを作成するときに割り当てられるバッファ';
 $strMySQLCharset = 'MySQL の文字セット';
 $strMysqlClientVersion = 'MySQL クライアントのバージョン';
-$strMySQLConnectionCollation = 'MySQL の接続照合順序';
+$strMySQLConnectionCollation = 'MySQL 接続の照合順序';
 $strMysqlLibDiffersServerVersion = 'お使いの PHP MySQL ライブラリのバージョン %s が MySQL サーバのバージョン %s と異なります。これは予期しない不具合を起こす可能性があります。';
 $strMySQLSaid = 'MySQLのメッセージ: ';
 $strMySQLShowProcess = 'MySQL プロセスの表示';
-$strMySQLShowStatus = 'MySQL のランタイム情報';
-$strMySQLShowVars = 'MySQL のシステム変数';
 
 $strName = '名前';
 $strNext = '次へ';
 $strNo = 'いいえ';
 $strNoActivity = '%s 秒以上操作をしませんでした。ログインしなおしてください';
-$strNoDatabases = 'データベースが存在しません';
 $strNoDatabasesSelected = 'データベースが選択されていません';
+$strNoDatabases = 'データベースが存在しません';
 $strNoDataReceived = 'インポートするデータを受信できませんでした。ファイル名が送信されていないか、ファイルサイズが PHP の設定で許可された最大値を超えています。FAQ 1.16をご覧ください';
 $strNoDescription = '説明がありません';
 $strNoDetailsForEngine = 'このストレージエンジンにはステータスの詳細情報はありません';
@@ -506,8 +508,8 @@ $strNoDropDatabases = 'DROP DATABASE 文は無効にされています';
 $strNoExplain = 'SQL の EXPLAIN 解析をスキップ';
 $strNoFilesFoundInZip = 'ZIP アーカイブにファイルが含まれていません!';
 $strNoFrames = 'phpMyAdmin は<b>フレーム対応</b>ブラウザでの利用をお勧めします';
-$strNoIndex = 'インデックスが定義されていません!';
 $strNoIndexPartsDefined = 'インデックス部分が定義されていません!';
+$strNoIndex = 'インデックスが定義されていません!';
 $strNoModification = '変更なし';
 $strNone = 'なし';
 $strNoOptions = 'この書式にはオプションはありません';
@@ -533,27 +535,57 @@ $strNumSearchResultsTotal = '<b>合計:</b> <i>%s</i> 件';
 $strNumTables = 'テーブル';
 
 $strOK = 'OK';
-$strOpenDocumentSpreadsheet = 'スプレッドシートを開く';
-$strOpenDocumentText = 'テキストを開く';
+$strOpenDocumentSpreadsheet = 'Openスプレッドシート';
+$strOpenDocumentText = 'Openテキスト';
 $strOpenNewWindow = '別ウィンドウで開く';
 $strOperations = '操作';
 $strOperator = '演算子';
 $strOptimizeTable = 'テーブルを最適化する';
+$strOptimize = '最適化';
 $strOptions = 'オプション';
 $strOr = 'または';
 $strOverhead = 'オーバーヘッド';
 $strOverwriteExisting = '既存のファイルは上書き';
 
+$strPacked = '圧縮';
 $strPageNumber = 'ページ番号:';
 $strPagesToBeFlushed = 'フラッシュ待ちページ数';
 $strPaperSize = '用紙サイズ';
 $strPartialImport = '部分インポート';
 $strPartialText = '部分テキスト';
+$strPartitionDefinition = 'パーティションの定義';
+$strPartitioned = 'パーティション有り';
+$strPartitionMaintenance = 'パーティション管理';
+$strPartition = 'パーティション %s';
 $strPassword = 'パスワード';
 $strPasswordChanged = '%s のパスワードは正しく変更されました';
 $strPasswordEmpty = 'パスワードが空です!';
 $strPasswordHashing = 'パスワードハッシュ';
 $strPasswordNotSame = 'パスワードが異なっています!';
+$strPBXTCheckpointFrequencyDesc = 'チェックポイントを実行する前にトランザクションログに書き込むデータ量。デフォルト値は 24MB です。';
+$strPBXTCheckpointFrequency = 'チェックポイント頻度';
+$strPBXTDataFileGrowSizeDesc = 'ハンドルデータファイル(.xtd)の増分。';
+$strPBXTDataFileGrowSize = 'データファイルの増分';
+$strPBXTDataLogThresholdDesc = 'データログファイルの大きさの最大値。デフォルト値は 64MB です。PBXT は最大 32000 個のデータログを作成できますが、これはあらゆるテーブルが使うものですので、この変数の値を大きくするとデータベースに保存できるデータの総数を増やすことができます。';
+$strPBXTDataLogThreshold = 'データログの閾値';
+$strPBXTGarbageThresholdDesc = 'データログファイルのガベージが何％になったら圧縮するか。1 から 99 までの値をとります。デフォルトは 50 です。';
+$strPBXTGarbageThreshold = 'ガベージ閾値';
+$strPBXTIndexCacheSizeDesc = 'インデックスキャッシュに割り当てるメモリ量。デフォルト値は 32MB です。ここで割り当てたメモリはインデックスページのキャッシュにのみ利用されます。';
+$strPBXTIndexCacheSize = 'インデックスキャッシュの大きさ';
+$strPBXTLogBufferSizeDesc = 'データログを書き出すときに使うバッファの大きさ。デフォルトは 256MB です。このエンジンはスレッドごとにバッファをひとつ割り当てます(そのスレッドがデータログを書き出す必要がある場合のみ)。';
+$strPBXTLogBufferSize = 'ログバッファの大きさ';
+$strPBXTLogCacheSizeDesc = 'トランザクションログデータをキャッシュするのに使うトランザクションログキャッシュに割り当てるメモリ量。デフォルトは 16MB です。';
+$strPBXTLogCacheSize = 'ログキャッシュの大きさ';
+$strPBXTLogFileCountDesc = 'システムが保存するトランザクションログファイル (pbxt/system/xlog*.xt) の数。ログの数がそれ以上になると古いログが削除されるか、リネームされて最大値の1つ前の番号がつけられます。';
+$strPBXTLogFileCount = 'ログファイル数';
+$strPBXTLogFileThresholdDesc = 'トランザクションログがどこまで増えたらロールオーバーして新しいログを作成するか。デフォルト値は 16MB です。';
+$strPBXTLogFileThreshold = 'ログファイルの閾値';
+$strPBXTRecordCacheSizeDesc = 'テーブルデータをキャッシュするのに使うレコードキャッシュに割り当てるメモリ量。デフォルト値は 32MB です。このメモリはハンドルデータファイル(.xtd)や列ポインタファイル(.xtr)の変更をキャッシュするのに利用されます。';
+$strPBXTRecordCacheSize = 'レコードキャッシュの大きさ';
+$strPBXTRowFileGrowSizeDesc = '列ポインタファイル(.xtr)の増分。';
+$strPBXTRowFileGrowSize = '列ファイルの増分';
+$strPBXTTransactionBufferSizeDesc = 'グローバルトランザクションログバッファの大きさ(このエンジンはこの大きさのバッファを2つ割り当てます）。デフォルトは 1MB です。';
+$strPBXTTransactionBufferSize = 'トランザクションバッファの大きさ';
 $strPdfDbSchema = 'データベース %s のスキーマ - ページ %s';
 $strPdfInvalidTblName = '"%s" テーブルは存在しません!';
 $strPdfNoTables = 'テーブルがありません';
@@ -565,27 +597,26 @@ $strPerMinute = '/分';
 $strPerSecond = '/秒';
 $strPersian = 'ペルシア語';
 $strPhoneBook = '電話帳';
-$strPHP40203 = 'お使いの PHP 4.2.3 にはマルチバイト文字 (mbstring) の扱いに重大なバグがあります。PHP のバグレポート 19404 番をご覧ください。このバージョンの PHP はお勧めできません';
+$strPHPExtension = 'PHP 拡張';
 $strPhp = 'PHP コードの作成';
 $strPHPVersion = 'PHP のバージョン';
-$strPleaseSelectPrimaryOrUniqueKey = '主キーまたはユニークなキーを選択してください';
+$strPleaseSelectPrimaryOrUniqueKey = '主キーまたはユニークキーを選択してください';
 $strPmaDocumentation = 'phpMyAdmin のドキュメント';
 $strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> はかならず設定ファイルで設定する必要があります!';
-$strPmaWiki = 'phpMyAdmin wiki';
 $strPolish = 'ポーランド語';
 $strPortrait = '縦向き';
 $strPos1 = '先頭';
 $strPrevious = '前';
-$strPrimary = '主';
 $strPrimaryKeyHasBeenDropped = '主キーを削除しました';
 $strPrimaryKeyName = '主キーの名前は PRIMARY でなければなりません!';
-$strPrimaryKeyWarning = '(主キーはかならず "PRIMARY" という名前でなければなりません。また主キー以外に"PRIMARY"という名前を使ってはなりません!)';
-$strPrint = '印刷';
-$strPrintView = '印刷用画面';
+$strPrimaryKeyWarning = '(主キーはかならず "PRIMARY" という名前でなければなりません。また主キー以外に "PRIMARY" という名前を使ってはなりません!)';
+$strPrimary = '主';
 $strPrintViewFull = '印刷用画面 (全テキストを含む)';
+$strPrintView = '印刷用画面';
+$strPrint = '印刷';
 $strPrivDescAllPrivileges = 'GRANT 以外のすべての特権を付与する';
-$strPrivDescAlter = '既存のテーブル構造の変更を許可する';
 $strPrivDescAlterRoutine = 'ストアドルーチンの修正と削除を許可する';
+$strPrivDescAlter = '既存のテーブル構造の変更を許可する';
 $strPrivDescCreateDb = '新しいデータベースやテーブルの作成を許可する';
 $strPrivDescCreateRoutine = 'ストアドルーチンの作成を許可する';
 $strPrivDescCreateTbl = '新しいテーブルの作成を許可する';
@@ -595,6 +626,7 @@ $strPrivDescCreateView = '新しいビューの作成を許可する';
 $strPrivDescDelete = 'データの削除を許可する';
 $strPrivDescDropDb = 'データベースとテーブルの削除を許可す';
 $strPrivDescDropTbl = 'テーブルの削除を許可する';
+$strPrivDescEvent = 'イベントスケジューラにイベントを設定できるようにする';
 $strPrivDescExecute5 = 'ストアドルーチンの実行を許可する';
 $strPrivDescExecute = 'ストアードプロシジャの実行を許可する (このバージョンの MySQL では無効です)';
 $strPrivDescFile = 'データのインポート、エクスポートを許可する';
@@ -606,8 +638,7 @@ $strPrivDescMaxConnections = '単位時間内に可能な新規接続回数を
 $strPrivDescMaxQuestions = '単位時間内にサーバに送信可能なクエリ数を制限する';
 $strPrivDescMaxUpdates = '単位時間内に実行可能なテーブルないしデータベースの編集コマンド数を制限する';
 $strPrivDescMaxUserConnections = 'ユーザの同時接続数を制限する';
-$strPrivDescProcess3 = '他のユーザのプロセスの停止を許可する';
-$strPrivDescProcess4 = 'プロセス一覧で完全なクエリの表示を許可する';
+$strPrivDescProcess = '全ユーザのプロセスを閲覧できるようにする';
 $strPrivDescReferences = 'このバージョンの MySQL では無効です';
 $strPrivDescReload = 'サーバ設定のリロード、サーバキャッシュのフラッシュを許可する';
 $strPrivDescReplClient = 'スレーブ/マスターの照会を許可する';
@@ -617,10 +648,11 @@ $strPrivDescShowDb = 'データベース総一覧へのアクセスを許可す
 $strPrivDescShowView = 'SHOW CREATE VIEW クエリの実行を許可する';
 $strPrivDescShutdown = 'サーバのシャットダウンを許可する';
 $strPrivDescSuper = '最大接続数に達しているときでも接続を許可する。グローバル変数の設定や他のユーザのスレッドを停止するといった管理操作をする場合はたいていこの設定が必要になります';
+$strPrivDescTrigger = 'トリガの作成・削除を許可する';
 $strPrivDescUpdate = 'データの修正を許可する';
 $strPrivDescUsage = '特権はありません';
-$strPrivileges = '特権';
 $strPrivilegesReloaded = '特権を正常にリロードしました';
+$strPrivileges = '特権';
 $strProcedures = 'プロシジャ';
 $strProcesses = 'プロセス';
 $strProcesslist = 'プロセス一覧';
@@ -642,11 +674,14 @@ $strQueryType = 'クエリ種別';
 $strQueryWindowLock = '他のウィンドウからクエリを上書きすることはできません';
 
 $strReadRequests = '読み込みリクエスト数';
+$strRebuild = '再構築';
 $strReceived = '受信済';
 $strRecommended = '推奨';
 $strRecords = 'レコード数';
 $strReferentialIntegrity = '参照整合性の確認:';
 $strRefresh = '再描画';
+$strRelationalDisplayField = 'リレーション表示フィールド';
+$strRelationalKey = 'リレーションキー';
 $strRelationalSchema = 'リレーショナルスキーマ';
 $strRelationDeleted = 'リレーションを削除しました';
 $strRelationNotWorking = 'リンクテーブルを処理するための追加機能が無効になっています。理由については%sこちら%sをご覧ください';
@@ -656,11 +691,13 @@ $strRelationView = 'リレーションビュー';
 $strReload = 'リロード';
 $strReloadingThePrivileges = '特権をリロードしています';
 $strReloadPrivileges = '特権をリロードする';
+$strRemovePartitioning = 'パーティションを削除';
 $strRemoveSelectedUsers = '選択したユーザを削除する';
 $strRenameDatabaseOK = 'データベース %s を %s にリネームしました';
-$strRenameTable = 'リネーム後のテーブル名';
 $strRenameTableOK = 'テーブル %s を %s にリネームしました';
+$strRenameTable = 'リネーム後のテーブル名';
 $strRepairTable = 'テーブルを修復する';
+$strRepair = '修復';
 $strReplaceNULLBy = 'NULL の代替文字列';
 $strReplaceTable = 'テーブルデータを差し替えるファイル';
 $strReplication = 'レプリケーション';
@@ -668,35 +705,38 @@ $strReset = 'リセット';
 $strResourceLimits = 'リソースの制限';
 $strRestartInsertion = '%s 行から挿入を再開する';
 $strReType = 'もう一度入力してください';
-$strRevoke = '取り消し';
-$strRevokeAndDelete = '特権をすべて取り消してユーザを削除する';
 $strRevokeAndDeleteDescr = 'USAGE 特権については特権をリロードするまで残ります';
+$strRevokeAndDelete = '特権をすべて取り消してユーザを削除する';
 $strRevokeMessage = '%s の特権を取り消しました';
+$strRevoke = '取り消し';
 $strRomanian = 'ルーマニア語';
 $strRoutineReturnType = '返り値の種類';
 $strRoutines = 'ルーチン';
 $strRowLength = '行の長さ';
-$strRows = '行';
+$strRowsAffected = '%1$d 行変更しました。';
+$strRowsDeleted = '%1$d 行削除しました。';
 $strRowsFrom = '開始行';
+$strRowsInserted = '%1$d 行挿入しました。';
 $strRowSize = ' 行のサイズ ';
 $strRowsModeFlippedHorizontal = '水平 (ヘッダも回転)';
 $strRowsModeHorizontal = '水平';
 $strRowsModeOptions = 'モード: %s (%s セルごとにヘッダを表示)';
 $strRowsModeVertical = '垂直';
 $strRowsStatistic = '行の統計';
+$strRows = '行';
 $strRunning = '実行環境: %s';
 $strRunQuery = 'クエリを実行する';
-$strRunSQLQuery = 'データベース %s 上でクエリを実行する';
 $strRunSQLQueryOnServer = 'サーバ %s 上でクエリを実行する';
+$strRunSQLQuery = 'データベース %s 上でクエリを実行する';
 $strRussian = 'ロシア語';
 
-$strSave = '保存する';
 $strSaveOnServer = 'サーバ上のディレクトリ %s に保存する';
 $strSavePosition = '位置を保存';
+$strSave = '保存する';
 $strScaleFactorSmall = '倍率が小さすぎるためスキーマが 1 ページに収まりません';
-$strSearch = '検索';
 $strSearchFormTitle = 'データベース内検索';
-$strSearchInTables = 'テーブル内検索:';
+$strSearchInField = '検索するフィールド:';
+$strSearchInTables = '検索するテーブル:';
 $strSearchNeedle = '検索する単語や値 (ワイルドカード: "%"):';
 $strSearchOption1 = 'いずれかの単語を含む';
 $strSearchOption2 = 'すべての単語を含む';
@@ -704,6 +744,7 @@ $strSearchOption3 = '完全一致';
 $strSearchOption4 = '正規表現';
 $strSearchResultsFor = '"<i>%s</i>" の検索結果 %s:';
 $strSearchType = '検索条件:';
+$strSearch = '検索';
 $strSecretRequired = '設定ファイルが秘密のパスフレーズ (blowfish_secret) を必要とするようになりました';
 $strSelectADb = 'データベースを選択してください';
 $strSelectAll = '全選択';
@@ -719,9 +760,9 @@ $strServer = 'サーバ';
 $strServerChoice = 'サーバの選択';
 $strServerNotResponding = 'サーバが応答しません';
 $strServers = 'サーバ';
-$strServerStatus = 'ランタイム情報';
 $strServerStatusDelayedInserts = '遅延インサート';
 $strServerStatusUptime = 'この MySQL サーバの稼働時間: %s (起動時刻: %s)';
+$strServerStatus = 'ランタイム情報';
 $strServerTabVariables = '変数';
 $strServerTrafficNotes = '<b>サーバトラフィック</b>: これらの表は MySQL サーバ起動以後のネットワークトラフィックの統計です';
 $strServerVars = 'サーバ変数と設定値';
@@ -732,7 +773,6 @@ $strSetEnumVal = 'フィールド種別が「enum」ないし「set」の場合
 $strShowAll = 'すべて表示';
 $strShowColor = '色表示';
 $strShowDatadictAs = 'データ辞書形式';
-$strShow = '表示';
 $strShowFullQueries = 'クエリ全体を表示';
 $strShowGrid = 'グリッドを表示';
 $strShowHideLeftMenu = '左側のメニューを表示する/隠す';
@@ -854,6 +894,7 @@ $strShowStatusThreads_runningDescr = 'スリープしていないスレッドの
 $strShowTableDimension = 'テーブルの大きさを表示する';
 $strShowTables = 'テーブルを表示する';
 $strShowThisQuery = ' 実行したクエリをここに表示する';
+$strShow = '表示';
 $strSimplifiedChinese = '簡体字中国語';
 $strSingly = '(1 回)';
 $strSize = 'サイズ';
@@ -894,10 +935,11 @@ $strStrucExcelCSV = 'MS Excel 用の CSV';
 $strStrucNativeExcel = 'MS Excel のネイティブ形式';
 $strStrucOnly = '構造のみ';
 $strStructPropose = 'テーブル構造を確認する';
-$strStructure = '構造';
 $strStructureForView = 'ビュー用の構造';
+$strStructure = '構造';
 $strSubmit = '実行する';
 $strSuccess = 'SQL は正常に実行されました';
+$strSuhosin = 'Suhosin が稼働しているため問題が発生する可能性があります。詳しくは%sドキュメント%sをご覧ください。';
 $strSum = '合計';
 $strSwedish = 'スウェーデン語';
 $strSwitchToDatabase = 'コピーしたデータベースに切り替える';
@@ -905,8 +947,10 @@ $strSwitchToTable = 'コピーしたテーブルに切り替える';
 
 $strTable = 'テーブル';
 $strTableAlreadyExists = 'テーブル %s は既に存在します!';
+$strTableAlteredSuccessfully = 'テーブル %1$s を変更しました';
 $strTableComments = 'テーブルのコメント';
 $strTableEmpty = 'テーブル名が空です!';
+$strTableHasBeenCreated = 'テーブル %1$s を作成しました。';
 $strTableHasBeenDropped = 'テーブル %s を削除しました';
 $strTableHasBeenEmptied = 'テーブル %s を空にしました';
 $strTableHasBeenFlushed = 'テーブル %s をフラッシュしました';
@@ -921,6 +965,7 @@ $strTakeIt = 'これにする';
 $strTblPrivileges = 'テーブル固有の特権';
 $strTempData = '一時データ';
 $strTextAreaLength = ' 長さによってはこのフィールドを<br /> 修正できなくなる場合もあります';
+$strTexyText = 'Texy! テキスト';
 $strThai = 'タイ語';
 $strTheme = 'テーマ / スタイル';
 $strThemeDefaultNotFound = 'デフォルトテーマ %s が見つかりません!';
@@ -931,16 +976,16 @@ $strThemePathNotFound = 'テーマ %s のテーマパスが見つかりません
 $strThisHost = 'このホスト';
 $strThreads = 'スレッド';
 $strThreadSuccessfullyKilled = 'スレッド %s は正常終了しました';
-$strTime = '時間';
 $strTimeoutInfo = '直前のインポートはタイムアウトしました。再送信すると位置 %d から再開されます';
 $strTimeoutNothingParsed = 'ただし、最後に実行したときはまったくデータを解析できませんでした。ふつうは PHP の時間制限を伸ばさない限りこのデータのインポートはできません';
 $strTimeoutPassed = 'スクリプトがタイムアウトしました。インポートを完了させたいのであれば同じファイルを再送信すればインポートが再開されます';
+$strTime = '時間';
 $strToFromPage = '開始/終了ページ';
 $strToggleScratchboard = 'スクラッチボードを切り替える';
 $strToggleSmallBig = '大小を切り替える';
 $strToSelectRelation = 'リレーションを選択します:';
-$strTotal = '合計';
 $strTotalUC = '合計';
+$strTotal = '合計';
 $strTraditionalChinese = '繁体字中国語';
 $strTraditionalSpanish = 'スペイン語 (伝統表記)';
 $strTraffic = 'トラフィック';
@@ -985,10 +1030,9 @@ $strUploadLimit = 'アップロードしようとしたファイルが大きす
 $strUploadsNotAllowed = 'このサーバではファイルのアップロードはできません';
 $strUsage = '使用量';
 $strUseBackquotes = 'テーブル名やフィールド名を逆クォートで囲む';
-$strUsedPhpExtensions = '使用中の PHP 拡張';
 $strUseHostTable = 'ホストテーブルを使う';
-$strUserAlreadyExists = 'ユーザ %s は既に存在します!';
 $strUser = 'ユーザ';
+$strUserAlreadyExists = 'ユーザ %s は既に存在します!';
 $strUserEmpty = 'ユーザ名が空です!';
 $strUserName = 'ユーザ名';
 $strUserNotFound = '特権テーブルには選択したユーザがいません';
@@ -1006,24 +1050,26 @@ $strValue = '値';
 $strVar = '変数';
 $strVersionInformation = 'バージョン情報';
 $strView = 'ビュー';
-$strViewDump = 'テーブルのダンプ(スキーマ)表示';
 $strViewDumpDatabases = 'データベースのダンプ(スキーマ)表示';
 $strViewDumpDB = 'DB のダンプ(スキーマ)表示';
+$strViewDump = 'テーブルのダンプ(スキーマ)表示';
+$strViewHasAtLeast = 'このビューの最低行数。詳しくは%sドキュメント%sをご覧ください。';
 $strViewHasBeenDropped = 'ビュー %s を破棄しました';
-$strViewMaxExactCount = 'ビューの行数が %s を越えました。%sドキュメント%s をご覧ください';
 $strViewName = 'VIEW の名前';
 
-$strWebServerUploadDirectory = 'ウェブサーバ上のアップロードディレクトリ';
 $strWebServerUploadDirectoryError = '指定したアップロードディレクトリが利用できません';
+$strWebServerUploadDirectory = 'ウェブサーバ上のアップロードディレクトリ';
+$strWebServer = 'Web サーバ';
 $strWelcome = '%s へようこそ';
-$strWestEuropean = '西ヨーロッパ言語';
+$strWestEuropean = '西ヨーロッパ諸語';
+$strWiki = 'Wiki';
 $strWildcard = 'ワイルドカード';
 $strWindowNotFound = 'ターゲットとなるブラウザウィンドウを更新できませんでした。親ウィンドウを閉じたか、ブラウザのセキュリティ設定でクロスウィンドウの更新をブロックしているものと思われます';
 $strWithChecked = 'チェックしたものを:';
 $strWriteRequests = '書き込みリクエスト数';
 $strWrongUser = 'ユーザ名ないしパスワードが間違っています。<br />アクセスは拒否されました';
 
-$strXkana = '全角カナへ変換する'; // convert to X208-kana
+$strXkana = '全角カナへ変換する';
 $strXML = 'XML';
 
 $strYes = 'はい';
@@ -1031,5 +1077,4 @@ $strYes = 'はい';
 $strZeroRemovesTheLimit = '注意: オプションを 0 (ゼロ)に設定すると制限を解除します';
 $strZip = '"zip 形式"';
 
-$strSuhosin = 'Suhosin が組み込まれているため問題が発生する可能性があります。詳しくは %sdocumentation%s をご覧ください。';  
 ?>
