@@ -1,5 +1,5 @@
 <?php
-/* $Id: malay-utf-8.inc.php 9261 2006-08-09 12:55:40Z lem9 $ */
+/* $Id: malay-utf-8.inc.php 11613 2008-09-25 15:55:22Z nijel $ */
 
 /*
 Projek Penterjemahan (l10n) phpmyadmin.net boleh diakses di laman http://shapik.johordt.com/l10n
@@ -46,7 +46,6 @@ $strAddSearchConditions = 'Tambah kriteria carian (badan bagi klausa "where"):';
 $strAddToIndex = 'Tambah ke indeks &nbsp;%s&nbsp;kolum';
 $strAddUserMessage = 'Anda telah menambah pengguna baru.';
 $strAddUser = 'Tambah Pengguna Baru';
-$strAffectedRows = 'Baris yang terlibat:';
 $strAfterInsertBack = 'Kembali ke muka sebelumnya';
 $strAfterInsertNewInsert = 'Tambah baris yang baru';
 $strAfter = 'Selepas %s';
@@ -76,7 +75,6 @@ $strBookmarkQuery = 'Tandabuku kueri-SQL';
 $strBookmarkThis = 'andabuku kueri-SQL ini';
 $strBookmarkView = 'Paparan sahaja';
 $strBrowse = 'Lungsur';
-$strBzError = 'phpMyAdmin tidak dapat memampatkan longgokan kerana terdapat masalah dalam sambungan Bz2 didalam php versi ini. Anda digalakkan untuk mengubah <code>$cfg[\'BZipDump\']</code> di fail konfigurasi phpMyAdmin kepada <code>FALSE</code>. Jika anda ingin menggunakan sambungan Bz2, anda digalakkan untuk meningkatkan versi php anda. Sila lihat laporan pepijat php %s untuk keterangan lanjut.';
 $strBzip = 'bzipped';
 
 $strCannotLogin = 'Tidak boleh log-masuk ke server MySQL';
@@ -122,7 +120,6 @@ $strDataDict = 'Kamus Data';
 $strDataOnly = 'Data sahaja';
 $strDefault = 'Asal';
 $strDeleted = 'Baris telah dipadam';
-$strDeletedRows = 'Baris dipadam:';
 $strDelete = 'Padam';
 $strDescending = 'Menurun';
 $strDisabled = 'Tidak Membenarkan';
@@ -157,7 +154,6 @@ $strExtra = 'Ekstra';
 $strFailedAttempts = 'Percubaan Gagal';
 $strFieldHasBeenDropped = 'Medan %s telah digugurkan';
 $strField = 'Medan';
-$strFieldsEmpty = ' Bilangan medan adalah kosong! ';
 $strFieldsEnclosedBy = 'Medan disertai oleh';
 $strFieldsEscapedBy = 'Medan dilarikan oleh';
 $strFields = 'Medan';
@@ -177,7 +173,6 @@ $strGo = 'Pergi';
 $strGzip = '"digzip"';
 
 $strHasBeenAltered = 'telah diubahsuai.';
-$strHasBeenCreated = 'telah dicipta.';
 $strHaveToShow = 'Anda mesti pilih sekurang-kurangnya satu Kolum untuk dipapar';
 $strHomepageOfficial = 'Laman Rasmi phpMyAdmin';
 $strHome = 'Rumah';
@@ -187,7 +182,6 @@ $strHost = 'Hos';
 $strId = 'ID';
 $strIdxFulltext = 'Tekspenuh';
 $strIgnore = 'Abai';
-$strImportDocSQL = 'Import Fail docSQL';
 $strIndexes = 'Indeks';
 $strIndexHasBeenDropped = 'Indeks %s telah digugurkan';
 $strIndex = 'Indeks';
@@ -195,7 +189,6 @@ $strIndexName = 'Nama indeks&nbsp;:';
 $strIndexType = 'Jenis indeks&nbsp;:';
 $strInsecureMySQL = 'Fail Konfigurasi anda mengandungi pelengkapan (root tidak berkata laluan) yang bersesuaian dengan privilej akaun MySQL. Pelayan MySQL anda dilaksanakan dengan pelengkapan asas, ianya terdedah kepada pencerobohan, dan anda hendaklah membetulkan lubang keselamatan ini.';
 $strInsertAsNewRow = 'Selitkan baris baru';
-$strInsertedRows = 'Baris diselit:';
 $strInsert = 'Selit';
 $strInUse = 'sedang digunakan';
 
@@ -225,8 +218,6 @@ $strMoveTable = 'Pindahkan jadual ke (pangkalandata<b>.</b>jadual):';
 $strMySQLCharset = 'Set Aksara MySQL';
 $strMySQLSaid = 'MySQL berkata: ';
 $strMySQLShowProcess = 'Papar proses';
-$strMySQLShowStatus = 'Papar maklumat masalaksana MySQL';
-$strMySQLShowVars = 'Papar pembolehubah sistem MySQL';
 
 $strName = 'Nama';
 $strNext = 'Berikut';
@@ -270,7 +261,6 @@ $strPdfDbSchema = 'Skema bagi pangkalan data "%s" database - Laman %s';
 $strPdfInvalidTblName = 'Jadual "%s" tidak wujud!';
 $strPdfNoTables = 'Tiada Jadual';
 $strPerHour = 'per jam';
-$strPHP40203 = 'Anda Menggunakan PHP 4.2.3, dimana terdapat pepijat serius didalam multi-byte strings (mbstring). Lihat Laporan Pepijat PHP 19404. PHP versi ini adalah tidak digalakkan dalam menggunakan phpMyAdmin.';
 $strPhp = 'Cipta Kod PHP';
 $strPHPVersion = 'Versi PHP';
 $strPmaDocumentation = 'Dokumentasi phpMyAdmin';
@@ -438,13 +428,10 @@ $strYes = 'Ya';
 $strZip = '"zipped"';
 
 // To translate:
-$strAbsolutePathToDocSqlDir = 'Please enter the absolute path on webserver to docSQL directory';  //to translate
 $strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
-$strAccessDeniedExplanation = 'phpMyAdmin tried to connect to the MySQL server, and the server rejected the connection. You should check the host, username and password in config.inc.php and make sure that they correspond to the information given by the administrator of the MySQL server.';  //to translate
+$strAccessDeniedExplanation = 'phpMyAdmin tried to connect to the MySQL server, and the server rejected the connection. You should check the host, username and password in your configuration and make sure that they correspond to the information given by the administrator of the MySQL server.';  //to translate
 $strAddAutoIncrement = 'Add AUTO_INCREMENT value';  //to translate
 $strAddConstraints = 'Add constraints';  //to translate
-$strAddedColumnComment = 'Added comment for column';  //to translate
-$strAddedColumnRelation = 'Added relation for column';  //to translate
 $strAddFields = 'Add %s field(s)';  //to translate
 $strAddHeaderComment = 'Add custom comment into header (\\n splits lines)';  //to translate
 $strAddIntoComments = 'Add into comments';//to translate
@@ -458,7 +445,6 @@ $strAndThen = 'and then';  //to translate
 $strApproximateCount = 'May be approximate. See FAQ 3.11';  //to translate
 $strArabic = 'Arabic';  //to translate
 $strArmenian = 'Armenian';  //to translate
-$strAutodetect = 'Autodetect';  //to translate
 $strAutomaticLayout = 'Automatic layout';  //to translate
 
 $strBaltic = 'Baltic';  //to translate
@@ -504,7 +490,6 @@ $strCheckPrivs = 'Check Privileges';  //to translate
 $strCheckPrivsLong = 'Check privileges for database &quot;%s&quot;.';  //to translate
 $strCollation = 'Collation';  //to translate
 $strColumnPrivileges = 'Column-specific privileges'; //to translate
-$strCommentsForTable = 'COMMENTS FOR TABLE';  //to translate
 $strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
 $strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
 $strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
@@ -518,8 +503,6 @@ $strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to transl
 $strCreationDates = 'Creation/Update/Check dates';  //to translate
 $strCroatian = 'Croatian';  //to translate
 $strCSV = 'CSV';  //to translate
-$strCSVImportOptions = 'CSV options';  //to translate
-$strCSVOptions = 'CSV options';//to translate
 $strCyrillic = 'Cyrillic';  //to translate
 $strCzech = 'Czech';  //to translate
 $strCzechSlovak = 'Czech-Slovak';  //to translate
@@ -527,7 +510,6 @@ $strCzechSlovak = 'Czech-Slovak';  //to translate
 $strDanish = 'Danish';  //to translate
 $strDatabaseEmpty = 'The database name is empty!';  //to translate
 $strDatabaseExportOptions = 'Database export options';//to translate
-$strDatabaseNoTable = 'This database contains no table!';//to translate
 $strDatabasesDropped = '%s databases have been dropped successfully.';  //to translate
 $strDatabasesStatsDisable = 'Disable Statistics';  //to translate
 $strDatabasesStatsEnable = 'Enable Statistics';  //to translate
@@ -535,15 +517,6 @@ $strDatabasesStatsHeavyTraffic = 'Note: Enabling the Database statistics here mi
 $strDataPages = 'Pages containing data';  //to translate
 $strDBComment = 'Database comment: ';//to translate
 $strDBCopy = 'Copy database to';  //to translate
-$strDBGContext = 'Context';  //to translate
-$strDBGContextID = 'Context ID';  //to translate
-$strDBGHits = 'Hits';  //to translate
-$strDBGLine = 'Line';  //to translate
-$strDBGMaxTimeMs = 'Max time, ms';  //to translate
-$strDBGMinTimeMs = 'Min time, ms';  //to translate
-$strDBGModule = 'Module';  //to translate
-$strDBGTimePerHitMs = 'Time/Hit, ms';  //to translate
-$strDBGTotalTimeMs = 'Total time, ms';  //to translate
 $strDbPrivileges = 'Database-specific privileges'; //to translate
 $strDBRename = 'Rename database to';  //to translate
 $strDbSpecific = 'database-specific';  //to translate
@@ -575,7 +548,6 @@ $strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them
 $strEsperanto = 'Esperanto';  //to translate
 $strEstonian = 'Estonian';  //to translate
 $strExcelEdition = 'Excel edition';  //to translate
-$strExcelOptions = 'Excel options';  //to translate
 $strExecuteBookmarked = 'Execute bookmarked query';  //to translate
 
 $strFileAlreadyExists = 'File %s already exists on server, change filename or check overwrite option.';  //to translate
@@ -603,25 +575,18 @@ $strGreek = 'Greek';  //to translate
 
 $strHandler = 'Handler';  //to translate
 $strHebrew = 'Hebrew';  //to translate
-$strHexForBinary = 'Use hexadecimal for binary fields';  //to translate
 $strHTMLExcel = 'Microsoft Excel 2000';  //to translate
-$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
 $strHTMLWord = 'Microsoft Word 2000';  //to translate
-$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
 $strHungarian = 'Hungarian';  //to translate
 
 $strIcelandic = 'Icelandic';  //to translate
 $strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
 $strIgnoreInserts = 'Use ignore inserts';  //to translate
-$strIgnoringFile = 'Ignoring file %s';  //to translate
 $strImportFiles = 'Import files';  //to translate
 $strImportFormat = 'Format of imported file';  //to translate
 $strImport = 'Import';  //to translate
 $strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
-$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
-$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
 $strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
-$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
 $strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
 $strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
 $strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
@@ -631,8 +596,6 @@ $strInnoDBDataHomeDir = 'Data home directory';  //to translate
 $strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
 $strInnoDBPages = 'pages';  //to translate
 $strInnodbStat = 'InnoDB Status';  //to translate
-$strInsertedRowId = 'Inserted row id:';  //to translate
-$strInternalNotNecessary = '* An internal relation is not necessary when it exists also in InnoDB.';  //to translate
 $strInternalRelations = 'Internal relations';  //to translate
 $strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
 $strInvalidColumnCount = 'Column count has to be larger than zero.';  //to translate
@@ -656,7 +619,6 @@ $strJustDelete = 'Just delete the users from the privilege tables.'; //to transl
 $strKeyCache = 'Key cache';  //to translate
 $strKorean = 'Korean';  //to translate
 
-$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
 $strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
 $strLatchedPages = 'Latched pages';  //to translate
 $strLatexCaption = 'Table caption';//to translate
@@ -665,11 +627,9 @@ $strLatexContinuedCaption = 'Continued table caption';//to translate
 $strLatexContinued = '(continued)';//to translate
 $strLatexIncludeCaption = 'Include table caption';//to translate
 $strLatexLabel = 'Label key';//to translate
-$strLaTeXOptions = 'LaTeX options';  //to translate
 $strLatexStructure = 'Structure of table __TABLE__';//to translate
 $strLatvian = 'Latvian';  //to translate
 $strLDI = 'CSV using LOAD DATA';  //to translate
-$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
 $strLDILocal = 'Use LOCAL keyword';  //to translate
 $strLithuanian = 'Lithuanian';  //to translate
 $strLoginInformation = 'Login Information'; //to translate
@@ -688,7 +648,7 @@ $strMIME_MIMEtype = 'MIME-type';//to translate
 $strMIME_nodescription = 'No Description is available for this transformation.<br />Please ask the author, what %s does.';//to translate
 $strMIME_transformation = 'Browser transformation';//to translate
 $strMIME_transformation_note = 'For a list of available transformation options and their MIME-type transformations, click on %stransformation descriptions%s';//to translate
-$strMIME_transformation_options_note = 'Please enter the values for transformation options using this format: \'a\',\'b\',\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, backslashes it (for example \'\\\\xyz\' or \'a\\\'b\').';//to translate
+$strMIME_transformation_options_note = 'Please enter the values for transformation options using this format: \'a\', 100, b,\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, backslashes it (for example \'\\\\xyz\' or \'a\\\'b\').';//to translate
 $strMIME_transformation_options = 'Transformation options';//to translate
 $strMIMETypesForTable = 'MIME TYPES FOR TABLE';  //to translate
 $strMIME_without = 'MIME-types printed in italics do not have a seperate transformation function';//to translate
@@ -729,7 +689,6 @@ $strPaperSize = 'Paper size';  //to translate
 $strPartialImport = 'Partial import';  //to translate
 $strPasswordChanged = 'The Password for %s was changed successfully.'; // to translate
 $strPasswordHashing = 'Password Hashing';  //to translate
-$strPDFOptions = 'PDF options';  //to translate
 $strPDF = 'PDF';  //to translate
 $strPDFReportTitle = 'Report title';  //to translate
 $strPerMinute = 'per minute';//to translate
@@ -758,8 +717,6 @@ $strPrivDescIndex = 'Allows creating and dropping indexes.'; //to translate
 $strPrivDescInsert = 'Allows inserting and replacing data.'; //to translate
 $strPrivDescLockTables = 'Allows locking tables for the current thread.'; //to translate
 $strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
-$strPrivDescProcess3 = 'Allows killing processes of other users.'; //to translate
-$strPrivDescProcess4 = 'Allows viewing the complete queries in the process list.'; //to translate
 $strPrivDescReferences = 'Has no effect in this MySQL version.'; //to translate
 $strPrivDescReload = 'Allows reloading server settings and flushing the server\'s caches.'; //to translate
 $strPrivDescReplClient = 'Gives the right to the user to ask where the slaves / masters are.'; //to translate
@@ -880,7 +837,7 @@ $strShowStatusKey_readsDescr = 'The number of physical reads of a key block from
 $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
-$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAYED queues.';  //to translate
 $strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
 $strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
@@ -925,8 +882,6 @@ $strSorting = 'Sorting';  //to translate
 $strSpanish = 'Spanish';  //to translate
 $strSQLCompatibility = 'SQL compatibility mode';  //to translate
 $strSQLExportType = 'Export type';  //to translate
-$strSQLImportOptions = 'SQL options';  //to translate
-$strSQLOptions = 'SQL options';//to translate
 $strStatCheckTime = 'Last check';//to translate
 $strStatCreateTime = 'Creation';//to translate
 $strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
@@ -951,7 +906,6 @@ $strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to trans
 $strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
 $strTheme = 'Theme / Style';  //to translate
 $strThisHost = 'This Host'; //to translate
-$strThisNotDirectory = 'This was not a directory';  //to translate
 $strThreads = 'Threads';  //to translate
 $strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
 $strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
@@ -965,7 +919,6 @@ $strTransformation_application_octetstream__hex = 'Displays hexadecimal represen
 $strTransformation_image_jpeg__inline = 'Displays a clickable thumbnail; options: width,height in pixels (keeps the original ratio)';  //to translate
 $strTransformation_image_jpeg__link = 'Displays a link to this image (direct blob download, i.e.).';//to translate
 $strTransformation_image_png__inline = 'See image/jpeg: inline';  //to translate
-$strTransformation_text_plain__dateformat = 'Takes a TIME, TIMESTAMP or DATETIME field and formats it using your local dateformat. First option is the offset (in hours) which will be added to the timestamp (Default: 0). Second option is a different dateformat according to the parameters available for PHPs strftime().';//to translate
 $strTransformation_text_plain__external = 'LINUX ONLY: Launches an external application and feeds the fielddata via standard input. Returns standard output of the application. Default is Tidy, to pretty print HTML code. For security reasons, you have to manually edit the file libraries/transformations/text_plain__external.inc.php and insert the tools you allow to be run. The first option is then the number of the program you want to use and the second option are the parameters for the program. The third parameter, if set to 1 will convert the output using htmlspecialchars() (Default is 1). A fourth parameter, if set to 1 will put a NOWRAP to the content cell so that the whole output will be shown without reformatting (Default 1)';//to translate
 $strTransformation_text_plain__formatted = 'Preserves original formatting of the field. No Escaping is done.';//to translate
 $strTransformation_text_plain__imagelink = 'Displays an image and a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is the width in pixels, third is the height.';  //to translate
@@ -982,7 +935,6 @@ $strUnsupportedCompressionDetected = 'You attempted to load file with unsupporte
 $strUpdComTab = 'Please see Documentation on how to update your Column_comments Table';  //to translate
 $strUpgrade = 'You should upgrade to %s %s or later.';  //to translate
 $strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
-$strUsedPhpExtensions = 'Used PHP extensions';  //to translate
 $strUseHostTable = 'Use Host Table';  //to translate
 $strUserAlreadyExists = 'The user %s already exists!'; //to translate
 $strUserNotFound = 'The selected user was not found in the privilege table.'; //to translate
@@ -996,15 +948,12 @@ $strUseThisValue = 'Use this value';  //to translate
 $strVersionInformation = 'Version information';  //to translate
 $strViewDumpDatabases = 'View dump (schema) of databases';//to translate
 $strViewHasBeenDropped = 'View %s has been dropped';  //to translate
-$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate
 $strView = 'View';  //to translate
 
 $strWestEuropean = 'West European';  //to translate
 $strWildcard = 'wildcard';  //to translate
 $strWindowNotFound = 'The target browser window could not be updated. Maybe you have closed the parent window or your browser is blocking cross-window updates of your security settings';  //to translate
 $strWriteRequests = 'Write requests';  //to translate
-$strWritingCommentNotPossible = 'Writing of comment not possible';  //to translate
-$strWritingRelationNotPossible = 'Writing of relation not possible';  //to translate
 
 $strXML = 'XML';//to translate
 
@@ -1014,16 +963,12 @@ $strQueryResultsOperations = 'Query results operations';  //to translate
 $strAddClause = 'Add %s';  //to translate
 $strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
 $strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
-$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
 $strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
-$strXMLOptions = 'XML options';  //to translate
-$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
-$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
 $strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
 $strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
@@ -1036,4 +981,134 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
+$strPartitionDefinition = 'PARTITION definition';  //to translate
+$strPrivDescTrigger = 'Allows creating and dropping triggers';  //to translate
+$strPrivDescEvent = 'Allows to set up events for the event scheduler';  //to translate
+$strPrivDescProcess = 'Allows viewing processes of all users';  //to translate
+$strPartitioned = 'partitioned';  //to translate
+$strTableAlteredSuccessfully = 'Table %1$s has been altered successfully';  //to translate
+$strDatabaseHasBeenCreated = 'Database %1$s has been created.';  //to translate
+$strTableHasBeenCreated = 'Table %1$s has been created.';  //to translate
+$strForeignKeyError = 'Error creating foreign key on %1$s (check data types)';  //to translate
+$strRowsDeleted = '%1$d row(s) deleted.';  //to translate
+$strRowsAffected = '%1$d row(s) affected.';  //to translate
+$strRowsInserted = '%1$d row(s) inserted.';  //to translate
+$strInsertedRowId = 'Inserted row id: %1$d';  //to translate
+$strIndexesSeemEqual = 'The indexes %1$s and %2$s seem to be equal and one of them could possibly be removed.';  //to translate
+$strPartitionMaintenance = 'Partition maintenance';  //to translate
+$strPartition = 'Partition %s';  //to translate
+$strAnalyze = 'Analyze';  //to translate
+$strCheck = 'Check';  //to translate
+$strOptimize = 'Optimize';  //to translate
+$strRebuild = 'Rebuild';  //to translate
+$strRepair = 'Repair';  //to translate
+$strRemovePartitioning = 'Remove partitioning';  //to translate
+$strSearchInField = 'Inside field:';  //to translate
+$strTexyText = 'Texy! text';  //to translate
+$strDetails = 'Details...';  //to translate
+$strComment = 'Comment';  //to translate
+$strPacked = 'Packed';  //to translate
+$strActions = 'Actions';  //to translate
+$strInterface = 'Interface';  //to translate
+$strSuhosin = 'Server running with Suhosin. Please refer to %sdocumentation%s for possible issues.';  //to translate
+$strEvents = 'Events';  //to translate
+$strForeignKeyRelationAdded = 'FOREIGN KEY relation added';  //to translate
+$strInternalAndForeign = 'An internal relation is not necessary when a corresponding FOREIGN KEY relation exists.';  //to translate
+$strViewHasAtLeast = 'This view has at least this number of rows. Please refer to %sdocumentation%s.';  //to translate
+$strRelationalKey = 'Relational key';  //to translate
+$strRelationalDisplayField = 'Relational display field';  //to translate
+$strPBXTIndexCacheSize = 'Index cache size';  //to translate
+$strPBXTRecordCacheSize = 'Record cache size';  //to translate
+$strPBXTLogCacheSize = 'Log cache size';  //to translate
+$strPBXTLogFileThreshold = 'Log file threshold';  //to translate
+$strPBXTTransactionBufferSize = 'Transaction buffer size';  //to translate
+$strPBXTCheckpointFrequency = 'Checkpoint frequency';  //to translate
+$strPBXTDataLogThreshold = 'Data log threshold';  //to translate
+$strPBXTGarbageThreshold = 'Garbage threshold';  //to translate
+$strPBXTLogBufferSize = 'Log buffer size';  //to translate
+$strPBXTDataFileGrowSize = 'Data file grow size';  //to translate
+$strPBXTRowFileGrowSize = 'Row file grow size';  //to translate
+$strPBXTRowFileGrowSizeDesc = 'The grow size of the row pointer (.xtr) files.';  //to translate
+$strPBXTDataFileGrowSizeDesc = 'The grow size of the handle data (.xtd) files.';  //to translate
+$strPBXTLogBufferSizeDesc = 'The size of the buffer used when writing a data log. The default is 256MB. The engine allocates one buffer per thread, but only if the thread is required to write a data log.';  //to translate
+$strPBXTGarbageThresholdDesc = 'The percentage of garbage in a data log file before it is compacted. This is a value between 1 and 99. The default is 50.';  //to translate
+$strPBXTDataLogThresholdDesc = 'The maximum size of a data log file. The default value is 64MB. PBXT can create a maximum of 32000 data logs, which are used by all tables. So the value of this variable can be increased to increase the total amount of data that can be stored in the database.';  //to translate
+$strPBXTCheckpointFrequencyDesc = 'The amount of data written to the transaction log before a checkpoint is performed. The default value is 24MB.';  //to translate
+$strPBXTTransactionBufferSizeDesc = 'The size of the global transaction log buffer (the engine allocates 2 buffers of this size). The default is 1MB.';  //to translate
+$strPBXTLogFileThresholdDesc = 'The size of a transaction log before rollover, and a new log is created. The default value is 16MB.';  //to translate
+$strPBXTLogCacheSizeDesc = 'The amount of memory allocated to the transaction log cache used to cache on transaction log data. The default is 16MB.';  //to translate
+$strPBXTRecordCacheSizeDesc = 'This is the amount of memory allocated to the record cache used to cache table data. The default value is 32MB. This memory is used to cache changes to the handle data (.xtd) and row pointer (.xtr) files.';  //to translate
+$strPBXTIndexCacheSizeDesc = 'This is the amount of memory allocated to the index cache. Default value is 32MB. The memory allocated here is used only for caching index pages.';  //to translate
+$strPBXTLogFileCount = 'Log file count';  //to translate
+$strPBXTLogFileCountDesc = 'This is the number of transaction log files (pbxt/system/xlog*.xt) the system will maintain. If the number of logs exceeds this value then old logs will be deleted, otherwise they are renamed and given the next highest number.';  //to translate
+$strAsDefined = 'As defined:';  //to translate
+$strWiki = 'Wiki';  //to translate
+$strWebServer = 'Web server';  //to translate
+$strPHPExtension = 'PHP extension';  //to translate
+$strCustomColor = 'Custom color';  //to translate
 ?>
