@@ -1,5 +1,5 @@
 <?php
-/* $Id: mongolian-utf-8.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
+/* $Id: mongolian-utf-8.inc.php 11613 2008-09-25 15:55:22Z nijel $ */
 
 /**
  * Translated by Bayarsaikhan Enkhtaivan
@@ -40,7 +40,6 @@ $strAddToIndex = 'Индекст нэмэх&nbsp;%s&nbsp;багана(ууд)';
 $strAddUserMessage = 'Шинэ хэрэглэгч нэмэгдлээ.';
 $strAddUser = 'Шинэ хэрэглэгч нэмэх';
 $strAdministration = 'Зохион байгуулалт';
-$strAffectedRows = 'Хийгдсэн мөрүүд:';
 $strAfterInsertBack = 'Буцах';
 $strAfterInsertNewInsert = 'Өөр шинэ мөр оруулах';
 $strAfterInsertNext = 'Дараагийн мөрийг засах';
@@ -96,7 +95,6 @@ $strBufferWriteWaitsInPercent = 'Бичихээр хүлээгдэх нь %';
 $strBufferWriteWaits = 'Бичихээр хүлээх';  
 $strBulgarian = 'Болгар';
 $strBusyPages = 'Завгүй хуудсууд';  
-$strBzError = 'phpMyAdmin нь шахаж чадсангүй, учир нь уг PHP хувилбарын Bz2 extension гэмтсэн байна. phpMyAdmin-ы тохиргооны файл дахь <code>$cfg[\'BZipDump\']</code> -ыг <code>FALSE</code> болго. Хэрэв та үүнийг ашигламаар байвал PHP-ийн сүүлийн хувилбарыг татаж үзээрэй. PHP bug report %s-аас дэлгэрэнгүй хар.';
 $strBzip = 'bzip-ээр шахагдсан';
 
 $strCalendar = 'Цагалбар';
@@ -133,7 +131,6 @@ $strCollation = 'Жишилт';
 $strColumnNames = 'Баганын нэрс';
 $strColumnPrivileges = 'Онцгой эрх, баганын эрх';
 $strCommand = 'Команд';
-$strCommentsForTable = 'Хүснэгтийн тайлбар';
 $strComments = 'Тайлбар';
 $strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';
 $strCompleteInserts = 'Оруулалтыг дуусгах';
@@ -193,7 +190,6 @@ $strDefragment = 'Хүснэгт янзлах';
 $strDelayedInserts = 'Давталттай оруулалт хэрэглэх';
 $strDeleteAndFlushDescr = 'Энэ бол цэвэрхэн зам, гэхдээ онцгой эрхийг дахиж дуудна.';
 $strDeleteAndFlush = 'Хэрэглэгчдийг устгаад дараа нь онцгой эрхийг дахин дууд.';
-$strDeletedRows = 'Устгагдсан мөрүүд:';
 $strDeleted = 'Мөр устгагдсан';
 $strDelete = 'Устгах';
 $strDeleting = '%s-г устгаж байна';
@@ -281,7 +277,6 @@ $strGreek = 'Грек';
 $strGzip = 'gzip-ээр шахах';
 
 $strHasBeenAltered = 'өөрчлөгдсөн байна.';
-$strHasBeenCreated = 'үүссэн байна.';
 $strHaveToShow = 'Харуулахын тулд ядаж нэг багана сонго';
 $strHebrew = 'Иврей';
 $strHomepageOfficial = 'phpMyAdmin-ын албан ёсны вэб сайт';
@@ -315,10 +310,7 @@ $strInnoDBPages = 'хуудсууд';
 $strInnodbStat = 'InnoDB байдал';
 $strInsecureMySQL = 'Таны тохиргооны файл нь MySQL-ын анхдагч онцгой эрхийг (нэвтрэгч root нь нууц үггүй) агуулжээ. Таны MySQL сервэр энэ анхдагчаар ажиллаж байгаа нь хэн ч урилгагүй орох боломжийг өгнө. Та хамгаалалтын асуудлаа засах хэрэгтэй';
 $strInsertAsNewRow = 'Шинэ мөр оруулаад';
-$strInsertedRowId = 'Орсон мөрийн id:';
-$strInsertedRows = 'Орсон мөрүүд:';
 $strInsert = 'Оруулах';
-$strInternalNotNecessary = '* An internal relation is not necessary when it exists also in InnoDB.';
 $strInternalRelations = 'Дотоод хамаарал';
 $strInUse = 'хэрэглэгдэж байна';
 $strInvalidColumnCount = 'Баганы тоо тэгээс их байна.';
@@ -400,8 +392,6 @@ $strMySQLCharset = 'MySQL-кодлол';
 $strMySQLConnectionCollation = 'MySQL холболтын кодлол';
 $strMySQLSaid = 'MySQL хэлэх нь: ';
 $strMySQLShowProcess = 'Процесууд харах';
-$strMySQLShowStatus = 'MySQL-ийн ажиллах үеийн мэдээлэл харах';
-$strMySQLShowVars = 'MySQL-ийн системийн утгыг харах';
 
 $strName = 'Нэр';
 $strNext = 'Цааш';
@@ -463,7 +453,6 @@ $strPerMinute = 'минутад';
 $strPerSecond = 'секундэд';
 $strPersian = 'Перс';
 $strPhoneBook = 'Утасны лавлах';
-$strPHP40203 = 'Та PHP 4.2.3 хувилбарыг ашиглаж байна, энэ нь олон-байттай тэмдэгт мөр (mbstring) дээр томоохон нүхтэй юм. PHP нүхний 19404 тайланг харна уу. PHP-ийн энэ хувилбар дээр phpMyAdmin-г ашиглахгүй байхыг зөвлөх байна .';
 $strPhp = 'PHP-код үүсгэх';
 $strPHPVersion = 'PHP хувилбар';
 $strPmaDocumentation = 'phpMyAdmin баримтжилт';
@@ -501,8 +490,6 @@ $strPrivDescLockTables = 'Тухайн процесст хүснэгт түгж
 $strPrivDescMaxConnections = 'Цаг тутамд шинээр холбогдох хэрэглэгчийн тоог хязгаарлах.';
 $strPrivDescMaxQuestions = 'Цаг тутамд хэрэглэгчийн асуулт (query) илгээхийг хязгаарлах.';
 $strPrivDescMaxUpdates = 'Цаг тутамд хэрэглэгчийн хүснэгт эсвэл өгөгдлийн сан солих командыг хязгаарлах.';
-$strPrivDescProcess3 = 'Бусад хэрэглэгчийн процессыг үгүй хийхийг зөвшөөрөх.';
-$strPrivDescProcess4 = 'Процессын жагсаалт дахь дууссан асуултыг харахыг зөвшөөрөх.';
 $strPrivDescReferences = 'MySQL-ын энэ хувилбарт үйлчлэлгүй.';
 $strPrivDescReload = 'Сервэрийн тохиргоог дахин дуудахыг зөвшөөрөх.';
 $strPrivDescReplClient = 'Gives the right to the user to ask where the slaves / masters are.';
@@ -953,9 +940,7 @@ $strTransformation_text_plain__sql = 'Formats text as SQL query with syntax high
 
 $strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
 $strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
-$strUsedPhpExtensions = 'Used PHP extensions';  //to translate
 
-$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate
 
 $strQueryResultsOperations = 'Query results operations';  //to translate
 $strAddClause = 'Add %s';  //to translate
@@ -979,7 +964,6 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
-$strPmaWiki = 'phpMyAdmin wiki';  //to translate
 $strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
 $strDocSQL = 'DocSQL';  //to translate
 $strTableName = 'Table name';  //to translate
@@ -1004,7 +988,6 @@ $strDirectLinks = 'Direct links';  //to translate
 $strHideShowAll = 'Hide/Show all';  //to translate
 $strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
 $strInternalRelationAdded = 'Internal relation added';  //to translate
-$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
 $strRelationDeleted = 'Relation deleted';  //to translate
 $strToSelectRelation = 'To select relation, click :';  //to translate
 $strExportImportToScale = 'Export/Import to scale';  //to translate
@@ -1012,7 +995,6 @@ $strRecommended = 'recommended';  //to translate
 $strToFromPage = 'to/from page';  //to translate
 $strSelectReferencedKey = 'Select referenced key';  //to translate
 $strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
-$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
 $strHelp = 'Help';  //to translate
 $strCancel = 'Cancel';  //to translate
 $strDeleteRelation = 'Delete relation';  //to translate
@@ -1038,7 +1020,6 @@ $strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see F
 $strViewName = 'VIEW name';  //to translate
 $strOptions = 'Options';  //to translate
 $strFiles = 'Files';  //to translate
-$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
 $strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
 $strRoutines = 'Routines';  //to translate
 $strRoutineReturnType = 'Return type';  //to translate
@@ -1048,4 +1029,69 @@ $strRestartInsertion = 'Restart insertion with %s rows';  //to translate
 $strTriggers = 'Triggers';  //to translate
 $strEvent = 'Event';  //to translate
 $strProfiling = 'Profiling';  //to translate
+$strPartitionDefinition = 'PARTITION definition';  //to translate
+$strPrivDescTrigger = 'Allows creating and dropping triggers';  //to translate
+$strPrivDescEvent = 'Allows to set up events for the event scheduler';  //to translate
+$strPrivDescProcess = 'Allows viewing processes of all users';  //to translate
+$strPartitioned = 'partitioned';  //to translate
+$strTableAlteredSuccessfully = 'Table %1$s has been altered successfully';  //to translate
+$strDatabaseHasBeenCreated = 'Database %1$s has been created.';  //to translate
+$strTableHasBeenCreated = 'Table %1$s has been created.';  //to translate
+$strForeignKeyError = 'Error creating foreign key on %1$s (check data types)';  //to translate
+$strRowsDeleted = '%1$d row(s) deleted.';  //to translate
+$strRowsAffected = '%1$d row(s) affected.';  //to translate
+$strRowsInserted = '%1$d row(s) inserted.';  //to translate
+$strInsertedRowId = 'Inserted row id: %1$d';  //to translate
+$strIndexesSeemEqual = 'The indexes %1$s and %2$s seem to be equal and one of them could possibly be removed.';  //to translate
+$strPartitionMaintenance = 'Partition maintenance';  //to translate
+$strPartition = 'Partition %s';  //to translate
+$strAnalyze = 'Analyze';  //to translate
+$strCheck = 'Check';  //to translate
+$strOptimize = 'Optimize';  //to translate
+$strRebuild = 'Rebuild';  //to translate
+$strRepair = 'Repair';  //to translate
+$strRemovePartitioning = 'Remove partitioning';  //to translate
+$strSearchInField = 'Inside field:';  //to translate
+$strTexyText = 'Texy! text';  //to translate
+$strDetails = 'Details...';  //to translate
+$strComment = 'Comment';  //to translate
+$strPacked = 'Packed';  //to translate
+$strActions = 'Actions';  //to translate
+$strInterface = 'Interface';  //to translate
+$strSuhosin = 'Server running with Suhosin. Please refer to %sdocumentation%s for possible issues.';  //to translate
+$strEvents = 'Events';  //to translate
+$strForeignKeyRelationAdded = 'FOREIGN KEY relation added';  //to translate
+$strInternalAndForeign = 'An internal relation is not necessary when a corresponding FOREIGN KEY relation exists.';  //to translate
+$strViewHasAtLeast = 'This view has at least this number of rows. Please refer to %sdocumentation%s.';  //to translate
+$strRelationalKey = 'Relational key';  //to translate
+$strRelationalDisplayField = 'Relational display field';  //to translate
+$strPBXTIndexCacheSize = 'Index cache size';  //to translate
+$strPBXTRecordCacheSize = 'Record cache size';  //to translate
+$strPBXTLogCacheSize = 'Log cache size';  //to translate
+$strPBXTLogFileThreshold = 'Log file threshold';  //to translate
+$strPBXTTransactionBufferSize = 'Transaction buffer size';  //to translate
+$strPBXTCheckpointFrequency = 'Checkpoint frequency';  //to translate
+$strPBXTDataLogThreshold = 'Data log threshold';  //to translate
+$strPBXTGarbageThreshold = 'Garbage threshold';  //to translate
+$strPBXTLogBufferSize = 'Log buffer size';  //to translate
+$strPBXTDataFileGrowSize = 'Data file grow size';  //to translate
+$strPBXTRowFileGrowSize = 'Row file grow size';  //to translate
+$strPBXTRowFileGrowSizeDesc = 'The grow size of the row pointer (.xtr) files.';  //to translate
+$strPBXTDataFileGrowSizeDesc = 'The grow size of the handle data (.xtd) files.';  //to translate
+$strPBXTLogBufferSizeDesc = 'The size of the buffer used when writing a data log. The default is 256MB. The engine allocates one buffer per thread, but only if the thread is required to write a data log.';  //to translate
+$strPBXTGarbageThresholdDesc = 'The percentage of garbage in a data log file before it is compacted. This is a value between 1 and 99. The default is 50.';  //to translate
+$strPBXTDataLogThresholdDesc = 'The maximum size of a data log file. The default value is 64MB. PBXT can create a maximum of 32000 data logs, which are used by all tables. So the value of this variable can be increased to increase the total amount of data that can be stored in the database.';  //to translate
+$strPBXTCheckpointFrequencyDesc = 'The amount of data written to the transaction log before a checkpoint is performed. The default value is 24MB.';  //to translate
+$strPBXTTransactionBufferSizeDesc = 'The size of the global transaction log buffer (the engine allocates 2 buffers of this size). The default is 1MB.';  //to translate
+$strPBXTLogFileThresholdDesc = 'The size of a transaction log before rollover, and a new log is created. The default value is 16MB.';  //to translate
+$strPBXTLogCacheSizeDesc = 'The amount of memory allocated to the transaction log cache used to cache on transaction log data. The default is 16MB.';  //to translate
+$strPBXTRecordCacheSizeDesc = 'This is the amount of memory allocated to the record cache used to cache table data. The default value is 32MB. This memory is used to cache changes to the handle data (.xtd) and row pointer (.xtr) files.';  //to translate
+$strPBXTIndexCacheSizeDesc = 'This is the amount of memory allocated to the index cache. Default value is 32MB. The memory allocated here is used only for caching index pages.';  //to translate
+$strPBXTLogFileCount = 'Log file count';  //to translate
+$strPBXTLogFileCountDesc = 'This is the number of transaction log files (pbxt/system/xlog*.xt) the system will maintain. If the number of logs exceeds this value then old logs will be deleted, otherwise they are renamed and given the next highest number.';  //to translate
+$strAsDefined = 'As defined:';  //to translate
+$strWiki = 'Wiki';  //to translate
+$strWebServer = 'Web server';  //to translate
+$strPHPExtension = 'PHP extension';  //to translate
+$strCustomColor = 'Custom color';  //to translate
 ?>
