@@ -1,5 +1,5 @@
 <?php
-/* $Id: portuguese-utf-8.inc.php 11113 2008-02-09 16:09:54Z lem9 $ */
+/* $Id: portuguese-utf-8.inc.php 11613 2008-09-25 15:55:22Z nijel $ */
 
 /**
  * Portuguese language file by
@@ -42,7 +42,6 @@ $strAddToIndex = 'Adicionar ao índice &nbsp;%s&nbsp;coluna(s)';
 $strAddUser = 'Acrescenta um utilizador';
 $strAddUserMessage = 'Acrescentou um novo utilizador.';
 $strAdministration = 'Administração';
-$strAffectedRows = 'Linhas afectadas:';
 $strAfter = 'Depois %s';
 $strAfterInsertBack = 'Voltar atrás';
 $strAfterInsertNewInsert = 'Inserir novo registo';
@@ -153,7 +152,6 @@ $strDeleteAndFlush = 'Apagar os utilizadores e recarreguar os privilégios a seg
 $strDeleteAndFlushDescr = 'Este é o processo mais limpo, mas recarregar os privilégios poderá demorar um pouco.';
 $strDelete = 'Apagar';
 $strDeleted = 'Registo eliminado';
-$strDeletedRows = 'Linhas apagadas:';
 $strDeleting = 'A apagar %s';
 $strDescending = 'Descendente';
 $strDescription = 'Descrição';
@@ -224,7 +222,6 @@ $strGreek = 'Grego';
 $strGzip = '"Compressão gzip"';
 
 $strHasBeenAltered = 'foi alterado(a).';
-$strHasBeenCreated = 'foi criado(a).';
 $strHaveToShow = 'Tem que escolher pelo menos uma coluna para mostrar';
 $strHebrew = 'Hebráico';
 $strHome = 'Início';
@@ -245,10 +242,7 @@ $strIndexType = 'Tipo de Índice&nbsp;:';
 $strInnodbStat = 'Estado da InnoDB';
 $strInsecureMySQL = 'O seu ficheiro de configuração contem configurações (root sem palavra-passe) que correspondem à conta privilegiada por defeito do MySQL. O servidor MySQL está a correr com este valor por defeito, assim aberto a intrusões, deveria corrigir este buraco de segurança.';
 $strInsertAsNewRow = 'Insere como novo registo';
-$strInsertedRowId = 'Inserir id de linha:';
-$strInsertedRows = 'Registos inseridos :';
 $strInsert = 'Insere';
-$strInternalNotNecessary = '* Não é necessária uma relação interna quando também já existe na InnoDB.';
 $strInternalRelations = 'Relações internas';
 $strInUse = 'em uso';
 
@@ -306,8 +300,6 @@ $strMultilingual = 'multilingua';
 $strMySQLCharset = 'Mapa de Caracteres do mySQL';
 $strMySQLSaid = 'Mensagens do MySQL : ';
 $strMySQLShowProcess = 'Mostra os Processos';
-$strMySQLShowStatus = 'Mostra informação do estado do MySQL';
-$strMySQLShowVars = 'Mostra as variáveis de sistema do MySQL';
 
 $strName = 'Nome';
 $strNext = 'Próximo';
@@ -361,7 +353,6 @@ $strPerHour = 'por hora';
 $strPerMinute = 'por minuto';
 $strPerSecond = 'por segundo';
 $strPhoneBook = 'lista telefónica';
-$strPHP40203 = 'Está a usar o PHP 4.2.3, que tem uma grave falha de segurança com a string multi-byte (mbstring). Veja o relatório de bugs do PHP 19404 - PHP bug report 19404. A utilização desta versão do PHP com o phpMyAdmin não é recomendada.';
 $strPhp = 'Criar código PHP';
 $strPHPVersion = 'versão do PHP';
 $strPmaDocumentation = 'Documentação do phpMyAdmin';
@@ -392,8 +383,6 @@ $strPrivDescInsert = 'Permite inserir e substituir dados.';
 $strPrivDescMaxConnections = 'Limits the number of new connections the user may open per hour.';
 $strPrivDescMaxQuestions = 'Limits the number of queries the user may send to the server per hour.';
 $strPrivDescMaxUpdates = 'Limits the number of commands that change any table or database the user may execute per hour.';
-$strPrivDescProcess3 = 'Permite eliminar processos de outros utilizadores.';
-$strPrivDescProcess4 = 'Permite ver o queries completos na lista de processos.';
 $strPrivDescReferences = 'Não tem efeito nesta versão do MySQL.';
 $strPrivDescSelect = 'Permite ler dados.';
 $strPrivDescShowDb = 'Dá acesso à lista de bases de dados completa.';
@@ -631,14 +620,12 @@ $strBufferReadMisses = 'Read misses';  //to translate
 $strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
 $strBufferWriteWaits = 'Write waits';  //to translate
 $strBusyPages = 'Busy pages';  //to translate
-$strBzError = 'phpMyAdmin was unable to compress the dump because of a broken Bz2 extension in this php version. It is strongly recommended to set the <code>$cfg[\'BZipDump\']</code> directive in your phpMyAdmin configuration file to <code>FALSE</code>. If you want to use the Bz2 compression features, you should upgrade to a later php version. See php bug report %s for details.'; //to translate
 
 $strCalendar = 'Calendar';  //to translate
 $strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
 $strCharsetsAndCollations = 'Character Sets and Collations';  //to translate
 $strCheckOverhead = 'Check tables with overhead';  //to translate
 $strCollation = 'Collation';  //to translate
-$strCommentsForTable = 'COMMENTS FOR TABLE';  //to translate
 $strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
 $strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
 $strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
@@ -948,7 +935,6 @@ $strTransformation_text_plain__substr = 'Only shows part of a string. First opti
 
 $strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
 $strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
-$strUsedPhpExtensions = 'Used PHP extensions';  //to translate
 $strUserOverview = 'User overview'; //to translate
 $strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
 
@@ -956,7 +942,6 @@ $strValidatorError = 'The SQL validator could not be initialized. Please check i
 $strVersionInformation = 'Version information';  //to translate
 $strViewDumpDatabases = 'View dump (schema) of databases';//to translate
 $strViewHasBeenDropped = 'View %s has been dropped';  //to translate
-$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate
 $strView = 'View';  //to translate
 
 $strWildcard = 'wildcard';  //to translate
@@ -985,7 +970,6 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
-$strPmaWiki = 'phpMyAdmin wiki';  //to translate
 $strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
 $strDocSQL = 'DocSQL';  //to translate
 $strTableName = 'Table name';  //to translate
@@ -1010,7 +994,6 @@ $strDirectLinks = 'Direct links';  //to translate
 $strHideShowAll = 'Hide/Show all';  //to translate
 $strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
 $strInternalRelationAdded = 'Internal relation added';  //to translate
-$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
 $strRelationDeleted = 'Relation deleted';  //to translate
 $strToSelectRelation = 'To select relation, click :';  //to translate
 $strExportImportToScale = 'Export/Import to scale';  //to translate
@@ -1018,7 +1001,6 @@ $strRecommended = 'recommended';  //to translate
 $strToFromPage = 'to/from page';  //to translate
 $strSelectReferencedKey = 'Select referenced key';  //to translate
 $strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
-$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
 $strHelp = 'Help';  //to translate
 $strCancel = 'Cancel';  //to translate
 $strDeleteRelation = 'Delete relation';  //to translate
@@ -1044,7 +1026,6 @@ $strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see F
 $strViewName = 'VIEW name';  //to translate
 $strOptions = 'Options';  //to translate
 $strFiles = 'Files';  //to translate
-$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
 $strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
 $strRoutines = 'Routines';  //to translate
 $strRoutineReturnType = 'Return type';  //to translate
@@ -1054,5 +1035,69 @@ $strRestartInsertion = 'Restart insertion with %s rows';  //to translate
 $strTriggers = 'Triggers';  //to translate
 $strEvent = 'Event';  //to translate
 $strProfiling = 'Profiling';  //to translate
+$strPartitionDefinition = 'PARTITION definition';  //to translate
+$strPrivDescTrigger = 'Allows creating and dropping triggers';  //to translate
+$strPrivDescEvent = 'Allows to set up events for the event scheduler';  //to translate
+$strPrivDescProcess = 'Allows viewing processes of all users';  //to translate
+$strPartitioned = 'partitioned';  //to translate
+$strTableAlteredSuccessfully = 'Table %1$s has been altered successfully';  //to translate
+$strDatabaseHasBeenCreated = 'Database %1$s has been created.';  //to translate
+$strTableHasBeenCreated = 'Table %1$s has been created.';  //to translate
+$strForeignKeyError = 'Error creating foreign key on %1$s (check data types)';  //to translate
+$strRowsDeleted = '%1$d row(s) deleted.';  //to translate
+$strRowsAffected = '%1$d row(s) affected.';  //to translate
+$strRowsInserted = '%1$d row(s) inserted.';  //to translate
+$strInsertedRowId = 'Inserted row id: %1$d';  //to translate
+$strIndexesSeemEqual = 'The indexes %1$s and %2$s seem to be equal and one of them could possibly be removed.';  //to translate
+$strPartitionMaintenance = 'Partition maintenance';  //to translate
+$strPartition = 'Partition %s';  //to translate
+$strAnalyze = 'Analyze';  //to translate
+$strCheck = 'Check';  //to translate
+$strOptimize = 'Optimize';  //to translate
+$strRebuild = 'Rebuild';  //to translate
+$strRepair = 'Repair';  //to translate
+$strRemovePartitioning = 'Remove partitioning';  //to translate
+$strSearchInField = 'Inside field:';  //to translate
+$strTexyText = 'Texy! text';  //to translate
+$strDetails = 'Details...';  //to translate
+$strComment = 'Comment';  //to translate
+$strPacked = 'Packed';  //to translate
+$strActions = 'Actions';  //to translate
+$strInterface = 'Interface';  //to translate
 $strSuhosin = 'Server running with Suhosin. Please refer to %sdocumentation%s for possible issues.';  //to translate
+$strEvents = 'Events';  //to translate
+$strForeignKeyRelationAdded = 'FOREIGN KEY relation added';  //to translate
+$strInternalAndForeign = 'An internal relation is not necessary when a corresponding FOREIGN KEY relation exists.';  //to translate
+$strViewHasAtLeast = 'This view has at least this number of rows. Please refer to %sdocumentation%s.';  //to translate
+$strRelationalKey = 'Relational key';  //to translate
+$strRelationalDisplayField = 'Relational display field';  //to translate
+$strPBXTIndexCacheSize = 'Index cache size';  //to translate
+$strPBXTRecordCacheSize = 'Record cache size';  //to translate
+$strPBXTLogCacheSize = 'Log cache size';  //to translate
+$strPBXTLogFileThreshold = 'Log file threshold';  //to translate
+$strPBXTTransactionBufferSize = 'Transaction buffer size';  //to translate
+$strPBXTCheckpointFrequency = 'Checkpoint frequency';  //to translate
+$strPBXTDataLogThreshold = 'Data log threshold';  //to translate
+$strPBXTGarbageThreshold = 'Garbage threshold';  //to translate
+$strPBXTLogBufferSize = 'Log buffer size';  //to translate
+$strPBXTDataFileGrowSize = 'Data file grow size';  //to translate
+$strPBXTRowFileGrowSize = 'Row file grow size';  //to translate
+$strPBXTRowFileGrowSizeDesc = 'The grow size of the row pointer (.xtr) files.';  //to translate
+$strPBXTDataFileGrowSizeDesc = 'The grow size of the handle data (.xtd) files.';  //to translate
+$strPBXTLogBufferSizeDesc = 'The size of the buffer used when writing a data log. The default is 256MB. The engine allocates one buffer per thread, but only if the thread is required to write a data log.';  //to translate
+$strPBXTGarbageThresholdDesc = 'The percentage of garbage in a data log file before it is compacted. This is a value between 1 and 99. The default is 50.';  //to translate
+$strPBXTDataLogThresholdDesc = 'The maximum size of a data log file. The default value is 64MB. PBXT can create a maximum of 32000 data logs, which are used by all tables. So the value of this variable can be increased to increase the total amount of data that can be stored in the database.';  //to translate
+$strPBXTCheckpointFrequencyDesc = 'The amount of data written to the transaction log before a checkpoint is performed. The default value is 24MB.';  //to translate
+$strPBXTTransactionBufferSizeDesc = 'The size of the global transaction log buffer (the engine allocates 2 buffers of this size). The default is 1MB.';  //to translate
+$strPBXTLogFileThresholdDesc = 'The size of a transaction log before rollover, and a new log is created. The default value is 16MB.';  //to translate
+$strPBXTLogCacheSizeDesc = 'The amount of memory allocated to the transaction log cache used to cache on transaction log data. The default is 16MB.';  //to translate
+$strPBXTRecordCacheSizeDesc = 'This is the amount of memory allocated to the record cache used to cache table data. The default value is 32MB. This memory is used to cache changes to the handle data (.xtd) and row pointer (.xtr) files.';  //to translate
+$strPBXTIndexCacheSizeDesc = 'This is the amount of memory allocated to the index cache. Default value is 32MB. The memory allocated here is used only for caching index pages.';  //to translate
+$strPBXTLogFileCount = 'Log file count';  //to translate
+$strPBXTLogFileCountDesc = 'This is the number of transaction log files (pbxt/system/xlog*.xt) the system will maintain. If the number of logs exceeds this value then old logs will be deleted, otherwise they are renamed and given the next highest number.';  //to translate
+$strAsDefined = 'As defined:';  //to translate
+$strWiki = 'Wiki';  //to translate
+$strWebServer = 'Web server';  //to translate
+$strPHPExtension = 'PHP extension';  //to translate
+$strCustomColor = 'Custom color';  //to translate
 ?>
