@@ -1,5 +1,5 @@
 <?php
-/* $Id: spanish-utf-8.inc.php 10539 2007-07-28 14:33:42Z lem9 $ */
+/* $Id: spanish-utf-8.inc.php 11584 2008-09-14 11:39:31Z lem9 $ */
 
 $charset = 'utf-8';
 $allow_recoding = TRUE;
@@ -23,6 +23,7 @@ $strAccessDenied = 'Acceso denegado ';
 $strAccessDeniedCreateConfig = 'La razón más probable es que usted no creó un archivo de configuración. Utilice %1$ssetup script%2$s para crear una.';
 $strAccessDeniedExplanation = 'phpMyAdmin intentó conectarse con el servidor MySQL, y el servidor rechazó esta conexión. Deberá revisar el host, nombre de usuario y contraseña en config.inc.php y asegurarse que corresponden con la información provista por el administrador del servidor MySQL.';
 $strAction = 'Acción';
+$strActions = 'Accciones';
 $strAddAutoIncrement = 'Añadir el valor AUTO_INCREMENT';
 $strAddClause = 'Añada %s';
 $strAddConstraints = 'Añadir restricciones';
@@ -39,7 +40,6 @@ $strAddToIndex = 'Añadir al índice &nbsp;%s&nbsp;columna(s)';
 $strAddUser = 'Agregar un nuevo usuario';
 $strAddUserMessage = 'Ha agregado un nuevo usuario.';
 $strAdministration = 'Administración';
-$strAffectedRows = 'Filas afectadas: ';
 $strAfter = 'Después de %s';
 $strAfterInsertBack = 'Volver';
 $strAfterInsertNewInsert = 'Insertar un nuevo registro';
@@ -49,6 +49,7 @@ $strAllowInterrupt = 'Permita la interrupción de la importación en el caso de
 $strAllTableSameWidth = '¿Mostrar todas las tablas que tienen el mismo ancho?';
 $strAll = 'Todos/as';
 $strAlterOrderBy = 'Modificar el ORDER BY de la tabla';
+$strAnalyze = 'Analice';
 $strAnalyzeTable = 'Analizar la tabla';
 $strAndThen = 'y luego';
 $strAnd = 'y luego';
@@ -62,6 +63,7 @@ $strAPrimaryKey = 'Se añadió una clave primaria en %s';
 $strArabic = 'Árabe';
 $strArmenian = 'Armenio';
 $strAscending = 'Ascendente';
+$strAsDefined = 'Como fuera definido:';
 $strAtBeginningOfTable = 'Al comienzo de la tabla';
 $strAtEndOfTable = 'Al final de la tabla';
 $strAttr = 'Atributos';
@@ -100,7 +102,6 @@ $strBufferWriteWaits = 'Escribir las esperas';
 $strBufferWriteWaitsInPercent = 'Escribir las esperas en %';
 $strBulgarian = 'Búlgaro';
 $strBusyPages = 'Páginas activas'; 
-$strBzError = 'Si desea usar las opciones de compresión Bz2, deberá actualizar su php a una versión más reciente. phpMyAdmin no fue capaz de comprimir el dump debido a que está dañada o inaccesible la extensión Bz2 en esta versión de php. Le recomendamos que cambie el parámetro <code>$cfg[\'BZipDump\']</code> en su archivo de configuración phpMyAdmin a <code>FALSE</code>. Lea el reporte de "bugs" de php %s para mayor información.';
 $strBzip = '"Comprimido con bzip"';
 
 $strCalendar = 'Calendario';
@@ -133,6 +134,7 @@ $strCheckAll = 'Marcar todos/as';
 $strCheckOverhead = 'Marcar las tablas con residuo a depurar';
 $strCheckPrivsLong = 'Revisar los privilegios para la base de datos &quot;%s&quot;.';
 $strCheckPrivs = 'Revisar los privilegios';
+$strCheck = 'Revise';
 $strCheckTable = 'Revisar la tabla';
 $strChoosePage = 'Elegir la página a editar';
 $strColComFeat = 'Mostrando los comentarios de la columna';
@@ -140,8 +142,8 @@ $strCollation = 'Cotejamiento';
 $strColumnNames = 'Nombre de las columnas';
 $strColumnPrivileges = 'Privilegios específicos para la columna';
 $strCommand = 'Comando';
+$strComment = 'Comentario';
 $strComments = 'Comentarios';
-$strCommentsForTable = 'COMENTARIOS PARA LA TABLA';
 $strCompatibleHashing = 'Compatible con MySQL&nbsp;4.0';
 $strCompleteInserts = 'Completar los INSERTS';
 $strCompression = 'Compresión';
@@ -179,6 +181,7 @@ $strCreationDates = 'Fechas de creación/actualización/revisión';
 $strCriteria = 'Criterio';
 $strCroatian = 'Croata';
 $strCSV = 'CSV';
+$strCustomColor = 'Cambiar el color';
 $strCyrillic = 'Cirílico';
 $strCzech = 'Checo';
 $strCzechSlovak = 'Checo-Eslovaco';
@@ -187,6 +190,7 @@ $strDanish = 'Danés';
 $strDatabase = 'Base de datos';
 $strDatabaseEmpty = '¡El nombre de la base de datos está vacío!';
 $strDatabaseExportOptions = 'Opciones de exportación de la base de datos';
+$strDatabaseHasBeenCreated = 'La base de datos %1$s se creó.';
 $strDatabaseHasBeenDropped = 'La base de datos %s ha sido eliminada.';
 $strDatabases = 'Bases de datos';
 $strDatabasesDropped = '%s bases de datos han sido eliminadas exitosamente.';
@@ -213,7 +217,6 @@ $strDeleteAndFlush = 'Borrar a los usuarios y luego volver a cargar los privileg
 $strDeleteAndFlushDescr = 'Este es el modo más limpio, pero volver a cargar los privilegios puede tomar tiempo.';
 $strDelete = 'Borrar';
 $strDeleted = 'La fila se ha borrado';
-$strDeletedRows = 'Filas borradas: ';
 $strDeleteNoUsersSelected = '¡No se han seleccionado usuarios para eliminar!';
 $strDeleteRelation = 'Eliminar la relación';
 $strDeleting = 'Borrando %s';
@@ -223,6 +226,7 @@ $strDescending = 'Descendente';
 $strDescription = 'Descripción';
 $strDesigner = 'Diseñador';
 $strDesignerHelpDisplayField = 'El campo Display se halla en color rosado. Para activar o desactivar un campo como un campo Display, dé clic en el ícono "Seleccione el campo a mostrar", luego dé clic en el nombre apropiado del campo.';
+$strDetails = 'Detalles...';
 $strDictionary = 'diccionario';
 $strDirectLinks = 'Enlaces directos';
 $strDirtyPages = 'Páginas que requieren ser depuradas'; 
@@ -270,6 +274,7 @@ $strEscapeWildcards = 'Los comodines _ y % deben acompañarse de \ para usarlos
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estonio';
 $strEvent = 'Evento';
+$strEvents = 'Eventos';
 $strExcelEdition = 'Edición Excel';
 $strExecuteBookmarked = 'Ejecute la consulta marcada previamente';
 $strExplain = 'Explicar el SQL';
@@ -303,7 +308,8 @@ $strFlushQueryCache = 'Vaciar el cache de consultas';
 $strFlushTables = 'Vaciar el cache de todas las tablas';
 $strFlushTable = 'Vaciar el caché de la tabla ("FLUSH")';
 $strFontSize = 'Tamaño del font';
-$strForeignKeyError = 'Error creando llaves extranjeras (foreign keys).  Revise los tipos de datos';
+$strForeignKeyError = 'Ocurrió un error al crear la llave extranjera en %1$s (revise los data types)';
+$strForeignKeyRelationAdded = 'Se añadió una relación FOREIGN KEY';
 $strFormat = 'Formato';
 $strFormEmpty = '¡Falta un valor en el formulario!';
 $strFreePages = 'Páginas libres'; 
@@ -328,7 +334,6 @@ $strGzip = '"Comprimido con gzip"';
 
 $strHandler = 'Gestor';
 $strHasBeenAltered = 'fue modificada.';
-$strHasBeenCreated = 'se creó.';
 $strHaveToShow = 'Debe elegir al menos una columna para mostrar';
 $strHebrew = 'Hebreo';
 $strHelp = 'Ayuda';
@@ -357,7 +362,7 @@ $strImportFormat = 'Formato del archivo importado';
 $strImport = 'Importar';
 $strImportSuccessfullyFinished = 'La importación se ejecutó exitosamente, se ejecutaron %d consultas.';
 $strIndexes = 'Índices';
-$strIndexesSeemEqual = 'Los siguientes índices parecen ser idénticos y uno de ellos debe ser removido:';
+$strIndexesSeemEqual = 'Los índices %1$s y %2$s parecen ser iguales y posiblemente se puede remover uno.';
 $strIndexHasBeenDropped = 'El índice %s ha sido eliminado';
 $strIndex = 'Índice';
 $strIndexName = 'Nombre del índice&nbsp;:';
@@ -371,14 +376,13 @@ $strInnoDBDataFilePath = 'Archivos de datos';
 $strInnoDBDataHomeDirDesc = 'La parte constante de la ruta del directorio para todos los archivos de datos InnoDB.'; 
 $strInnoDBDataHomeDir = 'Directorio raíz de los datos';
 $strInnoDBPages = 'páginas';
-$strInnoDBRelationAdded = 'Se añadió la relación InnoDB';
 $strInnodbStat = 'Estado del InnoDB';
 $strInsecureMySQL = 'Su archivo de configuración contiene parámetros (root sin contraseña) que corresponden a la cuenta privilegiada predeterminada de MySQL. Su servidor de MySQL está usando estos valores, lo que constituye una vulnerabilidad.  Se le recomienda corregir esta brecha de seguridad.  Por ejemplo, desde la página de inicio de phpMyAdmin seleccione Privilegios y agregue la contraseña a root@localhost.  Deberá escribir la misma contraseña en config.inc.php de phpMyAdmin';
 $strInsertAsNewRow = 'Insertar como una nueva fila';
-$strInsertedRowId = 'Se insertó la ID de la fila:';
-$strInsertedRows = 'Filas insertadas:';
+$strInsertedRowId = 'La Id de la fila insertada es: %1$d';
 $strInsert = 'Insertar';
-$strInternalNotNecessary = '* No es necesaria una relación interna cuando también existe en InnoDB.';
+$strInterface = 'Interfaz';
+$strInternalAndForeign = 'No es necesaria una relación interna cuando existe una relación LLAVE EXTRANJERA correspondiente.';
 $strInternalRelationAdded = 'Se añadió la relación interna';
 $strInternalRelations = 'Relaciones internas';
 $strInUse = 'en uso';
@@ -483,8 +487,6 @@ $strMySQLConnectionCollation = 'Cotejamiento de las conexiones MySQL';
 $strMysqlLibDiffersServerVersion = 'Su versión de librería PHP MySQL  %s es distinta de aquella de su versión de servidor MySQL %s. Esto puede ocasionar un comportamiento impredecible.';
 $strMySQLSaid = 'MySQL ha dicho: ';
 $strMySQLShowProcess = 'Mostrar procesos';
-$strMySQLShowStatus = 'Mostrar información de tiempo de ejecución de MySQL';
-$strMySQLShowVars = 'Mostrar las variables del sistema MySQL';
 
 $strName = 'Nombre';
 $strNext = 'Próxima';
@@ -531,22 +533,52 @@ $strOpenDocumentText = 'Texto Open Document';
 $strOpenNewWindow = 'Abrir nueva ventana de phpMyAdmin';
 $strOperations = 'Operaciones';
 $strOperator = 'Operador';
+$strOptimize = 'Optimice';
 $strOptimizeTable = 'Optimizar la tabla';
 $strOptions = 'Opciones';
 $strOr = 'O';
 $strOverhead = 'Residuo a depurar';
 $strOverwriteExisting = 'Sobreescribir el(los) archivo(s) existente(s)';
 
+$strPacked = 'Empacado';
 $strPageNumber = 'Número de página:';
 $strPagesToBeFlushed = 'Páginas que serán eliminadas'; 
 $strPaperSize = 'Tamaño del papel';
 $strPartialImport = 'Importación parcial';
 $strPartialText = 'Textos parciales';
+$strPartitionDefinition = 'definición de la PARTICIÓN';
+$strPartitioned = 'particionado';
+$strPartitionMaintenance = 'Mantenimiento de la partición';
+$strPartition = 'Partición %s';
 $strPasswordChanged = 'La contraseña para %s se cambió exitosamente.';
 $strPassword = 'Contraseña';
 $strPasswordEmpty = '¡La contraseña está vacía!';
 $strPasswordHashing = 'Hashing de la contraseña';
 $strPasswordNotSame = '¡Las contraseñas no coinciden!';
+$strPBXTCheckpointFrequencyDesc = 'La cantidad de datos escritos a la bitácora de transacciones antes de hacer un punto de revisión. El valor predeterminado es 24MB.';
+$strPBXTCheckpointFrequency = 'Frecuencia del punto de revisión';
+$strPBXTDataFileGrowSizeDesc = 'Tamaño que puede crecer el archivo de gestión de datos (.xtd).';
+$strPBXTDataFileGrowSize = 'Tamaño que puede crecer el archivo de datos';
+$strPBXTDataLogThresholdDesc = 'El tamaño máximo de una bitácora de archivo de datos. El predeterminado es 64MB. PBXT puede crear un máximo de 32000 bitácoras de datos, que son utilizados por todas las tablas. Por tanto, esta variable se puede incrementar para incrementar la cantidad total de datos que se pueden almacenar en la base de datos.';
+$strPBXTDataLogThreshold = 'Umbral de la bitácora de datos';
+$strPBXTGarbageThresholdDesc = 'El porcentaje de chatarra en un archivo bitácora de datos antes de ser compactado. Este es un valor entre 1 y 99. El valor predeterminado es 50.';
+$strPBXTGarbageThreshold = 'Umbral de chatarra';
+$strPBXTIndexCacheSizeDesc = 'Esta es la cantidad de memoria asignada al index cache. El valor predeterminado es 32MB. La memoria asignada aquí se usa solamente para el caché de las páginas índice.';
+$strPBXTIndexCacheSize = 'Tamaño del caché del índice';
+$strPBXTLogBufferSizeDesc = 'El tamaño de la memoria (búfer) utilizada cuando escribe una bitácora de datos. El predeterminado es 256MB. El motor asigna un búfer por proceso, pero solamente si el proceso es requerido para escribir una bitácora de datos.';
+$strPBXTLogBufferSize = 'Tamaño de la bitácora del búfer';
+$strPBXTLogCacheSizeDesc = 'La cantidad de memoria asignada al caché de la bitácora de transacciones utilizado para hacer el caché de los datos de la bitácora de transacciones. El valor predeterminado es 16MB.';
+$strPBXTLogCacheSize = 'Tamaño del caché de la bitácora';
+$strPBXTLogFileCount = 'Contaje de archivos bitácora';
+$strPBXTLogFileCountDesc = 'Este es el número de bitácoras de archivos de transacción (pbxt/system/xlog*.xt) que el sistema mantendrá. Si el número de bitácoras excede este valor, entonces las bitácoras antiguas se eliminan, de otro modo su nombre cambia y reciben el siguiente número más alto.';
+$strPBXTLogFileThresholdDesc = 'El tamaño de la bitácora de transacciones antes del rollover, y se crea una nueva bitácora. El valor predeterminado es 16MB.';
+$strPBXTLogFileThreshold = 'Umbral del archivo bitácora';
+$strPBXTRecordCacheSizeDesc = 'Esta es la cantidad de memoria asignada al caché de registros utilizado para el caché de los datos de la tabla. El valor predeterminado es 32MB. Esta memoria se utiliza para el caché de cambios a los archivos de datos handle (.xtd) y apuntador de la fila (.xtr).';
+$strPBXTRecordCacheSize = 'Tamaño del caché del registro';
+$strPBXTRowFileGrowSizeDesc = 'Tamaño que puede crecer el archivo del apuntador de filas (.xtr).';
+$strPBXTRowFileGrowSize = 'Tamaño que puede crecer el archivo de filas';
+$strPBXTTransactionBufferSizeDesc = 'El tamaño de global transaction log buffer (el motor asigna 2 memorias búfer de este tamaño). El valor predeterminado es 1MB.';
+$strPBXTTransactionBufferSize = 'Tamaño de la memoria (búfer) de la transacción';
 $strPdfDbSchema = 'Esquema de la base de datos "%s" - Página %s';
 $strPdfInvalidTblName = '¡La tabla "%s" no existe!';
 $strPdfNoTables = 'No existen tablas';
@@ -558,13 +590,12 @@ $strPerMinute = 'por minuto';
 $strPerSecond = 'por segundo';
 $strPersian = 'Persa';
 $strPhoneBook = 'directorio telefónico';
-$strPHP40203 = 'Usted está usando PHP 4.2.3, el cual tiene un error de codificación en cuanto a las "cadenas de caracteres multi-byte" (mbstring). Lea el reporte 19404 de PHP. No se recomienda el uso de phpMyAdmin con esta versión de PHP.';
 $strPhp = 'Crear código PHP';
+$strPHPExtension = 'extensión PHP';
 $strPHPVersion = 'Versión de PHP';
 $strPleaseSelectPrimaryOrUniqueKey = 'Por favor, seleccione la clave primaria o una clave única';
 $strPmaDocumentation = 'Documentación de phpMyAdmin';
 $strPmaUriError = 'El contenido de <tt>$cfg[\'PmaAbsoluteUri\']</tt> ¡DEBE constar en config.inc.php!';
-$strPmaWiki = 'Wiki del phpMyAdmin';
 $strPolish = 'Polaco';
 $strPortrait = 'Orientación vertical';
 $strPos1 = 'Empezar';
@@ -588,6 +619,7 @@ $strPrivDescCreateView = 'Permite crear nuevas vistas.';
 $strPrivDescDelete = 'Permite borrar datos.';
 $strPrivDescDropDb = 'Permite eliminar bases de datos y tablas.';
 $strPrivDescDropTbl = 'Permite eliminar tablas.';
+$strPrivDescEvent = 'Permite organizar los eventos para el gestor de eventos';
 $strPrivDescExecute5 = 'Permite ejecutar las rutinas almacenadas.';
 $strPrivDescExecute = 'Permite ejecutar procedimientos guardados; no tiene efecto en esta versión de MySQL.';
 $strPrivDescFile = 'Permite importar y exportar datos de y hacia archivos.';
@@ -599,8 +631,7 @@ $strPrivDescMaxConnections = 'Limita el número de conexiones nuevas que el usua
 $strPrivDescMaxQuestions = 'Limita el número de consultas que el usuario puede enviar al servidor por hora.';
 $strPrivDescMaxUpdates = 'Limita el número de comandos que cambian cualquier tabla o base de datos que el usuario puede ejecutar por hora.';
 $strPrivDescMaxUserConnections = 'Limita el número de conexiones simultáneas que el usuario pueda tener.';
-$strPrivDescProcess3 = 'Permite eliminar los procesos de otros usuarios.';
-$strPrivDescProcess4 = 'Permite ver las consultas completas en la lista de procesos.';
+$strPrivDescProcess = 'Permite ver los procesos de todos los usuarios';
 $strPrivDescReferences = 'No tiene efecto en esta versión de MySQL.';
 $strPrivDescReload = 'Permite volver a cargar los parámetros del servidor y depurar los cachés del servidor.';
 $strPrivDescReplClient = 'Da el derecho al usuario para preguntar dónde están los "esclavos / masters".';
@@ -610,6 +641,7 @@ $strPrivDescShowDb = 'Concede acceso a la lista completa de bases de datos.';
 $strPrivDescShowView = 'Permite llevar a cabo las consultas SHOW CREATE VIEW (MOSTRAR CREAR VER).';
 $strPrivDescShutdown = 'Permite desconectar el servidor.';
 $strPrivDescSuper = 'Permite la conexión, incluso si el número máximo de conexiones ha sido alcanzado; Necesario para la mayor parte de operaciones administrativas tales como montar parámetros de variables globales o matar procesos de otros usuarios.';
+$strPrivDescTrigger = 'Permite crear y eliminar un evento desencadenante';
 $strPrivDescUpdate = 'Permite cambiar los datos.';
 $strPrivDescUsage = 'Sin privilegios.';
 $strPrivileges = 'Privilegios';
@@ -635,11 +667,14 @@ $strQueryType = 'Tipo de consulta';
 $strQueryWindowLock = 'No sobreescribir esta consulta desde fuera de la ventana';
 
 $strReadRequests = 'Lea las solicitudes';
+$strRebuild = 'Reconstruya';
 $strReceived = 'Recibido';
 $strRecommended = 'recomendado';
 $strRecords = 'Registros';
 $strReferentialIntegrity = 'Comprobar la integridad referencial:';
 $strRefresh = 'Actualizar';
+$strRelationalDisplayField = 'Campo que muestra las relaciones';
+$strRelationalKey = 'Llave relacional';
 $strRelationalSchema = 'Esquema relacionado';
 $strRelationDeleted = 'La relación fue eliminada';
 $strRelationNotWorking = 'Las opciones adicionales para trabajar con tablas vinculadas fueron desactivadas. Para saber porqué, dé clic %saquí%s.';  //Features = ¿opciones, componentes?
@@ -649,10 +684,12 @@ $strRelationView = 'Vista de relaciones';
 $strReload = 'Cargar nuevamente';
 $strReloadingThePrivileges = 'Cargando los privilegios nuevamente';
 $strReloadPrivileges = 'Cargar los privilegios nuevamente';
+$strRemovePartitioning = 'Remueva la partición';
 $strRemoveSelectedUsers = 'Eliminar a los usuarios seleccionados';
 $strRenameDatabaseOK = 'La base de datos %s ha sido cambiada de nombre a %s';
 $strRenameTable = 'Cambiar el nombre de la tabla a';
 $strRenameTableOK = 'Tabla %s ahora se llama %s';
+$strRepair = 'Repare';
 $strRepairTable = 'Reparar la tabla';
 $strReplaceNULLBy = 'Reemplazar NULL con';
 $strReplaceTable = 'Reemplazar los datos de la tabla con los del archivo';
@@ -669,8 +706,11 @@ $strRomanian = 'Rumano';
 $strRoutineReturnType = 'Muestre el tipo';
 $strRoutines = 'Rutinas';
 $strRowLength = 'Longitud de la fila';
+$strRowsAffected = '%1$d fila(s) fueron afectadas.';
+$strRowsDeleted = '%1$d fila(s) fueron eliminadas.';
 $strRows = 'Filas';
 $strRowsFrom = 'filas empezando de';
+$strRowsInserted = '%1$d filas(s) fueron insertadas.';
 $strRowSize = ' Tamaño de la fila ';
 $strRowsModeFlippedHorizontal = 'horizontal (encabezados rotados)';
 $strRowsModeHorizontal = 'horizontal';
@@ -689,6 +729,7 @@ $strSavePosition = 'Guardar posición';
 $strScaleFactorSmall = 'El factor de la escala es demasiado pequeño para poner el esquema en una página';
 $strSearch = 'Buscar';
 $strSearchFormTitle = 'Buscar en la base de datos';
+$strSearchInField = 'Dentro del campo:';
 $strSearchInTables = 'En la(s) tabla(s):';
 $strSearchNeedle = 'Palabra(s) o valor(es) a buscar (comodín: "%"):';
 $strSearchOption1 = 'al menos una de estas palabras';
@@ -891,14 +932,17 @@ $strStructure = 'Estructura';
 $strStructureForView = 'Estructura para la vista';
 $strSubmit = 'Enviar';
 $strSuccess = 'Su consulta se ejecutó con éxito';
+$strSuhosin = 'El servidor está utilizando Suhosin. Por favor, refiérase a %sdocumentation%s para posibles ajustes.';
 $strSum = 'Número de filas';
 $strSwedish = 'Sueco';
 $strSwitchToDatabase = 'Seleccionar la base de datos copiada';
 $strSwitchToTable = 'Cambiar (switch) a la tabla copiada';
 
 $strTableAlreadyExists = '¡La tabla %s ya existe!';
+$strTableAlteredSuccessfully = 'Los cambios en la Tabla %1$s se hicieron exitosamente';
 $strTableComments = 'Comentarios de la tabla';
 $strTableEmpty = '¡El nombre de la tabla está vacío!';
+$strTableHasBeenCreated = 'La Tabla %1$s se creó.';
 $strTableHasBeenDropped = 'Se ha eliminado la tabla %s';
 $strTableHasBeenEmptied = 'Se ha vaciado la tabla %s';
 $strTableHasBeenFlushed = 'Se ha vaciado el caché de la tabla %s';
@@ -914,6 +958,7 @@ $strTakeIt = 'tómelo';
 $strTblPrivileges = 'Privilegios específicos para la tabla';
 $strTempData = 'Datos temporales';
 $strTextAreaLength = ' Debido a su longitud,<br /> este campo podría no ser editable ';
+$strTexyText = 'Texto Texy!';
 $strThai = 'Tailandés';
 $strThemeDefaultNotFound = '¡No se halló la plantilla de interfaz (theme) predeterminada %s!';
 $strThemeNoPreviewAvailable = 'No existe una previsualización disponible.';
@@ -978,7 +1023,6 @@ $strUploadLimit = 'Usted probablemente intentó cargar un archivo demasiado gran
 $strUploadsNotAllowed = 'No está permitido subir archivos a este servidor.';
 $strUsage = 'Uso';
 $strUseBackquotes = 'Usar "backquotes" con tablas y nombres de campo';
-$strUsedPhpExtensions = 'Extensiones PHP utilizadas';
 $strUseHostTable = 'Usar la tabla Anfitrión (Host)';
 $strUserAlreadyExists = '¡El usuario %s ya existe!';
 $strUserEmpty = '¡El nombre de usuario está vacío!';
@@ -1001,20 +1045,22 @@ $strVersionInformation = 'Acerca de esta versión';
 $strViewDumpDatabases = 'Ver el volcado (schema) de la base de datos';
 $strViewDumpDB = 'Ver el volcado esquema de la base de datos';
 $strViewDump = 'Mostrar el volcado esquema de la tabla';
+$strViewHasAtLeast = 'Esta vista tiene al menos este número de filas.  Por favor, refiérase a la %sdocumentation%s.';
 $strViewHasBeenDropped = 'Se descartó el modo de visualización %s';
-$strViewMaxExactCount = 'Esta visualización tiene más de %s filas. Por favor, refiérase a la %sdocumentación%s.';
 $strViewName = '(VIEW) VER nombre';
 $strView = 'Visualizar';
 
+$strWebServer = 'Servidor web';
 $strWebServerUploadDirectory = 'directorio en el servidor web para subir los archivos';
 $strWebServerUploadDirectoryError = 'No está disponible el directorio que usted habilitó para subir las tareas';
 $strWelcome = 'Bienvenido a %s';
 $strWestEuropean = 'Europea occidental';
+$strWiki = 'Wiki';
 $strWildcard = 'comodín';
 $strWindowNotFound = 'La ventana del navegador no pudo actualizarse. Quizá cerró la ventana principal o su navegador está bloqueando las actualizaciones en ventanas múltiples debido a sus parámetros de seguridad.';
 $strWithChecked = 'Para los elementos que están marcados:';
 $strWriteRequests = 'Escribir las solicitudes';
-$strWrongUser = 'El nombre de usuario o la contraseña está equivocado. El acceso fue denegado.';
+$strWrongUser = 'El nombre de usuario o la contraseña es incorrecto. El acceso fue denegado.';
 
 $strXML = 'XML';
 
